@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@ import org.hsqldb.server.ServerConstants;
  */
 
 // patch 1.9.0 by Blaine Simpson - IPv6 support
-public class DatabaseURL {
+public final class DatabaseURL {
 
     public static final String S_DOT               = ".";
     public static final String S_MEM               = "mem:";
@@ -75,31 +75,29 @@ public class DatabaseURL {
     /**
      * Parses the url into components that are returned in a properties object.
      *
-     * <p> The following components are isolated:
+     * The following components are isolated:<p>
      *
-     * <p>
-     * <ul> url: the original url
+     * url: the original url
+     * <ul>
      *
-     * <p> connection_type: a static string that indicate the protocol. If the
+     * <li> connection_type: a static string that indicate the protocol. If the
      * url does not begin with a valid protocol, null is returned by this method
      * instead of the properties object.
      *
-     * <p> host: name of host in networked modes in lowercase
+     * <li> host: name of host in networked modes in lowercase
      *
-     * <p> port: port number in networked mode, or 0 if not present
+     * <li> port: port number in networked mode, or 0 if not present
      *
-     * <p> path: path of the resource on server in networked modes, minimum
+     * <li> path: path of the resource on server in networked modes, minimum
      * (slash) with path elements appended apart from servlet path which is
      * (slash) plus the name of the servlet
      *
-     * <p> database: database name. For memory, networked modes,
+     * <li> database: database name. For memory, networked modes,
      * this is returned in lowercase, for file: and res: databases the original case of
      * characters is preserved. Returns empty string if name is not present in
      * the url.
      *
-     * <p> for each protocol if port number is not in the url
-     *
-     * <p> Additional connection properties specified as key/value pairs.
+     * <li> Additional connection properties specified as key/value pairs.
      * </ul>
      *
      * @return null returned if the part that should represent the port is not
@@ -356,7 +354,7 @@ public class DatabaseURL {
                 }
             }
 
-            if (database.length() == 0) {
+            if (database.isEmpty()) {
                 return null;
             }
         }
