@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,7 @@ import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayListIdentity;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.lib.Set;
@@ -62,7 +62,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class Expression implements Cloneable {
@@ -113,9 +113,6 @@ public class Expression implements Cloneable {
     protected Type dataType;
     protected int  groupingType;
 
-    //
-    int queryTableColumnIndex = -1;    // >= 0 when it is used for order by
-
     // self position in the result table
     int resultTableColumnIndex = -1;
 
@@ -203,6 +200,7 @@ public class Expression implements Cloneable {
             case OpTypes.ALTERNATIVE :
             case OpTypes.CASEWHEN :
             case OpTypes.CAST :
+            case OpTypes.CONVERT :
                 return ddl;
         }
 
@@ -365,7 +363,7 @@ public class Expression implements Cloneable {
     /**
      * Set the data type
      */
-    void setDataType(Session session, Type type) {
+    public void setDataType(Session session, Type type) {
 
         if (opType == OpTypes.VALUE) {
             valueData = type.convertToType(session, valueData, dataType);
@@ -397,15 +395,13 @@ public class Expression implements Cloneable {
             case OpTypes.VALUE :
                 return equals(valueData, other.valueData);
 
-            case OpTypes.ARRAY :
-
-            //
             case OpTypes.ARRAY_SUBQUERY :
             case OpTypes.ROW_SUBQUERY :
             case OpTypes.TABLE_SUBQUERY :
                 return table.queryExpression.isEquivalent(
                     other.table.queryExpression);
 
+            case OpTypes.ARRAY :
             default :
                 return equals(nodes, other.nodes);
         }
@@ -737,7 +733,7 @@ public class Expression implements Cloneable {
         return isDistinctAggregate;
     }
 
-    void setAggregate() {
+    public void setAggregate() {
         hasAggregate = true;
     }
 
@@ -778,7 +774,7 @@ public class Expression implements Cloneable {
     /**
      * Returns the left node
      */
-    Expression getLeftNode() {
+    public Expression getLeftNode() {
         return nodes.length > 0 ? nodes[LEFT]
                                 : null;
     }
@@ -786,7 +782,7 @@ public class Expression implements Cloneable {
     /**
      * Returns the right node
      */
-    Expression getRightNode() {
+    public Expression getRightNode() {
         return nodes.length > 1 ? nodes[RIGHT]
                                 : null;
     }
@@ -795,7 +791,7 @@ public class Expression implements Cloneable {
         nodes[LEFT] = e;
     }
 
-    void setRightNode(Expression e) {
+    public void setRightNode(Expression e) {
         nodes[RIGHT] = e;
     }
 
@@ -934,18 +930,21 @@ public class Expression implements Cloneable {
     /**
      * resolve tables and collect unresolved column expressions
      */
-    public HsqlList resolveColumnReferences(Session session,
-            RangeGroup rangeGroup, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet) {
+    public List resolveColumnReferences(Session session,
+                                        RangeGroup rangeGroup,
+                                        RangeGroup[] rangeGroups,
+                                        List unresolvedSet) {
 
         return resolveColumnReferences(session, rangeGroup,
                                        rangeGroup.getRangeVariables().length,
                                        rangeGroups, unresolvedSet, true);
     }
 
-    public HsqlList resolveColumnReferences(Session session,
-            RangeGroup rangeGroup, int rangeCount, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet, boolean acceptsSequences) {
+    public List resolveColumnReferences(Session session,
+                                        RangeGroup rangeGroup, int rangeCount,
+                                        RangeGroup[] rangeGroups,
+                                        List unresolvedSet,
+                                        boolean acceptsSequences) {
 
         if (opType == OpTypes.VALUE) {
             return unresolvedSet;
@@ -1160,7 +1159,8 @@ public class Expression implements Cloneable {
                     nodes[i].dataType = nodeDataType;
                 }
 
-                dataType = new ArrayType(nodeDataType, nodes.length);
+                dataType = new ArrayType(nodeDataType,
+                                         ArrayType.defaultArrayCardinality);
 
                 return;
             }
@@ -1177,7 +1177,9 @@ public class Expression implements Cloneable {
                     throw Error.error(ErrorCode.X_42564);
                 }
 
-                dataType = new ArrayType(dataType, Integer.MAX_VALUE);
+                dataType =
+                    new ArrayType(dataType,
+                                  ArrayType.defaultLargeArrayCardinality);
 
                 break;
             }
@@ -1360,14 +1362,14 @@ public class Expression implements Cloneable {
     /**
      * Returns the column index in the table
      */
-    int getColumnIndex() {
+    public int getColumnIndex() {
         return columnIndex;
     }
 
     /**
      * Returns the data type
      */
-    Type getDataType() {
+    public Type getDataType() {
         return dataType;
     }
 
@@ -1435,7 +1437,7 @@ public class Expression implements Cloneable {
         }
     }
 
-    Object getValue(Session session, Type type) {
+    public Object getValue(Session session, Type type) {
 
         Object o = getValue(session);
 
@@ -1661,7 +1663,7 @@ public class Expression implements Cloneable {
 
         boolean        nonDeterministic = false;
         OrderedHashSet set              = new OrderedHashSet();
-        HsqlList unresolved = resolveColumnReferences(session, rangeGroup,
+        List unresolved = resolveColumnReferences(session, rangeGroup,
             RangeGroup.emptyArray, null);
 
         ExpressionColumn.checkColumnsResolved(unresolved);
@@ -1890,9 +1892,8 @@ public class Expression implements Cloneable {
      * collect all expressions of a set of expression types appearing anywhere
      * in a select statement and its subselects, etc.
      */
-    OrderedHashSet collectAllExpressions(OrderedHashSet set,
-                                         OrderedIntHashSet typeSet,
-                                         OrderedIntHashSet stopAtTypeSet) {
+    public OrderedHashSet collectAllExpressions(OrderedHashSet set,
+            OrderedIntHashSet typeSet, OrderedIntHashSet stopAtTypeSet) {
 
         if (stopAtTypeSet.contains(opType)) {
             return set;
@@ -1990,8 +1991,8 @@ public class Expression implements Cloneable {
 
         RangeGroup ranges = new RangeGroupSimple(table.getDefaultRanges(),
             false);
-        HsqlList set = resolveColumnReferences(session, ranges,
-                                               RangeGroup.emptyArray, null);
+        List set = resolveColumnReferences(session, ranges,
+                                           RangeGroup.emptyArray, null);
 
         if (set != null && !set.isEmpty()) {
             Expression e = (Expression) set.get(0);
@@ -2016,18 +2017,15 @@ public class Expression implements Cloneable {
         }
     }
 
-    static HsqlList resolveColumnSet(Session session,
-                                     RangeVariable[] rangeVars,
-                                     RangeGroup[] rangeGroups,
-                                     HsqlList sourceSet) {
+    static List resolveColumnSet(Session session, RangeVariable[] rangeVars,
+                                 RangeGroup[] rangeGroups, List sourceSet) {
         return resolveColumnSet(session, rangeVars, rangeVars.length,
                                 rangeGroups, sourceSet, null);
     }
 
-    static HsqlList resolveColumnSet(Session session,
-                                     RangeVariable[] rangeVars,
-                                     int rangeCount, RangeGroup[] rangeGroups,
-                                     HsqlList sourceSet, HsqlList targetSet) {
+    static List resolveColumnSet(Session session, RangeVariable[] rangeVars,
+                                 int rangeCount, RangeGroup[] rangeGroups,
+                                 List sourceSet, List targetSet) {
 
         if (sourceSet == null) {
             return targetSet;
@@ -2050,7 +2048,7 @@ public class Expression implements Cloneable {
         return false;
     }
 
-    void getJoinRangeVariables(RangeVariable[] ranges, HsqlList list) {}
+    void getJoinRangeVariables(RangeVariable[] ranges, List list) {}
 
     double costFactor(Session session, RangeVariable range, int operation) {
         return Index.minimumSelectivity;
@@ -2116,7 +2114,7 @@ public class Expression implements Cloneable {
         return false;
     }
 
-    public void setCondition(ExpressionLogical e) {
+    public void setCondition(Expression e) {
         throw Error.runtimeError(ErrorCode.U_S0500, "Expression");
     }
 
