@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayListIdentity;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.types.ArrayType;
 import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.RowType;
@@ -46,7 +46,7 @@ import org.hsqldb.types.Type;
  * Implementation of array aggregate operations
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 2.0.1
  */
 public class ExpressionArrayAggregate extends Expression {
@@ -168,11 +168,11 @@ public class ExpressionArrayAggregate extends Expression {
         return sb.toString();
     }
 
-    public HsqlList resolveColumnReferences(Session session,
+    public List resolveColumnReferences(Session session,
             RangeGroup rangeGroup, int rangeCount, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet, boolean acceptsSequences) {
+            List unresolvedSet, boolean acceptsSequences) {
 
-        HsqlList conditionSet = condition.resolveColumnReferences(session,
+        List conditionSet = condition.resolveColumnReferences(session,
             rangeGroup, rangeCount, rangeGroups, null, false);
 
         if (conditionSet != null) {
@@ -230,7 +230,7 @@ public class ExpressionArrayAggregate extends Expression {
             case OpTypes.ARRAY_AGG :
                 arrayDataType =
                     new ArrayType(rowDataType,
-                                  ArrayType.defaultArrayCardinality);
+                                  ArrayType.defaultLargeArrayCardinality);
                 dataType = new ArrayType(exprType,
                                          ArrayType.defaultArrayCardinality);
                 break;
@@ -238,14 +238,14 @@ public class ExpressionArrayAggregate extends Expression {
             case OpTypes.GROUP_CONCAT :
                 arrayDataType =
                     new ArrayType(rowDataType,
-                                  ArrayType.defaultArrayCardinality);
+                                  ArrayType.defaultLargeArrayCardinality);
                 dataType = Type.SQL_VARCHAR_DEFAULT;
                 break;
 
             case OpTypes.MEDIAN :
                 arrayDataType =
                     new ArrayType(nodeDataTypes[0],
-                                  ArrayType.defaultArrayCardinality);
+                                  ArrayType.defaultLargeArrayCardinality);
                 dataType = ExpressionAggregate.getType(session,
                                                        OpTypes.MEDIAN,
                                                        exprType);
@@ -427,10 +427,10 @@ public class ExpressionArrayAggregate extends Expression {
     }
 
     public boolean hasCondition() {
-        return condition != null && !condition.isTrue();
+        return !condition.isTrue();
     }
 
-    public void setCondition(ExpressionLogical e) {
+    public void setCondition(Expression e) {
         condition = e;
     }
 
@@ -439,9 +439,7 @@ public class ExpressionArrayAggregate extends Expression {
         ExpressionArrayAggregate e =
             (ExpressionArrayAggregate) super.duplicate();
 
-        if (condition != null) {
-            e.condition = condition.duplicate();
-        }
+        e.condition = condition.duplicate();
 
         return e;
     }
