@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,8 +37,8 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayListIdentity;
-import org.hsqldb.lib.HashMappedList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.Set;
 import org.hsqldb.map.ValuePool;
@@ -50,7 +50,7 @@ import org.hsqldb.types.Type;
  * Implementation of column, variable, parameter, etc. access operations.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class ExpressionColumn extends Expression {
@@ -61,7 +61,7 @@ public class ExpressionColumn extends Expression {
         HsqlNameManager.getSimpleName("ROWNUM", false);
 
     //
-    public static final HashMappedList diagnosticsList = new HashMappedList();
+    public static final OrderedHashMap diagnosticsList = new OrderedHashMap();
     static final String[] diagnosticsVariableTokens    = new String[] {
         Tokens.T_NUMBER, Tokens.T_MORE, Tokens.T_ROW_COUNT
     };
@@ -173,10 +173,6 @@ public class ExpressionColumn extends Expression {
         this.rangePosition = rangePosition;
     }
 
-    ExpressionColumn() {
-        super(OpTypes.ASTERISK);
-    }
-
     ExpressionColumn(int type) {
 
         super(type);
@@ -404,9 +400,9 @@ public class ExpressionColumn extends Expression {
         return rangeVariable;
     }
 
-    public HsqlList resolveColumnReferences(Session session,
+    public List resolveColumnReferences(Session session,
             RangeGroup rangeGroup, int rangeCount, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet, boolean acceptsSequences) {
+            List unresolvedSet, boolean acceptsSequences) {
 
         switch (opType) {
 
@@ -954,7 +950,7 @@ public class ExpressionColumn extends Expression {
 
             case OpTypes.DYNAMIC_PARAM :
                 sb.append("DYNAMIC PARAM: ");
-                sb.append(", TYPE = ").append(dataType.getNameString());
+                sb.append(", TYPE = ").append(dataType.getDefinition());
                 break;
 
             case OpTypes.SEQUENCE :
@@ -994,7 +990,7 @@ public class ExpressionColumn extends Expression {
         return "";
     }
 
-    static void checkColumnsResolved(HsqlList set) {
+    public static void checkColumnsResolved(List set) {
 
         if (set != null && !set.isEmpty()) {
             Expression e = (Expression) set.get(0);
@@ -1139,8 +1135,10 @@ public class ExpressionColumn extends Expression {
                 }
 
                 for (int i = 0; i < length; i++) {
-                    if (columns[i] instanceof ExpressionColumn) {
-                        if (equals(columns[i])) {
+                    Expression e = (Expression) columns[i];
+
+                    if (e instanceof ExpressionColumn) {
+                        if (equals(e)) {
                             if (matchIndex < 0) {
                                 matchIndex = i;
                             } else if (session.database.sqlEnforceRefs) {
@@ -1151,9 +1149,8 @@ public class ExpressionColumn extends Expression {
                         }
 
                         if (tableName == null && schema == null
-                                && columnName
-                                    .equals(((ExpressionColumn) columns[i])
-                                        .columnName)) {
+                                && columnName.equals(
+                                    ((ExpressionColumn) e).columnName)) {
                             if (matchIndex < 0) {
                                 matchIndex = i;
                             } else if (session.database.sqlEnforceRefs) {
@@ -1304,7 +1301,7 @@ public class ExpressionColumn extends Expression {
         return isParam;
     }
 
-    void getJoinRangeVariables(RangeVariable[] ranges, HsqlList list) {
+    void getJoinRangeVariables(RangeVariable[] ranges, List list) {
 
         if (opType == OpTypes.COLUMN) {
             for (int i = 0; i < ranges.length; i++) {
