@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,7 @@ package org.hsqldb;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.types.BinaryData;
 import org.hsqldb.types.BinaryType;
@@ -49,7 +49,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class ExpressionOp extends Expression {
@@ -198,6 +198,24 @@ public class ExpressionOp extends Expression {
         return new ExpressionOp(e, dataType);
     }
 
+    public static Expression getConvertExpression(Session session,
+            Expression e, Type dataType) {
+
+        if (e.getType() == OpTypes.VALUE) {
+            Object value = dataType.convertToType(session,
+                                                  e.getValue(session),
+                                                  e.getDataType());
+
+            return new ExpressionValue(value, dataType);
+        }
+
+        Expression c = new ExpressionOp(e, dataType);
+
+        c.opType = OpTypes.CONVERT;
+
+        return c;
+    }
+
     public String getSQL() {
 
         StringBuilder sb    = new StringBuilder(64);
@@ -232,6 +250,10 @@ public class ExpressionOp extends Expression {
                 sb.append(')');
                 break;
 
+            case OpTypes.CONVERT :
+                sb.append(left);
+                break;
+
             case OpTypes.CASEWHEN :
                 sb.append(' ').append(Tokens.T_CASEWHEN).append('(');
                 sb.append(left).append(',').append(right).append(')');
@@ -329,6 +351,12 @@ public class ExpressionOp extends Expression {
                 sb.append(' ');
                 break;
 
+            case OpTypes.CONVERT :
+                sb.append(Tokens.T_CONVERT).append(' ');
+                sb.append(dataType.getTypeDefinition());
+                sb.append(' ');
+                break;
+
             case OpTypes.CASEWHEN :
                 sb.append(Tokens.T_CASEWHEN).append(' ');
                 break;
@@ -355,9 +383,11 @@ public class ExpressionOp extends Expression {
         return sb.toString();
     }
 
-    public HsqlList resolveColumnReferences(Session session,
-            RangeGroup rangeGroup, int rangeCount, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet, boolean acceptsSequences) {
+    public List resolveColumnReferences(Session session,
+                                        RangeGroup rangeGroup, int rangeCount,
+                                        RangeGroup[] rangeGroups,
+                                        List unresolvedSet,
+                                        boolean acceptsSequences) {
 
         if (opType == OpTypes.VALUE) {
             return unresolvedSet;
@@ -418,7 +448,8 @@ public class ExpressionOp extends Expression {
 
                 break;
             }
-            case OpTypes.CAST : {
+            case OpTypes.CAST :
+            case OpTypes.CONVERT : {
                 Expression node     = nodes[LEFT];
                 Type       nodeType = node.dataType;
 
@@ -559,6 +590,10 @@ public class ExpressionOp extends Expression {
             dataType = nodes[RIGHT].dataType;
 
             if (!nodes[RIGHT].dataType.equals(nodes[LEFT].dataType)) {
+                if (dataType.isCharacterType()) {
+                    dataType = Type.SQL_VARCHAR_DEFAULT;
+                }
+
                 nodes[LEFT] = new ExpressionOp(nodes[LEFT], dataType);
             }
         } else {
@@ -866,6 +901,24 @@ public class ExpressionOp extends Expression {
 
                 return value;
             }
+            case OpTypes.CONVERT : {
+                Object value =
+                    dataType.convertToType(session,
+                                           nodes[LEFT].getValue(session),
+                                           nodes[LEFT].dataType);
+
+                if (dataType.userTypeModifier != null) {
+                    Constraint[] constraints =
+                        dataType.userTypeModifier.getConstraints();
+
+                    for (int i = 0; i < constraints.length; i++) {
+                        constraints[i].checkCheckConstraint(session, null,
+                                                            null, value);
+                    }
+                }
+
+                return value;
+            }
             case OpTypes.CASEWHEN : {
                 Boolean result = (Boolean) nodes[LEFT].getValue(session);
 
