@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,7 +42,6 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.StringUtil;
-import org.hsqldb.types.DTIType;
 import org.hsqldb.types.TimestampData;
 import org.hsqldb.types.Types;
 
@@ -60,7 +59,7 @@ import org.hsqldb.types.Types;
  * timezone.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.7.0
  */
 public class HsqlDateTime {
@@ -69,7 +68,6 @@ public class HsqlDateTime {
     private static final Calendar tempCalDefault = new GregorianCalendar();
     private static final Calendar tempCalGMT =
         new GregorianCalendar(TimeZone.getTimeZone("GMT"), defaultLocale);
-    private static final Date   tempDate    = new Date(0);
     private static final String sdfdPattern = "yyyy-MM-dd";
     private static final SimpleDateFormat sdfd =
         new SimpleDateFormat(sdfdPattern);
@@ -133,17 +131,18 @@ public class HsqlDateTime {
         }
     }
 
-    public static void getTimestampString(StringBuilder sb, long seconds,
+    public static String getTimestampString(long seconds,
                                           int nanos, int scale) {
 
         synchronized (sdfts) {
-            tempDate.setTime(seconds * 1000);
-            sb.append(sdfts.format(tempDate));
+            sysDate.setTime(seconds * 1000);
+            String ts = sdfts.format(sysDate);
 
             if (scale > 0) {
-                sb.append('.');
-                sb.append(StringUtil.toZeroPaddedString(nanos, 9, scale));
+                ts += '.' + StringUtil.toZeroPaddedString(nanos, 9, scale);
             }
+
+            return ts;
         }
     }
 
@@ -308,6 +307,17 @@ public class HsqlDateTime {
 
             switch (part) {
 
+                case Types.DTI_ISO_WEEK_OF_YEAR : {
+                    int dayWeek = calendar.get(Calendar.DAY_OF_WEEK);
+
+                    if (dayWeek == 1) {
+                        dayWeek = 8;
+                    }
+                    calendar.add(Calendar.DAY_OF_YEAR, 2 - dayWeek);
+                    resetToDate(calendar);
+
+                    break;
+                }
                 case Types.DTI_WEEK_OF_YEAR : {
                     int dayWeek = calendar.get(Calendar.DAY_OF_WEEK);
 
@@ -470,7 +480,7 @@ public class HsqlDateTime {
         Types.SQL_INTERVAL_MONTH, Types.SQL_INTERVAL_MONTH,
         Types.SQL_INTERVAL_MONTH,
         -1, -1,
-        Types.DTI_WEEK_OF_YEAR, -1, Types.SQL_INTERVAL_DAY, Types.SQL_INTERVAL_DAY,
+        Types.DTI_WEEK_OF_YEAR, Types.DTI_ISO_WEEK_OF_YEAR, Types.SQL_INTERVAL_DAY, Types.SQL_INTERVAL_DAY,
         -1,
         Types.SQL_INTERVAL_HOUR, -1, Types.SQL_INTERVAL_HOUR,
         Types.SQL_INTERVAL_MINUTE,
@@ -658,7 +668,7 @@ public class HsqlDateTime {
     /**
      * Converts the given format into a pattern accepted by <code>java.text.SimpleDataFormat</code>
      *
-     * @param format
+     * @param format date format
      */
     public static String toJavaDatePattern(String format) {
 
@@ -885,7 +895,7 @@ public class HsqlDateTime {
         /**
          * Checks whether the specified bit is not set.
          *
-         * @param bit
+         * @param bit numbered from high bit
          */
         private boolean isZeroBit(int bit) {
             return (state & (1L << bit)) == 0;
@@ -893,7 +903,7 @@ public class HsqlDateTime {
 
         /**
          * Sets the specified bit.
-         * @param bit
+         * @param bit numbered from high bit
          */
         private void setBit(int bit) {
             state |= (1L << bit);
@@ -902,8 +912,8 @@ public class HsqlDateTime {
         /**
          * Matches the specified character against tokens.
          *
-         * @param ch
-         * @param position
+         * @param ch character
+         * @param position in the string
          */
         public boolean next(char ch, int position) {
 
