@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2019, The HSQL Development Group
+ * Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -88,7 +88,7 @@ import org.hsqldb.types.Type;
  *
  * @author Fred Toussi (fredt@users dot sourceforge dot net)
  * @author Thomas Mueller (Hypersonic SQL Group)
- * @version 2.3.1
+ * @version 2.6.0
  * @since 1.6.2
  */
 
@@ -107,7 +107,8 @@ class Like implements Cloneable {
     private int      iFirstWildCard;
     private boolean  isNull;
     int              escapeChar;
-    boolean          hasCollation;
+    String           prefix          = "";
+    static final int NORMAL_CHAR     = 0;
     static final int UNDERSCORE_CHAR = 1;
     static final int PERCENT_CHAR    = 2;
     boolean          isVariable      = true;
@@ -116,10 +117,6 @@ class Like implements Cloneable {
 
     Like() {}
 
-    void setParams(boolean collation) {
-        hasCollation = collation;
-    }
-
     void setIgnoreCase(boolean flag) {
         isIgnoreCase = flag;
     }
@@ -179,6 +176,18 @@ class Like implements Cloneable {
                                         (int) ((ClobData) o).length(session));
         }
 
+        if (!isBinary && prefix.length() > 0) {
+            if (length < prefix.length()) {
+                return false;
+            }
+
+            o = ((String) o).substring(0, prefix.length());
+
+            int compare = dataType.compare(session, prefix, o);
+
+            return compare == 0;
+        }
+
         return compareAt(session, o, 0, 0, iLen, length, cLike, wildCardType)
                ? Boolean.TRUE
                : Boolean.FALSE;
@@ -223,7 +232,7 @@ class Like implements Cloneable {
         for (; i < iLen; i++) {
             switch (wildCardType[i]) {
 
-                case 0 :                  // general character
+                case NORMAL_CHAR :        // general character
                     if ((j >= jLen)
                             || (cLike[i] != getChar(session, o, j++))) {
                         return false;
@@ -255,11 +264,7 @@ class Like implements Cloneable {
             }
         }
 
-        if (j != jLen) {
-            return false;
-        }
-
-        return true;
+        return j == jLen;
     }
 
     void setPattern(Session session, Object pattern, Object escape,
@@ -359,6 +364,50 @@ class Like implements Cloneable {
                 wildCardType[i + 1] = PERCENT_CHAR;
             }
         }
+
+        if (isBinary) {
+            return;
+        }
+
+        prefix = "";
+
+        int     prefixLength = 0;
+        boolean found        = false;
+
+        outerloop:
+        for (int i = 0; i < iLen; i++) {
+            switch (wildCardType[i]) {
+
+                case NORMAL_CHAR : {
+                    if (found) {
+                        found = false;
+
+                        break outerloop;
+                    }
+
+                    break;
+                }
+                case UNDERSCORE_CHAR : {
+                    found = false;
+
+                    break outerloop;
+                }
+                case PERCENT_CHAR : {
+                    if (found) {
+                        found = false;
+
+                        break outerloop;
+                    }
+
+                    prefixLength = i;
+                    found        = true;
+                }
+            }
+        }
+
+        if (found) {
+            prefix = String.valueOf(cLike, 0, prefixLength);
+        }
     }
 
     boolean isEquivalentToUnknownPredicate() {
@@ -392,21 +441,6 @@ class Like implements Cloneable {
         return getStartsWith();
     }
 
-    Object getRangeHigh(Session session) {
-
-        Object o = getStartsWith();
-
-        if (o == null) {
-            return null;
-        }
-
-        if (isBinary) {
-            return new BinaryData(session, (BinaryData) o, maxByteValue);
-        } else {
-            return dataType.concat(session, o, "\uffff");
-        }
-    }
-
     public String describe(Session session) {
 
         StringBuilder sb = new StringBuilder();
