@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@ import org.hsqldb.HsqlNameManager.HsqlName;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.IntKeyIntValueHashMap;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.types.IntervalType;
 import org.hsqldb.types.NumberType;
@@ -49,13 +49,13 @@ import org.hsqldb.types.Types;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class ParserBase {
 
-    protected Scanner  scanner;
-    protected Token    token;
+    protected Scanner scanner;
+    protected Token   token;
 
     //
     protected int           partPosition;
@@ -78,7 +78,7 @@ public class ParserBase {
 
         this.scanner           = scanner;
         this.token             = scanner.token;
-        this.recordedStatement = new HsqlArrayList();
+        this.recordedStatement = new HsqlArrayList(256);
     }
 
     public Scanner getScanner() {
@@ -248,9 +248,11 @@ public class ParserBase {
         String tokenString = token1.tokenString;
 
         if (token2 != null) {
-            tokenString += " " + token2.tokenString;
+            tokenString += token2.tokenString;
         }
 
+        tokenString += " ";
+
         scanner.replaceToken(tokenString);
 
         if (isRecording) {
@@ -486,9 +488,7 @@ public class ParserBase {
     void readThis(String tokenString) {
 
         if (!tokenString.equals(token.tokenString)) {
-            String required = tokenString;
-
-            throw unexpectedTokenRequire(required);
+            throw unexpectedTokenRequire(tokenString);
         }
 
         read();
@@ -825,6 +825,7 @@ public class ParserBase {
         expressionTypeMap.put(Tokens.VAR_SAMP, OpTypes.VAR_SAMP);
         expressionTypeMap.put(Tokens.ARRAY_AGG, OpTypes.ARRAY_AGG);
         expressionTypeMap.put(Tokens.GROUP_CONCAT, OpTypes.GROUP_CONCAT);
+        expressionTypeMap.put(Tokens.STRING_AGG, OpTypes.STRING_AGG);
         expressionTypeMap.put(Tokens.MEDIAN, OpTypes.MEDIAN);
     }
 
@@ -846,7 +847,7 @@ public class ParserBase {
         if (token.tokenType == Tokens.X_ENDPARSE) {
             return Error.parseError(ErrorCode.X_42590,
                                     ErrorCode.TOKEN_REQUIRED,
-                                    scanner.getLineNumber(), new Object[] {
+                                    scanner.getLineNumber(), new String[] {
                 "", required
             });
         }
@@ -866,7 +867,7 @@ public class ParserBase {
         }
 
         return Error.parseError(ErrorCode.X_42581, ErrorCode.TOKEN_REQUIRED,
-                                scanner.getLineNumber(), new Object[] {
+                                scanner.getLineNumber(), new String[] {
             tokenS, required
         });
     }
@@ -930,10 +931,10 @@ public class ParserBase {
      * read list of comma separated prop = value pairs as tokens
      * optionalEquals, requireEquals for use of '='
      */
-    HashMappedList readPropertyValuePairs(boolean optionalEquals,
+    OrderedHashMap readPropertyValuePairs(boolean optionalEquals,
                                           boolean requireEquals) {
 
-        HashMappedList list = null;
+        OrderedHashMap list = null;
         String         prop;
         Token          value;
         int            pos;
@@ -975,7 +976,7 @@ public class ParserBase {
             value = token.duplicate();
 
             if (list == null) {
-                list = new HashMappedList();
+                list = new OrderedHashMap();
             }
 
             list.put(prop, value);
