@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.LongDeque;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
@@ -50,7 +50,7 @@ import org.hsqldb.types.Type;
  * Parser for SQL stored procedures and functions - PSM
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class ParserRoutine extends ParserTable {
@@ -105,7 +105,24 @@ public class ParserRoutine extends ParserTable {
 
         variableNames.toArray(variables);
 
-        targetTypes = new Type[variables.length];
+        targetTypes = getTypesArray(variables);
+
+        select.setReturningResult();
+        select.resolve(session, rangeGroups, targetTypes);
+
+        if (select.getColumnCount() != variables.length) {
+            throw Error.error(ErrorCode.X_42564, Tokens.T_INTO);
+        }
+
+        Statement statement = new StatementSet(session, variables, select,
+                                               columnMap, compileContext);
+
+        return statement;
+    }
+
+    Type[] getTypesArray(Expression[] variables) {
+
+        Type[] targetTypes = new Type[variables.length];
 
         for (int i = 0; i < variables.length; i++) {
             if (variables[i].getColumn().getParameterMode()
@@ -119,17 +136,7 @@ public class ParserRoutine extends ParserTable {
             targetTypes[i] = variables[i].getDataType();
         }
 
-        select.setReturningResult();
-        select.resolve(session, rangeGroups, targetTypes);
-
-        if (select.getColumnCount() != variables.length) {
-            throw Error.error(ErrorCode.X_42564, Tokens.T_INTO);
-        }
-
-        Statement statement = new StatementSet(session, variables, select,
-                                               columnMap, compileContext);
-
-        return statement;
+        return targetTypes;
     }
 
     /**
@@ -289,7 +296,8 @@ public class ParserRoutine extends ParserTable {
 
         exprList.toArray(updateExpressions);
         resolveUpdateExpressions(table, RangeGroup.emptyGroup, columnMap,
-                                 updateExpressions, rangeGroups, null);
+                                 targets, updateExpressions, rangeGroups,
+                                 null);
 
         StatementDMQL cs = new StatementSet(session, targets, table,
                                             rangeGroups[0].getRangeVariables(),
@@ -2429,7 +2437,7 @@ public class ParserRoutine extends ParserTable {
 
             readThis(Tokens.CLOSEBRACKET);
 
-            HsqlList unresolved = condition.resolveColumnReferences(session,
+            List unresolved = condition.resolveColumnReferences(session,
                 rangeGroups[0], rangeGroups, null);
 
             ExpressionColumn.checkColumnsResolved(unresolved);
@@ -2559,7 +2567,7 @@ public class ParserRoutine extends ParserTable {
                 throw Error.error(ErrorCode.X_42505);
             }
         } else {
-            session.getGrantee().checkSchemaUpdateOrGrantRights(schema.name);
+            session.getGrantee().checkSchemaUpdateOrGrantRights(schema);
         }
 
         session.checkDDLWrite();
