@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.HsqlArrayList;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.types.BinaryData;
@@ -46,7 +47,7 @@ import org.hsqldb.types.Types;
  * Parser for SQL table definition
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class ParserTable extends ParserDML {
@@ -78,7 +79,7 @@ public class ParserTable extends ParserDML {
         }
 
         if (token.tokenType == Tokens.AS) {
-            return compileCreateTableAsSubqueryDefinition(table);
+            return compileCreateTableAsSubqueryDefinition(table, ifNot);
         }
 
         return compileCreateTableBody(table, ifNot);
@@ -88,23 +89,60 @@ public class ParserTable extends ParserDML {
 
         HsqlArrayList tempConstraints = new HsqlArrayList();
         HsqlArrayList tempIndexes     = new HsqlArrayList();
+        Statement     statement       = null;
+        HsqlName[]    readLockNames   = null;
         boolean isTable = readTableContentsSource(table, tempConstraints,
             tempIndexes);
 
         if (!isTable) {
-            return compileCreateTableAsSubqueryDefinition(table);
+            return compileCreateTableAsSubqueryDefinition(table, ifNot);
         }
 
         readTableVersioningClause(table);
+
+        if (token.tokenType == Tokens.AS) {
+            read();
+
+            QueryExpression queryExpression = null;
+
+            queryExpression = readTableQuery();
+
+            readThis(Tokens.WITH);
+            readThis(Tokens.DATA);
+
+            statement = new StatementQuery(session, queryExpression,
+                                           compileContext);
+            readLockNames = statement.getTableNamesForRead();
+
+            Type[] dataTypes = queryExpression.getColumnTypes();
+
+            if (table.getColumnCount() != dataTypes.length) {
+                throw Error.error(ErrorCode.X_42593);
+            }
+
+            for (int i = 0; i < dataTypes.length; i++) {
+                boolean b = table.getColumn(i).getDataType().canBeAssignedFrom(
+                    dataTypes[i]);
+
+                if (!b) {
+                    throw Error.error(ErrorCode.X_42561);
+                }
+            }
+        }
+
         readTableOnCommitClause(table);
 
         if (database.sqlSyntaxMys) {
-            if (readIfThis(Tokens.COMMENT)) {
-                readIfThis(Tokens.EQUALS_OP);
+            OrderedHashMap list = super.readPropertyValuePairs(true, false);
 
-                String comment = readQuotedString();
+            if (list != null) {
+                Token value = (Token) list.get(Tokens.T_COMMENT);
 
-                table.getName().comment = comment;
+                if (value != null) {
+                    String comment = value.tokenString;
+
+                    table.getName().comment = comment;
+                }
             }
         }
 
@@ -126,16 +164,17 @@ public class ParserTable extends ParserDML {
             }
         }
 
-        String     sql            = getLastPart();
-        Object[]   args           = new Object[] {
-            table, tempConstraints, tempIndexes, null, Boolean.valueOf(ifNot)
+        String   sql  = getLastPart();
+        Object[] args = new Object[] {
+            table, tempConstraints, tempIndexes, statement,
+            Boolean.valueOf(ifNot)
         };
         HsqlName[] writeLockNames = new HsqlName[names.size()];
 
         names.toArray(writeLockNames);
 
         return new StatementSchema(sql, StatementTypes.CREATE_TABLE, args,
-                                   null, writeLockNames);
+                                   readLockNames, writeLockNames);
     }
 
     boolean readTableContentsSource(Table table,
@@ -170,7 +209,7 @@ public class ParserTable extends ParserDML {
                     start     = false;
                     startPart = false;
 
-                    break;
+                    continue;
                 }
                 case Tokens.CONSTRAINT :
                 case Tokens.PRIMARY :
@@ -185,8 +224,8 @@ public class ParserTable extends ParserDML {
 
                     start     = false;
                     startPart = false;
-                    break;
 
+                    continue;
                 case Tokens.PERIOD :
                     if (!startPart) {
                         throw unexpectedToken();
@@ -196,12 +235,16 @@ public class ParserTable extends ParserDML {
                         throw unexpectedToken();
                     }
 
-                    readAndAddPeriod(table);
+                    PeriodDefinition period = readAndAddPeriod(table);
+
+                    if (period == null) {
+                        break;
+                    }
 
                     start     = false;
                     startPart = false;
-                    break;
 
+                    continue;
                 case Tokens.COMMA :
                     if (startPart) {
                         throw unexpectedToken();
@@ -210,14 +253,14 @@ public class ParserTable extends ParserDML {
                     read();
 
                     startPart = true;
-                    break;
 
+                    continue;
                 case Tokens.CLOSEBRACKET :
                     read();
 
                     end = true;
-                    break;
 
+                    continue;
                 case Tokens.KEY :
                 case Tokens.INDEX :
                     if (database.sqlSyntaxMys) {
@@ -226,56 +269,54 @@ public class ParserTable extends ParserDML {
                         start     = false;
                         startPart = false;
 
-                        break;
-                    }
-                default :
-                    if (!startPart) {
-                        throw unexpectedToken();
+                        continue;
                     }
+            }
 
-                    checkIsSchemaObjectName();
+            if (!startPart) {
+                throw unexpectedToken();
+            }
 
-                    HsqlName hsqlName =
-                        database.nameManager.newColumnHsqlName(table.getName(),
-                            token.tokenString, isDelimitedIdentifier());
+            checkIsSchemaObjectName();
 
-                    read();
+            HsqlName hsqlName =
+                database.nameManager.newColumnHsqlName(table.getName(),
+                    token.tokenString, isDelimitedIdentifier());
 
-                    ColumnSchema newcolumn = readColumnDefinitionOrNull(table,
-                        hsqlName, tempConstraints);
+            read();
 
-                    if (newcolumn == null) {
-                        if (start) {
-                            rewind(position);
+            ColumnSchema newcolumn = readColumnDefinitionOrNull(table,
+                hsqlName, tempConstraints);
 
-                            return false;
-                        } else {
-                            throw Error.error(ErrorCode.X_42000);
-                        }
-                    }
+            if (newcolumn == null) {
+                if (start) {
+                    rewind(position);
 
-                    table.addColumn(newcolumn);
+                    return false;
+                } else {
+                    throw Error.error(ErrorCode.X_42000);
+                }
+            }
 
-                    start     = false;
-                    startPart = false;
+            table.addColumn(newcolumn);
 
-                    if (newcolumn.getSystemPeriodType()
-                            == SchemaObject.PeriodSystemColumnType
-                                .PERIOD_ROW_START) {
-                        if (hasRowStart) {
-                            throw Error.error(ErrorCode.X_42591);
-                        }
+            start     = false;
+            startPart = false;
 
-                        hasRowStart = true;
-                    } else if (newcolumn.getSystemPeriodType()
-                               == SchemaObject.PeriodSystemColumnType
-                                   .PERIOD_ROW_END) {
-                        if (hasRowEnd) {
-                            throw Error.error(ErrorCode.X_42591);
-                        }
+            if (newcolumn.getSystemPeriodType()
+                    == SchemaObject.PeriodSystemColumnType.PERIOD_ROW_START) {
+                if (hasRowStart) {
+                    throw Error.error(ErrorCode.X_42591);
+                }
 
-                        hasRowEnd = true;
-                    }
+                hasRowStart = true;
+            } else if (newcolumn.getSystemPeriodType()
+                       == SchemaObject.PeriodSystemColumnType.PERIOD_ROW_END) {
+                if (hasRowEnd) {
+                    throw Error.error(ErrorCode.X_42591);
+                }
+
+                hasRowEnd = true;
             }
         }
 
@@ -527,25 +568,23 @@ public class ParserTable extends ParserDML {
         return columnList;
     }
 
-    StatementSchema compileCreateTableAsSubqueryDefinition(Table table) {
+    StatementSchema compileCreateTableAsSubqueryDefinition(Table table,
+            boolean ifNotExists) {
 
-        HsqlName[] readName    = null;
-        boolean    withData    = true;
-        HsqlName[] columnNames = null;
-        Statement  statement   = null;
+        HsqlName[]      readName        = null;
+        boolean         withData        = true;
+        HsqlName[]      columnNames     = null;
+        Statement       statement       = null;
+        QueryExpression queryExpression = null;
 
         if (token.tokenType == Tokens.OPENBRACKET) {
             columnNames = readColumnNames(table.getName());
         }
 
         readThis(Tokens.AS);
-        readThis(Tokens.OPENBRACKET);
 
-        QueryExpression queryExpression = XreadQueryExpression();
+        queryExpression = readTableQuery();
 
-        queryExpression.setReturningResult();
-        queryExpression.resolve(session);
-        readThis(Tokens.CLOSEBRACKET);
         readThis(Tokens.WITH);
 
         if (token.tokenType == Tokens.NO) {
@@ -597,8 +636,9 @@ public class ParserTable extends ParserDML {
             readName = statement.getTableNamesForRead();
         }
 
-        Object[]   args           = new Object[] {
-            table, new HsqlArrayList(), null, statement, Boolean.FALSE
+        Object[] args = new Object[] {
+            table, new HsqlArrayList(), new HsqlArrayList(), statement,
+            Boolean.valueOf(ifNotExists)
         };
         String     sql            = getLastPart();
         HsqlName[] writeLockNames = database.schemaManager.catalogNameArray;
@@ -608,6 +648,19 @@ public class ParserTable extends ParserDML {
         return st;
     }
 
+    private QueryExpression readTableQuery() {
+
+        readThis(Tokens.OPENBRACKET);
+
+        QueryExpression queryExpression = XreadQueryExpression();
+
+        queryExpression.setReturningResult();
+        queryExpression.resolve(session);
+        readThis(Tokens.CLOSEBRACKET);
+
+        return queryExpression;
+    }
+
     /**
      * Adds a list of temp constraints to a new table
      */
@@ -982,10 +1035,11 @@ public class ParserTable extends ParserDML {
         Expression generateExpr    = null;
         int sysPeriodType =
             SchemaObject.PeriodSystemColumnType.PERIOD_ROW_NONE;
-        boolean        isNullable  = true;
-        Expression     defaultExpr = null;
-        Type           typeObject  = null;
-        NumberSequence sequence    = null;
+        boolean           isNullable    = true;
+        Expression        defaultExpr   = null;
+        ExpressionLogical colConstraint = null;
+        Type              typeObject    = null;
+        NumberSequence    sequence      = null;
 
         switch (token.tokenType) {
 
@@ -1054,6 +1108,31 @@ public class ParserTable extends ParserDML {
                 }
 
                 typeObject = readTypeDefinition(true, true);
+
+                if (database.sqlSyntaxMys && typeObject.isDomainType()
+                        && typeObject.getName().name.equals(Tokens.T_ENUM)) {
+                    typeObject.userTypeModifier = null;
+
+                    HsqlName constName = database.nameManager.newAutoName("CT",
+                        table.getSchemaName(), table.getName(),
+                        SchemaObject.CONSTRAINT);
+                    Constraint c =
+                        new Constraint(constName, null,
+                                       SchemaObject.ConstraintTypes.CHECK);
+
+                    constraintList.add(c);
+                    readThis(Tokens.OPENBRACKET);
+
+                    Expression left  = new ExpressionColumn(hsqlName.name);
+                    Expression right = super.XreadInValueListConstructor(1);
+
+                    readThis(Tokens.CLOSEBRACKET);
+
+                    colConstraint = new ExpressionLogical(OpTypes.IN, left,
+                                                          right);
+                    colConstraint.noOptimisation = true;
+                    c.check                      = colConstraint;
+                }
             }
         }
 
@@ -1231,29 +1310,8 @@ public class ParserTable extends ParserDML {
         ColumnSchema column = new ColumnSchema(hsqlName, typeObject,
                                                isNullable, false, defaultExpr);
 
-        if (database.sqlSyntaxMys && typeObject.isDomainType()
-                && typeObject.getName().name.equals("ENUM")) {
-            typeObject.userTypeModifier = null;
-
-            HsqlName constName = database.nameManager.newAutoName("CT",
-                table.getSchemaName(), table.getName(),
-                SchemaObject.CONSTRAINT);
-            Constraint c = new Constraint(constName, null,
-                                          SchemaObject.ConstraintTypes.CHECK);
-
-            constraintList.add(c);
-            readThis(Tokens.OPENBRACKET);
-
-            Expression left  = new ExpressionColumn(column);
-            Expression right = super.XreadInValueListConstructor(1);
-
-            readThis(Tokens.CLOSEBRACKET);
-
-            ExpressionLogical in = new ExpressionLogical(OpTypes.IN, left,
-                right);
-
-            in.noOptimisation = true;
-            c.check           = in;
+        if (colConstraint != null) {
+            colConstraint.setLeftNode(new ExpressionColumn(column));
         }
 
         column.setGeneratingExpression(generateExpr);
@@ -1343,23 +1401,37 @@ public class ParserTable extends ParserDML {
      *
      * @param table a table
      */
-    void readAndAddPeriod(Table table) {
+    PeriodDefinition readAndAddPeriod(Table table) {
 
         PeriodDefinition period = readPeriod(table);
 
+        if (period == null) {
+            return null;
+        }
+
         if (period.getPeriodType() == SchemaObject.PeriodType.PERIOD_SYSTEM) {
             table.systemPeriod = period;
         } else {
             table.applicationPeriod = period;
         }
+
+        return period;
     }
 
     PeriodDefinition readPeriod(Table table) {
 
         int      periodType = SchemaObject.PeriodType.PERIOD_NONE;
         HsqlName periodName = null;
+        int      position   = getPosition();
 
         readThis(Tokens.PERIOD);
+
+        if (token.tokenType != Tokens.FOR) {
+            rewind(position);
+
+            return null;
+        }
+
         readThis(Tokens.FOR);
 
         if (token.tokenType == Tokens.SYSTEM_TIME) {
@@ -1368,8 +1440,6 @@ public class ParserTable extends ParserDML {
                 database.nameManager.newHsqlName(table.getName().schema,
                                                  token.tokenString, false,
                                                  SchemaObject.PERIOD);
-
-            read();
         } else {
             periodType = SchemaObject.PeriodType.PERIOD_APPLICATION;
 
@@ -1383,10 +1453,10 @@ public class ParserTable extends ParserDML {
                                                  token.tokenString,
                                                  isDelimitedIdentifier(),
                                                  SchemaObject.PERIOD);
-
-            read();
         }
 
+        read();
+
         periodName.parent = table.getName();
 
         OrderedHashSet set = readColumnNames(false);
@@ -1759,7 +1829,6 @@ public class ParserTable extends ParserDML {
     void readCheckConstraintCondition(Constraint c) {
 
         readThis(Tokens.OPENBRACKET);
-        startRecording();
 
         isCheckOrTriggerCondition = true;
 
@@ -1864,12 +1933,12 @@ public class ParserTable extends ParserDML {
                 case Tokens.TRUE :
                     read();
 
-                    return Expression.EXPR_TRUE;
+                    return new ExpressionBoolean(true);
 
                 case Tokens.FALSE :
                     read();
 
-                    return Expression.EXPR_FALSE;
+                    return new ExpressionBoolean(false);
             }
         } else if (dataType.isBitType()) {
             switch (token.tokenType) {
@@ -1949,7 +2018,7 @@ public class ParserTable extends ParserDML {
         }
 
         if (database.sqlSyntaxOra || database.sqlSyntaxPgs) {
-            e = XreadSimpleValueExpressionPrimary();
+            e = XreadAllTypesCommonValueExpression(false);
 
             if (e != null) {
                 if (e.getType() == OpTypes.ROW_SUBQUERY) {
@@ -2227,10 +2296,7 @@ public class ParserTable extends ParserDML {
         read();
 
         indexHsqlName = readNewSchemaObjectName(SchemaObject.INDEX, true);
-
-        HsqlName tableSchema = table.getSchemaName();
-
-        indexHsqlName.schema = tableSchema;
+        indexHsqlName.schema = table.getSchemaName();
         indexHsqlName.parent = table.getName();
         indexHsqlName.schema = table.getSchemaName();
 
