@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,8 +38,8 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayListIdentity;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.lib.Set;
@@ -56,16 +56,9 @@ import org.hsqldb.types.Types;
  * Implementation of an SQL query expression
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
-
-/**
- * @todo 1.9.0 - review these
- * - work out usage of getMainSelect etc and add relevant methods
- * - Result metadata for the final result of QueryExpression
- *
- */
 public class QueryExpression implements RangeGroup {
 
     public static final int NOUNION       = 0,
@@ -78,19 +71,19 @@ public class QueryExpression implements RangeGroup {
                             UNION_TERM    = 7;
 
     //
-    int                     columnCount;
-    private QueryExpression leftQueryExpression;
-    private QueryExpression rightQueryExpression;
-    SortAndSlice            sortAndSlice;
-    private int             unionType;
-    private boolean         unionCorresponding;
-    private OrderedHashSet  unionCorrespondingColumns;
-    int[]                   unionColumnMap;
-    Type[]                  unionColumnTypes;
-    boolean                 isFullOrder;
+    int                    columnCount;
+    QueryExpression        leftQueryExpression;
+    QueryExpression        rightQueryExpression;
+    public SortAndSlice    sortAndSlice;
+    private int            unionType;
+    private boolean        unionCorresponding;
+    private OrderedHashSet unionCorrespondingColumns;
+    int[]                  unionColumnMap;
+    Type[]                 unionColumnTypes;
+    boolean                isFullOrder;
 
     //
-    HsqlList unresolvedExpressions;
+    List unresolvedExpressions;
 
     //
     boolean isReferencesResolved;
@@ -106,30 +99,32 @@ public class QueryExpression implements RangeGroup {
     boolean[]      accessibleColumns;
 
     //
-    View    view;
-    boolean isBaseMergeable;
-    boolean isMergeable;
-    boolean isUpdatable;
-    boolean isInsertable;
-    boolean isCheckable;
-    boolean isTopLevel;
-    boolean isRecursive;
-    boolean isSingleRow;
-    boolean acceptsSequences;
-    boolean isCorrelated;
-    boolean isTable;
-    boolean isValueList;
-
-    //
-    TableDerived recursiveTable;
-
-    //
+    View             view;
+    boolean          isBaseMergeable;
+    boolean          isMergeable;
+    boolean          isUpdatable;
+    boolean          isInsertable;
+    boolean          isCheckable;
+    boolean          isTopLevel;
+    boolean          isRecursive;
+    boolean          isSingleRow;
+    boolean          acceptsSequences;
+    boolean          isCorrelated;
+    boolean          isTable;
+    boolean          isValueList;
+    boolean          lowerCaseResultIdentifier;
     public TableBase resultTable;
     public Index     mainIndex;
     public Index     fullIndex;
     public Index     orderIndex;
     public Index     idIndex;
 
+    //
+    TableDerived           recursiveWorkTable;
+    TableDerived           recursiveResultTable;
+    RecursiveQuerySettings recursiveSettings;
+    TableDerived[]         materialiseList = TableDerived.emptyArray;
+
     //
     CompileContext compileContext;
 
@@ -370,7 +365,7 @@ public class QueryExpression implements RangeGroup {
                     int index = ((Integer) e.getValue(null)).intValue();
 
                     if (0 < index && index <= unionColumnNames.length) {
-                        sort.getLeftNode().queryTableColumnIndex = index - 1;
+                        sort.getLeftNode().resultTableColumnIndex = index - 1;
 
                         continue;
                     }
@@ -380,7 +375,7 @@ public class QueryExpression implements RangeGroup {
                                            e.getColumnName());
 
                 if (index >= 0) {
-                    sort.getLeftNode().queryTableColumnIndex = index;
+                    sort.getLeftNode().resultTableColumnIndex = index;
 
                     continue;
                 }
@@ -392,7 +387,7 @@ public class QueryExpression implements RangeGroup {
         sortAndSlice.prepare(0);
     }
 
-    private void addUnresolvedExpressions(HsqlList expressions) {
+    private void addUnresolvedExpressions(List expressions) {
 
         if (expressions == null) {
             return;
@@ -457,14 +452,14 @@ public class QueryExpression implements RangeGroup {
         if (isRecursive) {
             leftQueryExpression.resolveTypesPartTwoRecursive(session);
 
-            recursiveTable.colTypes = leftQueryExpression.getColumnTypes();
+            recursiveWorkTable.colTypes = leftQueryExpression.getColumnTypes();
 
-            for (int i = 0; i < recursiveTable.colTypes.length; i++) {
-                recursiveTable.getColumn(i).setType(
-                    recursiveTable.colTypes[i]);
+            for (int i = 0; i < recursiveWorkTable.colTypes.length; i++) {
+                recursiveWorkTable.getColumn(i).setType(
+                    recursiveWorkTable.colTypes[i]);
             }
 
-            recursiveTable.getFullIndex(session);
+            recursiveWorkTable.getFullIndex(session);
         } else {
             leftQueryExpression.resolveTypesPartTwo(session);
         }
@@ -532,13 +527,8 @@ public class QueryExpression implements RangeGroup {
     }
 
     void resolveTypesPartThree(Session session) {
-
         compileContext = null;
         isResolved     = true;
-
-        if (isRecursive) {
-            recursiveTable.queryExpression.isCorrelated = false;
-        }
     }
 
     public Object[] getValues(Session session) {
@@ -658,6 +648,8 @@ public class QueryExpression implements RangeGroup {
                 throw Error.runtimeError(ErrorCode.U_S0500, "QueryExpression");
         }
 
+        rightNavigator.release();
+
         if (sortAndSlice.hasOrder()) {
             navigator.sortOrderUnion(sortAndSlice);
         }
@@ -673,19 +665,72 @@ public class QueryExpression implements RangeGroup {
         return first;
     }
 
+    public void setRecursiveQuerySettings(RecursiveQuerySettings settings) {
+
+        OrderedHashSet subqueryList = rightQueryExpression.getSubqueries();
+        OrderedHashSet refList      = new OrderedHashSet();
+
+        if (subqueryList == null) {
+            subqueryList = new OrderedHashSet();
+        }
+
+        for (int i = 0; i < subqueryList.size(); i++) {
+            TableDerived td = (TableDerived) subqueryList.get(i);
+
+            if (td.isCorrelated()) {
+                continue;
+            }
+
+            QueryExpression qe = td.queryExpression;
+
+            if (qe == null) {
+                continue;
+            }
+
+            refList = qe.collectRangeVariables(refList);
+
+            for (int j = 0; j < refList.size(); j++) {
+                RangeVariable range = (RangeVariable) refList.get(j);
+
+                if (range.rangeTable == recursiveWorkTable
+                        || range.rangeTable == recursiveResultTable) {
+                    materialiseList =
+                        ArrayUtil.toAdjustedArray(materialiseList, td);
+
+                    break;
+                }
+            }
+        }
+
+        recursiveSettings = settings;
+    }
+
     Result getResultRecursive(Session session) {
 
         RowSetNavigatorData resultNav = new RowSetNavigatorData(session, this);
+        Result leftResult = leftQueryExpression.getResult(session, 0);
+        PersistentStore recursiveStore =
+            recursiveWorkTable.getRowStore(session);
+        PersistentStore recursiveResultStore =
+            recursiveResultTable.getRowStore(session);
 
-        recursiveTable.materialise(session);
-        resultNav.unionAll(recursiveTable.getNavigator(session));
+        leftResult.getNavigator().reset();
+        recursiveWorkTable.insertSys(session, recursiveStore, leftResult);
+        leftResult.getNavigator().reset();
+        recursiveResultTable.insertSys(session, recursiveResultStore,
+                                       leftResult);
+        resultNav.unionAll((RowSetNavigatorData) leftResult.getNavigator());
 
         for (int round = 0; ; round++) {
+            for (int i = 0; i < materialiseList.length; i++) {
+                materialiseList[i].materialise(session);
+            }
+
             Result currentResult = rightQueryExpression.getResult(session, 0);
-            RowSetNavigatorData tempNavigator =
+            RowSetNavigatorData currentNavigator =
                 (RowSetNavigatorData) currentResult.getNavigator();
 
-            if (tempNavigator.isEmpty()) {
+            if (currentNavigator.isEmpty()) {
                 break;
             }
 
@@ -694,11 +739,11 @@ public class QueryExpression implements RangeGroup {
             switch (unionType) {
 
                 case UNION :
-                    resultNav.union(tempNavigator);
+                    resultNav.union(currentNavigator);
                     break;
 
                 case UNION_ALL :
-                    resultNav.unionAll(tempNavigator);
+                    resultNav.unionAll(currentNavigator);
                     break;
 
                 default :
@@ -714,11 +759,13 @@ public class QueryExpression implements RangeGroup {
                 throw Error.error(ErrorCode.X_22522);
             }
 
-            PersistentStore store = recursiveTable.getRowStore(session);
-
-            store.removeAll();
-            currentResult.getNavigator().reset();
-            recursiveTable.insertSys(session, store, currentResult);
+            currentNavigator.reset();
+            recursiveResultTable.insertSys(session, recursiveResultStore,
+                                           currentResult);
+            recursiveStore.removeAll();
+            currentNavigator.reset();
+            recursiveWorkTable.insertSys(session, recursiveStore,
+                                         currentResult);
         }
 
         Result result = Result.newResult(resultNav);
@@ -761,7 +808,7 @@ public class QueryExpression implements RangeGroup {
         return leftQueryExpression.getMainSelect();
     }
 
-    /** @todo 1.9.0 review */
+    /* @todo regular review */
     public String describe(Session session, int blanks) {
 
         StringBuilder sb;
@@ -816,7 +863,7 @@ public class QueryExpression implements RangeGroup {
         return sb.toString();
     }
 
-    public HsqlList getUnresolvedExpressions() {
+    public List getUnresolvedExpressions() {
         return unresolvedExpressions;
     }
 
@@ -920,7 +967,7 @@ public class QueryExpression implements RangeGroup {
         }
     }
 
-    public HashMappedList getColumns() {
+    public OrderedHashMap getColumns() {
 
         TableDerived table = (TableDerived) getResultTable();
 
@@ -941,7 +988,7 @@ public class QueryExpression implements RangeGroup {
     /**
      * Used in views after full type resolution
      */
-    public void setTableColumnNames(HashMappedList list) {
+    public void setTableColumnNames(OrderedHashMap list) {
 
         if (resultTable != null) {
             ((TableDerived) resultTable).columnList = list;
@@ -974,7 +1021,7 @@ public class QueryExpression implements RangeGroup {
     void createResultTable(Session session) {
 
         HsqlName       tableName;
-        HashMappedList columnList;
+        OrderedHashMap columnList;
         int            tableType;
 
         tableName = session.database.nameManager.getSubqueryTableName();
@@ -1023,16 +1070,16 @@ public class QueryExpression implements RangeGroup {
         leftQueryExpression.setReturningResultSet();
     }
 
-    private HashMappedList getUnionColumns() {
+    private OrderedHashMap getUnionColumns() {
 
         if (unionCorresponding || leftQueryExpression == null) {
-            HashMappedList columns = ((TableDerived) resultTable).columnList;
-            HashMappedList list    = new HashMappedList();
+            OrderedHashMap columns = ((TableDerived) resultTable).columnList;
+            OrderedHashMap list    = new OrderedHashMap();
 
             for (int i = 0; i < unionColumnMap.length; i++) {
                 ColumnSchema column =
                     (ColumnSchema) columns.get(unionColumnMap[i]);
-                String name = (String) columns.getKey(unionColumnMap[i]);
+                String name = (String) columns.getKeyAt(unionColumnMap[i]);
 
                 list.add(name, column);
             }
@@ -1049,7 +1096,7 @@ public class QueryExpression implements RangeGroup {
             return leftQueryExpression.getResultColumnNames();
         }
 
-        HashMappedList list = ((TableDerived) resultTable).columnList;
+        OrderedHashMap list = ((TableDerived) resultTable).columnList;
         HsqlName[]     resultColumnNames = new HsqlName[list.size()];
 
         for (int i = 0; i < resultColumnNames.length; i++) {
@@ -1146,4 +1193,26 @@ public class QueryExpression implements RangeGroup {
     }
 
     public void setAsExists() {}
+
+    public void setLowerCaseResultIdentifer() {
+        lowerCaseResultIdentifier = true;
+    }
+
+    static class RecursiveQuerySettings {
+
+        static final int none         = 0;
+        static final int depthFirst   = 1;
+        static final int breadthFirst = 2;
+        static final int findCycle    = 1;
+        int              searchOrderType;
+        SortAndSlice     searchOrderSort;
+        ColumnSchema     searchOrderSetColumn;
+        int              cycle;
+        int[]            cycleColumnList;
+        ColumnSchema     cycleColumnFirst;
+        ColumnSchema     cycleMarkColumn;
+        String           cycleMarkValue;
+        String           noCycleMarkValue;
+        ColumnSchema     cyclePathColumn;
+    }
 }
