@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,8 @@
 
 package org.hsqldb;
 
+import java.util.Locale;
+
 import org.hsqldb.HsqlNameManager.HsqlName;
 import org.hsqldb.HsqlNameManager.SimpleName;
 import org.hsqldb.ParserDQL.CompileContext;
@@ -40,12 +42,12 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayListIdentity;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HashSet;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
 import org.hsqldb.lib.IntValueHashMap;
 import org.hsqldb.lib.Iterator;
+import org.hsqldb.lib.List;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.lib.Set;
@@ -65,7 +67,7 @@ import org.hsqldb.types.Types;
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  *
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class QuerySpecification extends QueryExpression {
@@ -509,7 +511,7 @@ public class QuerySpecification extends QueryExpression {
 
         checkLobUsage();
         setMergeability();
-        setUpdatability();
+        setUpdatability(session);
         setResultColumnTypes();
         createResultMetaData(session);
         createTable(session);
@@ -591,7 +593,7 @@ public class QuerySpecification extends QueryExpression {
                                                rangeGroups, acceptsSequences);
 
             if (!isGrouped && !isDistinctSelect) {
-                HsqlList list = exprColumns[i].collectAllSubqueries(null);
+                List list = exprColumns[i].collectAllSubqueries(null);
 
                 if (list != null) {
                     isMergeable = false;
@@ -632,7 +634,7 @@ public class QuerySpecification extends QueryExpression {
 
             replaceColumnIndexInOrderBy(e);
 
-            if (e.getLeftNode().queryTableColumnIndex != -1) {
+            if (e.getLeftNode().resultTableColumnIndex != -1) {
                 continue;
             }
 
@@ -746,8 +748,8 @@ public class QuerySpecification extends QueryExpression {
             return;
         }
 
-        HsqlList list = expression.resolveColumnReferences(session, this,
-            count, rangeGroups, null, withSequences);
+        List list = expression.resolveColumnReferences(session, this, count,
+            rangeGroups, null, withSequences);
 
         if (list != null) {
             for (int i = 0; i < list.size(); i++) {
@@ -756,7 +758,7 @@ public class QuerySpecification extends QueryExpression {
 
                 if (e.isSelfAggregate()) {
                     for (int j = 0; j < e.nodes.length; j++) {
-                        HsqlList colList = e.nodes[j].resolveColumnReferences(
+                        List colList = e.nodes[j].resolveColumnReferences(
                             session, this, count, RangeGroup.emptyArray, null,
                             false);
 
@@ -839,7 +841,7 @@ public class QuerySpecification extends QueryExpression {
 
         for (int i = rangeVariableList.size() - 1; i >= 0; i--) {
             RangeVariable  range = (RangeVariable) rangeVariableList.get(i);
-            HashMappedList columnList = range.rangeTable.columnList;
+            OrderedHashMap columnList = range.rangeTable.columnList;
 
             for (int j = 0; j < columnList.size(); j++) {
                 ColumnSchema column       = (ColumnSchema) columnList.get(j);
@@ -929,7 +931,7 @@ public class QuerySpecification extends QueryExpression {
         for (int i = 0; i < indexLimitVisible; i++) {
             Expression e = (Expression) exprColumnList.get(i);
 
-            e.queryTableColumnIndex = i;
+            e.resultTableColumnIndex = i;
         }
 
         indexLimitRowId   = indexLimitVisible;
@@ -992,6 +994,10 @@ public class QuerySpecification extends QueryExpression {
             set = queryCondition.collectRangeVariables(rangeVars, set);
         }
 
+        for (int i = 0; i < rangeVariables.length; i++) {
+            set = rangeVariables[i].collectRangeVariables(rangeVars, set);
+        }
+
         return set;
     }
 
@@ -1385,7 +1391,7 @@ public class QuerySpecification extends QueryExpression {
             for (int i = 0; i < orderCount; i++) {
                 Expression e = (Expression) sortAndSlice.exprList.get(i);
 
-                if (e.queryTableColumnIndex != -1) {
+                if (e.resultTableColumnIndex != -1) {
                     continue;
                 }
 
@@ -1402,7 +1408,7 @@ public class QuerySpecification extends QueryExpression {
             for (int i = 0; i < orderCount; i++) {
                 Expression e = (Expression) sortAndSlice.exprList.get(i);
 
-                if (e.queryTableColumnIndex != -1) {
+                if (e.resultTableColumnIndex != -1) {
                     continue;
                 }
 
@@ -1514,7 +1520,7 @@ public class QuerySpecification extends QueryExpression {
         }
     }
 
-    boolean resolveForGroupBy(HsqlList unresolvedSet) {
+    boolean resolveForGroupBy(List unresolvedSet) {
 
         for (int i = indexLimitVisible;
                 i < indexLimitVisible + groupByColumnCount; i++) {
@@ -1550,31 +1556,31 @@ public class QuerySpecification extends QueryExpression {
     /**
      * Returns the result of executing this Select.
      *
-     * @param maxrows may be 0 to indicate no limit on the number of rows.
+     * @param maxRows may be 0 to indicate no limit on the number of rows.
      * Positive values limit the size of the result set.
      * @return the result of executing this Select
      */
-    Result getResult(Session session, int maxrows) {
-
-//todo single row
-        Result r = getSingleResult(session, maxrows);
-
-        r.getNavigator().reset();
-
-        return r;
-    }
-
-    private Result getSingleResult(Session session, int maxRows) {
+    Result getResult(Session session, int maxRows) {
 
+        RowSetNavigatorData navigator = new RowSetNavigatorData(session, this);
         int[] limits = sortAndSlice.getLimits(session, this, maxRows);
-        Result              r         = buildResult(session, limits);
-        RowSetNavigatorData navigator = (RowSetNavigatorData) r.getNavigator();
+        int                 skipCount  = 0;
+        int                 limitCount = limits[2];
+
+        if (sortAndSlice.skipFullResult) {
+            skipCount  = limits[0];
+            limitCount = limits[1];
+        }
+
+        Result r = buildResult(session, navigator, skipCount, limitCount);
+
+        navigator = (RowSetNavigatorData) r.getNavigator();
 
         if (isDistinctSelect) {
             navigator.removeDuplicates();
         }
 
-        if (sortAndSlice.hasOrder()) {
+        if (sortAndSlice.hasOrder() && !sortAndSlice.skipSort) {
             navigator.sortOrder();
         }
 
@@ -1583,14 +1589,16 @@ public class QuerySpecification extends QueryExpression {
             navigator.trim(limits[0], limits[1]);
         }
 
+        r.getNavigator().reset();
+
         return r;
     }
 
-    private Result buildResult(Session session, int[] limits) {
+    private Result buildResult(Session session, RowSetNavigatorData navigator,
+                               int skipCount, int limitCount) {
 
-        RowSetNavigatorData navigator = new RowSetNavigatorData(session, this);
-        Result              result        = Result.newResult(navigator);
-        boolean             resultGrouped = isGrouped && !isSimpleDistinct;
+        Result  result          = Result.newResult(navigator);
+        boolean isResultGrouped = isGrouped && !isSimpleDistinct;
 
         result.metaData = resultMetaData;
 
@@ -1598,42 +1606,24 @@ public class QuerySpecification extends QueryExpression {
             result.rsProperties = ResultProperties.updatablePropsValue;
         }
 
-        int skipCount  = 0;
-        int limitCount = limits[2];
-
-        if (sortAndSlice.skipFullResult) {
-            skipCount  = limits[0];
-            limitCount = limits[1];
-        }
-
-        if (this.isSimpleCount) {
-            Object[] data  = new Object[indexLimitData];
-            Table    table = rangeVariables[0].getTable();
-
-            table.materialise(session);
-
-            PersistentStore store = table.getRowStore(session);
-            long            count = store.elementCount(session);
-
-            data[indexStartAggregates] = ValuePool.getLong(count);
-
-            navigator.add(data);
-            navigator.reset();
-            session.sessionContext.setRangeIterator(navigator);
-
-            if (navigator.next()) {
-                data = navigator.getCurrent();
-
-                for (int i = 0; i < indexStartAggregates; i++) {
-                    data[i] = exprColumns[i].getValue(session);
-                }
-            }
-
-            session.sessionContext.unsetRangeIterator(navigator);
+        if (isSimpleCount) {
+            getSimpleCountResult(session, navigator);
 
             return result;
         }
 
+        if (limitCount == 0) {
+            return result;
+        }
+
+        if (isGroupingSets) {
+            session.sessionContext.setGroup(null);
+        }
+
+        int memoryRowLimit =
+            (!isAggregated && !isSingleMemoryTable && !isGroupingSets)
+            ? session.resultMaxMemoryRows
+            : 0;
         int fullJoinIndex = 0;
         RangeIterator[] rangeIterators =
             new RangeIterator[rangeVariables.length];
@@ -1686,10 +1676,6 @@ public class QuerySpecification extends QueryExpression {
                 continue;
             }
 
-            if (limitCount == 0) {
-                break;
-            }
-
             session.sessionData.startRowProcessing();
 
             Object[] data  = new Object[indexLimitData];
@@ -1728,7 +1714,7 @@ public class QuerySpecification extends QueryExpression {
 
             Object[] groupData = null;
 
-            if (isAggregated || resultGrouped) {
+            if (isAggregated || isResultGrouped) {
                 groupData = navigator.getGroupData(data);
 
                 if (groupData != null) {
@@ -1758,15 +1744,16 @@ public class QuerySpecification extends QueryExpression {
 
             int rowCount = navigator.getSize();
 
-            if (rowCount == session.resultMaxMemoryRows && !isAggregated
-                    && !isSingleMemoryTable && !isGroupingSets) {
+            if (rowCount == memoryRowLimit) {
                 navigator = new RowSetNavigatorDataTable(session, this,
                         navigator);
 
                 result.setNavigator(navigator);
+
+                memoryRowLimit = 0;
             }
 
-            if (isAggregated || resultGrouped) {
+            if (isAggregated || isResultGrouped) {
                 if (!sortAndSlice.isGenerated) {
                     continue;
                 }
@@ -1843,7 +1830,7 @@ public class QuerySpecification extends QueryExpression {
             while (groupsIterator.hasNext()) {
                 navigator.resetRowMap();
 
-                HsqlList set = (HsqlList) groupsIterator.next();
+                List set = (List) groupsIterator.next();
 
                 session.sessionContext.setGroup(set);
 
@@ -1887,7 +1874,7 @@ public class QuerySpecification extends QueryExpression {
         navigator.reset();
 
         if (isAggregated) {
-            if (!resultGrouped && navigator.getSize() == 0) {
+            if (!isResultGrouped && navigator.getSize() == 0) {
                 Object[] data = new Object[exprColumns.length];
 
                 for (int i = 0; i < indexStartAggregates; i++) {
@@ -1943,6 +1930,34 @@ public class QuerySpecification extends QueryExpression {
         return result;
     }
 
+    private void getSimpleCountResult(Session session,
+                                      RowSetNavigatorData navigator) {
+
+        Object[] data  = new Object[indexLimitData];
+        Table    table = rangeVariables[0].getTable();
+
+        table.materialise(session);
+
+        PersistentStore store = table.getRowStore(session);
+        long            count = store.elementCount(session);
+
+        data[indexStartAggregates] = ValuePool.getLong(count);
+
+        navigator.add(data);
+        navigator.reset();
+        session.sessionContext.setRangeIterator(navigator);
+
+        if (navigator.next()) {
+            data = navigator.getCurrent();
+
+            for (int i = 0; i < indexStartAggregates; i++) {
+                data[i] = exprColumns[i].getValue(session);
+            }
+        }
+
+        session.sessionContext.unsetRangeIterator(navigator);
+    }
+
     void setReferenceableColumns() {
 
         accessibleColumns = new boolean[indexLimitVisible];
@@ -1953,7 +1968,7 @@ public class QuerySpecification extends QueryExpression {
             Expression expression = exprColumns[i];
             String     alias      = expression.getAlias();
 
-            if (alias.length() == 0) {
+            if (alias.isEmpty()) {
                 SimpleName name = HsqlNameManager.getAutoColumnName(i);
 
                 expression.setAlias(name);
@@ -2000,14 +2015,25 @@ public class QuerySpecification extends QueryExpression {
             if (tableColumn == null) {
                 column = new ColumnBase();
             } else {
-                column = new ColumnBase(session.database.getCatalogName().name,
-                                        tableColumn);
+                column = new ColumnBase(session.database.getCatalogName(),
+                                        tableColumn,
+                                        lowerCaseResultIdentifier);
             }
 
             column.setType(e.getDataType());
 
+            SimpleName alias    = e.getSimpleName();
+            String     colLabel = alias == null ? ""
+                                                : alias.name;
+
+            if (lowerCaseResultIdentifier) {
+                if (!alias.isNameQuoted) {
+                    colLabel = colLabel.toLowerCase(Locale.ENGLISH);
+                }
+            }
+
             resultMetaData.columns[i]      = column;
-            resultMetaData.columnLabels[i] = e.getAlias();
+            resultMetaData.columnLabels[i] = colLabel;
         }
     }
 
@@ -2118,7 +2144,7 @@ public class QuerySpecification extends QueryExpression {
         int tableType = persistenceScope == TableBase.SCOPE_STATEMENT
                         ? TableBase.SYSTEM_SUBQUERY
                         : TableBase.RESULT_TABLE;
-        HashMappedList columnList = new HashMappedList();
+        OrderedHashMap columnList = new OrderedHashMap();
 
         for (int i = 0; i < indexLimitVisible; i++) {
             Expression e          = exprColumns[i];
@@ -2364,7 +2390,7 @@ public class QuerySpecification extends QueryExpression {
         }
     }
 
-    void setUpdatability() {
+    void setUpdatability(Session session) {
 
         if (!isUpdatable) {
             return;
@@ -2385,7 +2411,9 @@ public class QuerySpecification extends QueryExpression {
         }
 
         if (sortAndSlice.hasLimit() || sortAndSlice.hasOrder()) {
-            return;
+            if (!session.database.sqlSyntaxDb2) {
+                return;
+            }
         }
 
         RangeVariable rangeVar  = rangeVariables[0];
