@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,13 +43,13 @@ import org.hsqldb.types.Type;
  * Implementation of ORDER BY and LIMIT properties of query expressions.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public final class SortAndSlice {
 
-    static final SortAndSlice noSort        = new SortAndSlice();
-    static final int[]        defaultLimits = new int[] {
+    public static final SortAndSlice noSort        = new SortAndSlice();
+    static final int[]               defaultLimits = new int[] {
         0, Integer.MAX_VALUE, Integer.MAX_VALUE
     };
 
@@ -58,15 +58,16 @@ public final class SortAndSlice {
     public boolean[]   sortDescending;
     public boolean[]   sortNullsLast;
     public Collation[] collations;
+    boolean            hasCollation;
     boolean            sortUnion;
     HsqlArrayList      exprList = new HsqlArrayList();
     ExpressionOp       limitCondition;
     public int         columnCount;
     boolean            hasNullsLast;
-    boolean            strictLimit;
-    boolean            zeroLimit;
+    boolean            noZeroLimit;
+    boolean            zeroLimitIsZero;
     boolean            usingIndex;
-    boolean            allDescending;
+    boolean            descendingSort;
     public boolean     skipSort       = false;    // true when result can be used as is
     public boolean     skipFullResult = false;    // true when result can be sliced as is
     public Index   index;
@@ -102,11 +103,11 @@ public final class SortAndSlice {
     }
 
     public void setStrictLimit() {
-        strictLimit = true;
+        noZeroLimit = true;
     }
 
-    public void setZeroLimit() {
-        zeroLimit = true;
+    public void setZeroLimitIsZero() {
+        zeroLimitIsZero = true;
     }
 
     public void setUsingIndex() {
@@ -168,26 +169,25 @@ public final class SortAndSlice {
         sortOrder      = new int[columnCount];
         sortDescending = new boolean[columnCount];
         sortNullsLast  = new boolean[columnCount];
+        collations     = new Collation[columnCount];
 
         for (int i = 0; i < columnCount; i++) {
             ExpressionOrderBy sort = (ExpressionOrderBy) exprList.get(i);
+            int colIndex           = sort.getLeftNode().resultTableColumnIndex;
 
-            if (sort.getLeftNode().queryTableColumnIndex == -1) {
+            if (colIndex == -1) {
                 sortOrder[i] = startColumn + i;
             } else {
-                sortOrder[i] = sort.getLeftNode().queryTableColumnIndex;
+                sortOrder[i] = colIndex;
             }
 
             sortDescending[i] = sort.isDescending();
             sortNullsLast[i]  = sort.isNullsLast();
+            collations[i]     = sort.collation;
             hasNullsLast      |= sortNullsLast[i];
 
             if (sort.collation != null) {
-                if (collations == null) {
-                    collations = new Collation[columnCount];
-                }
-
-                collations[i] = sort.collation;
+                hasCollation = true;
             }
         }
     }
@@ -206,7 +206,7 @@ public final class SortAndSlice {
             ExpressionOrderBy sort     = (ExpressionOrderBy) exprList.get(i);
             Type              dataType = sort.getLeftNode().getDataType();
 
-            if (dataType.isArrayType() || dataType.isLobType()) {
+            if (dataType.isLobType()) {
                 throw Error.error(ErrorCode.X_42534);
             }
         }
@@ -232,7 +232,7 @@ public final class SortAndSlice {
             return;
         }
 
-        if (collations != null) {
+        if (hasCollation) {
             return;
         }
 
@@ -265,9 +265,9 @@ public final class SortAndSlice {
 
         int count = ArrayUtil.countTrueElements(sortDescending);
 
-        allDescending = count == columnCount;
+        descendingSort = count == columnCount;
 
-        if (!allDescending && count > 0) {
+        if (!descendingSort && count > 0) {
             return;
         }
 
@@ -304,7 +304,7 @@ public final class SortAndSlice {
         }
 
         if (rangeIndex == primaryTableIndex) {
-            if (allDescending) {
+            if (descendingSort) {
                 boolean reversed = select.rangeVariables[0].reverseOrder();
 
                 if (!reversed) {
@@ -317,7 +317,7 @@ public final class SortAndSlice {
         } else if (!select.rangeVariables[0].joinConditions[0]
                 .hasIndexCondition()) {
             if (select.rangeVariables[0].setSortIndex(primaryTableIndex,
-                    allDescending)) {
+                    descendingSort)) {
                 skipSort       = true;
                 skipFullResult = true;
             }
@@ -417,11 +417,11 @@ public final class SortAndSlice {
                     (Integer) limitCondition.getRightNode().getValue(session);
 
                 if (value == null || value.intValue() < 0
-                        || (strictLimit && value.intValue() == 0)) {
+                        || (noZeroLimit && value.intValue() == 0)) {
                     throw Error.error(ErrorCode.X_2201W);
                 }
 
-                if (value.intValue() == 0 && !zeroLimit) {
+                if (value.intValue() == 0 && !zeroLimitIsZero) {
                     limitRows = Integer.MAX_VALUE;
                 } else {
                     limitRows = value.intValue();
@@ -478,7 +478,7 @@ public final class SortAndSlice {
             Index orderIndex = table.createAndAddIndexStructure(session, null,
                 sortOrder, sortDescending, sortNullsLast, false, false, false);
 
-            if (collations != null) {
+            if (hasCollation) {
                 for (int i = 0; i < columnCount; i++) {
                     if (collations[i] != null) {
                         Type type = orderIndex.getColumnTypes()[i];
