@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,14 +36,15 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.index.IndexAVLCheck;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.Iterator;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.persist.DataFileCache;
 import org.hsqldb.persist.DataSpaceManager;
 import org.hsqldb.persist.HsqlDatabaseProperties;
 import org.hsqldb.persist.HsqlProperties;
 import org.hsqldb.persist.PersistentStore;
+import org.hsqldb.persist.RowStoreAVLDisk;
 import org.hsqldb.persist.ScriptLoader;
 import org.hsqldb.persist.TableSpaceManager;
 import org.hsqldb.result.Result;
@@ -52,13 +53,13 @@ import org.hsqldb.rights.User;
 import org.hsqldb.scriptio.ScriptWriterText;
 import org.hsqldb.scriptio.ScriptWriterTextColumnNames;
 import org.hsqldb.types.TimestampData;
-import org.hsqldb.persist.RowStoreAVLDisk;
+import org.hsqldb.types.Type;
 
 /**
  * Implementation of Statement for SQL commands.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class StatementCommand extends Statement {
@@ -301,8 +302,13 @@ public class StatementCommand extends Statement {
                         name, set);
                 }
 
-                Result result = Result.newDoubleColumnResult("OBJCT_TYPE",
-                    "OBJECT_NAME");
+                String[] names  = new String[] {
+                    "OBJCT_TYPE", "OBJECT_NAME"
+                };
+                Type[]   types  = new Type[] {
+                    Type.SQL_VARCHAR_DEFAULT, Type.SQL_VARCHAR_DEFAULT
+                };
+                Result   result = Result.newMultiColumnResult(names, types);
 
                 for (int i = 0; i < set.size(); i++) {
                     HsqlName current = (HsqlName) set.get(i);
@@ -691,7 +697,7 @@ public class StatementCommand extends Statement {
                     boolean padSpaces =
                         ((Boolean) arguments[1]).booleanValue();
 
-                    /** @todo 1.9.0 - ensure no data in character columns */
+                    /* @todo 1.9.0 - ensure no data in character columns */
                     session.checkAdmin();
                     session.checkDDLWrite();
                     session.database.collation.setCollation(name, padSpaces);
@@ -797,6 +803,9 @@ public class StatementCommand extends Statement {
                 } else if (HsqlDatabaseProperties.sql_sys_index_names.equals(
                         property)) {
                     session.database.setSysIndexNames(mode);
+                } else if (HsqlDatabaseProperties.sql_lowercase_ident.equals(
+                        property)) {
+                    session.database.setLowerCaseIndentifer(mode);
                 }
 
                 return Result.updateZeroResult;
@@ -961,7 +970,9 @@ public class StatementCommand extends Statement {
                 TimestampData    timestamp = (TimestampData) arguments[5];
 
                 try {
-                    session.checkAdmin();
+                    if (!session.getGrantee().canPerformScriptOps()) {
+                        throw Error.error(ErrorCode.X_42507);
+                    }
 
                     if (name == null) {
                         return session.database.getScript(false);
@@ -1028,6 +1039,10 @@ public class StatementCommand extends Statement {
                     int     mode         = ((Integer) arguments[1]).intValue();
                     Boolean isVersioning = (Boolean) arguments[2];
 
+                    if (!session.getGrantee().canPerformScriptOps()) {
+                        throw Error.error(ErrorCode.X_42507);
+                    }
+
                     return ScriptLoader.loadScriptData(
                         session, pathName, mode, isVersioning.booleanValue());
                 } catch (HsqlException e) {
@@ -1045,7 +1060,7 @@ public class StatementCommand extends Statement {
                         result = IndexAVLCheck.checkAllTables(session, type);
                     } else {
                         table = session.database.schemaManager.getUserTable(
-                            tableName.name, tableName.schema.name);
+                            tableName);
                         result = IndexAVLCheck.checkTable(session, table,
                                                           type);
                     }
@@ -1059,8 +1074,7 @@ public class StatementCommand extends Statement {
                 try {
                     HsqlName name = (HsqlName) arguments[0];
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
 
                     session.checkAdmin();
                     session.checkDDLWrite();
@@ -1096,6 +1110,10 @@ public class StatementCommand extends Statement {
                         return Result.updateZeroResult;
                     }
 
+                    if (!dataSpace.isMultiSpace()) {
+                        return Result.updateZeroResult;
+                    }
+
                     RowStoreAVLDisk store =
                         (RowStoreAVLDisk) table.getRowStore(session);
 
@@ -1111,8 +1129,7 @@ public class StatementCommand extends Statement {
                     HsqlName name    = (HsqlName) arguments[0];
                     int      spaceid = ((Integer) arguments[1]).intValue();
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
 
                     if (!session.isProcessingScript()) {
                         return Result.updateZeroResult;
@@ -1152,8 +1169,7 @@ public class StatementCommand extends Statement {
                     HsqlName name     = (HsqlName) arguments[0];
                     int[]    colIndex = (int[]) arguments[1];
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
 
                     StatementSchema.checkSchemaUpdateAuthorisation(session,
                             table.getSchemaName());
@@ -1162,7 +1178,7 @@ public class StatementCommand extends Statement {
                         throw Error.error(ErrorCode.ACCESS_IS_DENIED);
                     }
 
-                    Index index = table.getIndexForColumns(session, colIndex);
+                    Index index = table.getIndexForColumns(colIndex);
 
                     if (index != null) {
                         Index[] indexes = table.getIndexList();
@@ -1185,8 +1201,7 @@ public class StatementCommand extends Statement {
                     String   value = (String) arguments[1];
                     Integer  type  = (Integer) arguments[2];
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
 
                     if (session.isProcessingScript()) {
                         table.setIndexRoots(session, value);
@@ -1201,8 +1216,7 @@ public class StatementCommand extends Statement {
                 try {
                     HsqlName name = (HsqlName) arguments[0];
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
                     boolean mode = ((Boolean) arguments[1]).booleanValue();
 
                     StatementSchema.checkSchemaUpdateAuthorisation(session,
@@ -1217,11 +1231,15 @@ public class StatementCommand extends Statement {
             }
             case StatementTypes.SET_TABLE_SOURCE :
             case StatementTypes.SET_TABLE_SOURCE_HEADER : {
+                HsqlName name     = (HsqlName) arguments[0];
+                Boolean  mode     = (Boolean) arguments[1];
+                String   source   = (String) arguments[2];
+                Boolean  isDesc   = (Boolean) arguments[3];
+                Boolean  isHeader = (Boolean) arguments[4];
+                Table    table    = null;
+
                 try {
-                    HsqlName name = (HsqlName) arguments[0];
-                    Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                    table = session.database.schemaManager.getUserTable(name);
 
                     StatementSchema.checkSchemaUpdateAuthorisation(session,
                             table.getSchemaName());
@@ -1232,10 +1250,8 @@ public class StatementCommand extends Statement {
                         return Result.newErrorResult(e, sql);
                     }
 
-                    if (arguments[1] != null) {
-                        boolean mode = ((Boolean) arguments[1]).booleanValue();
-
-                        if (mode) {
+                    if (mode != null) {
+                        if (mode.booleanValue()) {
                             ((TextTable) table).connect(session);
                         } else {
                             ((TextTable) table).disconnect();
@@ -1247,15 +1263,11 @@ public class StatementCommand extends Statement {
                         return Result.updateZeroResult;
                     }
 
-                    String  source   = (String) arguments[2];
-                    boolean isDesc   = ((Boolean) arguments[3]).booleanValue();
-                    boolean isHeader = ((Boolean) arguments[4]).booleanValue();
-
-                    if (isHeader) {
+                    if (isHeader.booleanValue()) {
                         ((TextTable) table).setHeader(source);
                     } else {
-                        ((TextTable) table).setDataSource(session, source,
-                                                          isDesc, false);
+                        ((TextTable) table).setDataSource(
+                            session, source, isDesc.booleanValue(), false);
                     }
 
                     return Result.updateZeroResult;
@@ -1270,6 +1282,8 @@ public class StatementCommand extends Statement {
                         session.addWarning((HsqlException) e);
                         session.database.logger.logWarningEvent(
                             "Problem processing SET TABLE SOURCE", e);
+                        ((TextTable) table).setDataSource(
+                            source, isDesc.booleanValue());
 
                         return Result.updateZeroResult;
                     } else {
@@ -1284,10 +1298,11 @@ public class StatementCommand extends Statement {
 
                     //
                     Table table =
-                        session.database.schemaManager.getUserTable(name.name,
-                            name.schema.name);
+                        session.database.schemaManager.getUserTable(name);
+                    int             oldType  = table.getTableType();
+                    PersistentStore oldStore = table.getRowStore(session);
 
-                    if (table.getTableType() == type) {
+                    if (oldType == type) {
                         return Result.updateZeroResult;
                     }
 
@@ -1301,6 +1316,7 @@ public class StatementCommand extends Statement {
                         throw Error.error(ErrorCode.GENERAL_IO_ERROR);
                     }
 
+                    oldStore.removeAll();
                     session.database.schemaManager.setSchemaChangeTimestamp();
 
                     if (name.schema == SqlInvariants.LOBS_SCHEMA_HSQLNAME) {
@@ -1418,8 +1434,13 @@ public class StatementCommand extends Statement {
                             break;
 
                         case Tokens.END :
+                            if (session == targetSession) {
+                                return Result.updateZeroResult;
+                            }
+
                             session.database.txManager.resetSession(session,
-                                    targetSession, Long.MAX_VALUE,
+                                    targetSession,
+                                    targetSession.statementStartTimestamp,
                                     TransactionManager.resetSessionStatement);
                             break;
                     }
@@ -1481,12 +1502,12 @@ public class StatementCommand extends Statement {
                 // ensure schema existence
                 session.database.schemaManager.getSchemaHsqlName(name.name);
 
-                HashMappedList list =
+                OrderedHashMap list =
                     session.database.schemaManager.getTables(name.name);
 
                 tables = new Table[list.size()];
 
-                list.toValuesArray(tables);
+                list.valuesToArray(tables);
                 StatementSchema.checkSchemaUpdateAuthorisation(session, name);
 
                 if (!noCheck) {
