@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,7 @@ import org.hsqldb.types.Types;
  * Implementation of Statement for DML statements.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 
@@ -349,7 +349,7 @@ public class StatementDML extends StatementDMQL {
         }
     }
 
-    /**
+    /*
      * @todo - fredt - low priority - this does not work with different prepare calls
      * with the same SQL statement, but different generated column requests
      * To fix, add comment encapsulating the generated column list to SQL
@@ -357,9 +357,17 @@ public class StatementDML extends StatementDMQL {
      */
     public void setGeneratedColumnInfo(int generate, ResultMetaData meta) {
 
-        // also supports INSERT_SELECT
-        if (type != StatementTypes.INSERT && type != StatementTypes.MERGE) {
-            return;
+        // also covers INSERT_SELECT
+        switch (type) {
+
+            case StatementTypes.INSERT :
+            case StatementTypes.MERGE :
+            case StatementTypes.UPDATE_WHERE :
+            case StatementTypes.DELETE_WHERE :
+                break;
+
+            default :
+                return;
         }
 
         int idColIndex = baseTable.getIdentityColumnIndex();
@@ -428,6 +436,10 @@ public class StatementDML extends StatementDMQL {
                     }
                 }
                 break;
+
+            case ResultConstants.RETURN_PRIMARY_KEYS :
+                generatedIndexes = baseTable.getPrimaryKey();
+                break;
         }
 
         generatedResultMetaData =
@@ -575,12 +587,14 @@ public class StatementDML extends StatementDMQL {
 
         count = update(session, baseTable, rowset, generatedNavigator);
 
+        if (count == 0) {
+            session.addWarning(HsqlException.noDataCondition);
+        }
+
         if (resultOut == null) {
             if (count == 1) {
                 return Result.updateOneResult;
             } else if (count == 0) {
-                session.addWarning(HsqlException.noDataCondition);
-
                 return Result.updateZeroResult;
             }
 
@@ -588,10 +602,6 @@ public class StatementDML extends StatementDMQL {
         } else {
             resultOut.setUpdateCount(count);
 
-            if (count == 0) {
-                session.addWarning(HsqlException.noDataCondition);
-            }
-
             return resultOut;
         }
     }
@@ -833,14 +843,14 @@ public class StatementDML extends StatementDMQL {
             baseTable.fireTriggers(session, Trigger.INSERT_AFTER, newData);
         }
 
+        if (count == 0) {
+            session.addWarning(HsqlException.noDataCondition);
+        }
+
         if (resultOut == null) {
             if (count == 1) {
                 return Result.updateOneResult;
-            }
-
-            if (count == 0) {
-                session.addWarning(HsqlException.noDataCondition);
-
+            } else if (count == 0) {
                 return Result.updateZeroResult;
             }
 
@@ -848,10 +858,6 @@ public class StatementDML extends StatementDMQL {
         } else {
             resultOut.setUpdateCount(count);
 
-            if (count == 0) {
-                session.addWarning(HsqlException.noDataCondition);
-            }
-
             return resultOut;
         }
     }
@@ -1015,14 +1021,6 @@ public class StatementDML extends StatementDMQL {
                         throw ex;
                     }
                 }
-            } else {
-
-                // DYNAMIC_PARAM and PARAMETER expressions may have wider values
-                if (e.dataType == null
-                        || type.typeDataGroup != e.dataType.typeDataGroup
-                        || type.isArrayType()) {
-                    value = type.convertToType(session, value, e.dataType);
-                }
             }
 
             data[colIndex] = value;
@@ -1069,8 +1067,7 @@ public class StatementDML extends StatementDMQL {
 
             // for identity using global sequence
             session.sessionData.startRowProcessing();
-
-            /**
+            /*
              * @todo 1.9.0 - make optional using database property -
              * this means the identity column can be set to null to force
              * creation of a new identity value
@@ -1248,6 +1245,14 @@ public class StatementDML extends StatementDMQL {
             targetRangeVariables);
         RowSetNavigatorDataChange rowset =
             session.sessionContext.getRowSetDataChange();
+        Result          resultOut          = null;
+        RowSetNavigator generatedNavigator = null;
+
+        if (generatedIndexes != null) {
+            resultOut = Result.newUpdateCountResult(generatedResultMetaData,
+                    0);
+            generatedNavigator = resultOut.getChainedResult().getNavigator();
+        }
 
         session.sessionContext.rownum = 1;
 
@@ -1270,18 +1275,26 @@ public class StatementDML extends StatementDMQL {
         rowset.endMainDataSet();
 
         if (rowset.getSize() > 0) {
-            count = delete(session, baseTable, rowset);
-        } else {
+            count = delete(session, baseTable, rowset, generatedNavigator);
+        }
+
+        if (count == 0) {
             session.addWarning(HsqlException.noDataCondition);
-
-            return Result.updateZeroResult;
         }
 
-        if (count == 1) {
-            return Result.updateOneResult;
-        }
+        if (resultOut == null) {
+            if (count == 1) {
+                return Result.updateOneResult;
+            } else if (count == 0) {
+                return Result.updateZeroResult;
+            }
 
-        return new Result(ResultConstants.UPDATECOUNT, count);
+            return new Result(ResultConstants.UPDATECOUNT, count);
+        } else {
+            resultOut.setUpdateCount(count);
+
+            return resultOut;
+        }
     }
 
     Result executeDeleteTruncateStatement(Session session) {
@@ -1333,7 +1346,8 @@ public class StatementDML extends StatementDMQL {
      *  DELETE.
      */
     int delete(Session session, Table table,
-               RowSetNavigatorDataChange navigator) {
+               RowSetNavigatorDataChange navigator,
+               RowSetNavigator generatedNavigator) {
 
         int rowCount = navigator.getSize();
 
@@ -1408,6 +1422,12 @@ public class StatementDML extends StatementDMQL {
 
             session.addDeleteAction(currentTable, store, row, null);
 
+            if (generatedNavigator != null) {
+                Object[] generatedValues = getGeneratedColumns(row.getData());
+
+                generatedNavigator.add(generatedValues);
+            }
+
             if (data != null) {
                 hasUpdate = true;
             }
@@ -1562,7 +1582,7 @@ public class StatementDML extends StatementDMQL {
 
         for (int i = 0, size = table.checkConstraints.length; i < size; i++) {
             table.checkConstraints[i].checkInsert(session, table, newData,
-                                                  oldData == null);
+                                                  oldData);
         }
 
         if (!session.database.isReferentialIntegrity()) {
@@ -1570,16 +1590,16 @@ public class StatementDML extends StatementDMQL {
         }
 
         for (int i = 0, size = table.fkConstraints.length; i < size; i++) {
-            boolean    check = oldData == null;
-            Constraint c     = table.fkConstraints[i];
+            boolean    check     = oldData == null;
+            Constraint c         = table.fkConstraints[i];
+            int[]      fkColumns = c.getRefColumns();
 
             if (!check) {
-                check = ArrayUtil.haveCommonElement(c.getRefColumns(),
-                                                    updatedColumns);
+                check = ArrayUtil.haveCommonElement(fkColumns, updatedColumns);
             }
 
             if (check) {
-                c.checkInsert(session, table, newData, oldData == null);
+                c.checkInsert(session, table, newData, oldData);
             }
         }
     }
@@ -1626,7 +1646,7 @@ public class StatementDML extends StatementDMQL {
                 Row      refRow  = refiterator.getCurrentRow();
                 Object[] refData = null;
 
-                /** @todo use MATCH */
+                /* @todo use MATCH */
                 if (c.core.refIndex.compareRowNonUnique(
                         session, refRow.getData(), row.getData(),
                         c.core.mainCols) != 0) {
