@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -487,7 +487,7 @@ public abstract class StatementDMQL extends Statement {
         }
 
         if (expr != null) {
-            expr = (ExpressionLogical) expr.duplicate();
+            expr = expr.duplicate();
 
             targetRangeVariables[0].setFilterExpression(session, expr);
 
@@ -537,7 +537,7 @@ public abstract class StatementDMQL extends Statement {
         }
     }
 
-    /** @todo 1.9.0 - build the metadata only once and reuse */
+    /* @todo 1.9.0 - build the metadata only once and reuse */
 
     /**
      * Returns the metadata for the placeholder parameters.
@@ -563,7 +563,7 @@ public abstract class StatementDMQL extends Statement {
     /**
      * Provides the toString() implementation.
      */
-    String describeImpl(Session session) throws Exception {
+    String describeImpl(Session session) {
 
         StringBuilder sb     = new StringBuilder();
         int           blanks = 0;
