@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ import org.hsqldb.types.Type;
  * Implementation of Statement for DDL statements.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class StatementSchema extends Statement {
@@ -100,6 +100,7 @@ public class StatementSchema extends Statement {
                 break;
 
             case StatementTypes.ALTER_DOMAIN :
+            case StatementTypes.ALTER_CONSTRAINT :
             case StatementTypes.ALTER_INDEX :
             case StatementTypes.ALTER_ROUTINE :
             case StatementTypes.ALTER_SEQUENCE :
@@ -325,8 +326,11 @@ public class StatementSchema extends Statement {
 
             case StatementTypes.RENAME_OBJECT :
             case StatementTypes.RENAME_SCHEMA : {
-                HsqlName     name    = (HsqlName) arguments[0];
-                HsqlName     newName = (HsqlName) arguments[1];
+                HsqlName name     = (HsqlName) arguments[0];
+                HsqlName newName  = (HsqlName) arguments[1];
+                boolean  ifExists = ((Boolean) arguments[2]).booleanValue();
+
+
                 SchemaObject object;
 
                 switch (name.type) {
@@ -354,6 +358,15 @@ public class StatementSchema extends Statement {
                 try {
                     name.setSchemaIfNull(session.getCurrentSchemaHsqlName());
 
+                    if (ifExists) {
+                        object = schemaManager.findUserTable(name.name,
+                                                             name.schema.name);
+
+                        if (object == null) {
+                            return Result.updateZeroResult;
+                        }
+                    }
+
                     if (name.type == SchemaObject.COLUMN) {
                         Table table = schemaManager.getUserTable(name.parent);
                         int   index = table.getColumnIndex(name.name);
@@ -415,6 +428,24 @@ public class StatementSchema extends Statement {
                     return Result.newErrorResult(e, sql);
                 }
             }
+            case StatementTypes.ALTER_CONSTRAINT : {
+                Table      table      = (Table) arguments[0];
+                int[]      newColumns = (int[]) arguments[1];
+                HsqlName   name       = (HsqlName) arguments[2];
+                Constraint constraint;
+
+                try {
+                    constraint =
+                        (Constraint) session.database.schemaManager
+                            .getSchemaObject(name);
+
+                    constraint.extendFKIndexColumns(session, newColumns);
+
+                    break;
+                } catch (HsqlException e) {
+                    return Result.newErrorResult(e, sql);
+                }
+            }
             case StatementTypes.ALTER_INDEX : {
                 Table    table        = (Table) arguments[0];
                 int[]    indexColumns = (int[]) arguments[1];
@@ -1761,7 +1792,7 @@ public class StatementSchema extends Statement {
             throw Error.error(ErrorCode.X_42505, schema.name);
         }
 
-        session.getGrantee().checkSchemaUpdateOrGrantRights(schema.name);
+        session.getGrantee().checkSchemaUpdateOrGrantRights(schema);
         session.checkDDLWrite();
     }
 
