@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,8 +37,8 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.index.Index.IndexUse;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HsqlArrayList;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.OrderedIntHashSet;
 import org.hsqldb.lib.Set;
@@ -54,7 +54,6 @@ import org.hsqldb.persist.PersistentStore;
 import org.hsqldb.result.Result;
 import org.hsqldb.rights.Grantee;
 import org.hsqldb.trigger.Trigger;
-import org.hsqldb.types.BinaryData;
 import org.hsqldb.types.Collation;
 import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.TimestampData;
@@ -64,7 +63,7 @@ import org.hsqldb.types.Type;
  * Holds the data structures and methods for creation of a named database table.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.6.1
  */
 public class Table extends TableBase implements SchemaObject {
@@ -76,7 +75,7 @@ public class Table extends TableBase implements SchemaObject {
     protected long     changeTimestamp;
 
     //
-    public HashMappedList columnList;              // columns in table
+    public OrderedHashMap columnList;              // columns in table
     int                   identityColumn;          // -1 means no such column
     NumberSequence        identitySequence;        // next value of identity column
 
@@ -217,7 +216,7 @@ public class Table extends TableBase implements SchemaObject {
         // type may have changed above for CACHED tables
         tableType         = type;
         identityColumn    = -1;
-        columnList        = new HashMappedList();
+        columnList        = new OrderedHashMap();
         indexList         = Index.emptyArray;
         constraintList    = Constraint.emptyArray;
         fkConstraints     = Constraint.emptyArray;
@@ -686,8 +685,9 @@ public class Table extends TableBase implements SchemaObject {
         StringBuilder sb = new StringBuilder(128);
 
         sb.append(Tokens.T_SET).append(' ').append(Tokens.T_TABLE).append(' ');
-        sb.append(getName().getSchemaQualifiedStatementName());
-        sb.append(' ').append(Tokens.T_INDEX).append(' ').append('\'');
+        sb.append(getName().getSchemaQualifiedStatementName()).append(' ');
+        sb.append(Tokens.T_INDEX).append(' ');
+        sb.append('\'');
         sb.append(StringUtil.getList(roots, " ", ""));
         sb.append(' ');
         sb.append(StringUtil.getList(new long[indexList.length], " ", ""));
@@ -1187,8 +1187,6 @@ public class Table extends TableBase implements SchemaObject {
 
     /**
      *  Returns any unique Constraint using this index
-     *
-     * @param  index
      */
     public Constraint getUniqueOrPKConstraintForIndex(Index index) {
 
@@ -1208,9 +1206,6 @@ public class Table extends TableBase implements SchemaObject {
 
     /**
      *  Returns the next constraint of a given type
-     *
-     * @param  from
-     * @param  type
      */
     int getNextConstraintIndex(int from, int type) {
 
@@ -1646,7 +1641,7 @@ public class Table extends TableBase implements SchemaObject {
     /**
      *  Returns the identity column index.
      */
-    int getIdentityColumnIndex() {
+    public int getIdentityColumnIndex() {
         return identityColumn;
     }
 
@@ -1689,7 +1684,7 @@ public class Table extends TableBase implements SchemaObject {
         for (int i = 0; i < columnCount; i++) {
             ColumnSchema column = getColumn(i);
 
-            colNotNull[i]       = column.isPrimaryKey() || !column.isNullable();
+            colNotNull[i]      = column.isPrimaryKey() || !column.isNullable();
             colDefaults[i]     = column.getDefaultExpression();
             colGenerated[i]    = column.isGenerated();
             colUpdated[i]      = column.isAutoUpdate();
@@ -1958,7 +1953,7 @@ public class Table extends TableBase implements SchemaObject {
         return cols;
     }
 
-    int[] getColumnIndexes(HashMappedList list) {
+    int[] getColumnIndexes(OrderedHashMap list) {
 
         int[] cols = new int[list.size()];
 
@@ -2281,8 +2276,6 @@ public class Table extends TableBase implements SchemaObject {
 
     /**
      *  Returns any unique Constraint using this index
-     *
-     * @param  index
      */
     public Constraint getUniqueConstraintForIndex(Index index) {
 
@@ -2327,7 +2320,7 @@ public class Table extends TableBase implements SchemaObject {
         String oldname = column.getName().name;
         int    i       = getColumnIndex(oldname);
 
-        columnList.setKey(i, newName);
+        columnList.setKeyAt(i, newName);
         column.getName().rename(newName, isquoted);
     }
 
@@ -2340,7 +2333,7 @@ public class Table extends TableBase implements SchemaObject {
             throw Error.error(ErrorCode.X_42504);
         }
 
-        columnList.setKey(i, newName.name);
+        columnList.setKeyAt(i, newName.name);
         column.getName().rename(newName);
     }
 
@@ -2613,7 +2606,7 @@ public class Table extends TableBase implements SchemaObject {
     /**
      *  Finds an existing index for a column group - for persistent tables
      */
-    synchronized Index getIndexForColumns(Session session, int[] cols) {
+    synchronized Index getIndexForColumns(int[] cols) {
 
         int i = bestIndexForColumn[cols[0]];
 
@@ -2778,45 +2771,13 @@ public class Table extends TableBase implements SchemaObject {
         return roots;
     }
 
-    /**
-     *  Sets the index roots of a cached table to specified file
-     *  pointers. If a
-     *  file pointer is -1 then the particular index root is null. A null index
-     *  root signifies an empty table. Accordingly, all index roots should be
-     *  null or all should be a valid file pointer/reference.
-     */
-    public void setIndexRoots(long[] roots, long[] uniqueSize,
-                              long cardinality) {
-
-        if (!isCached) {
-            throw Error.error(ErrorCode.X_42501, tableName.name);
-        }
-
-        PersistentStore store =
-            database.persistentStoreCollection.getStore(this);
-
-        for (int index = 0; index < indexList.length; index++) {
-            store.setAccessor(indexList[index], roots[index]);
-        }
-
-        for (int index = 0; index < indexList.length; index++) {
-            store.setElementCount(indexList[index], cardinality,
-                                  uniqueSize[index]);
-        }
-    }
-
     public void setIndexRoots(long[] roots) {
 
-        if (!isCached) {
-            throw Error.error(ErrorCode.X_42501, tableName.name);
-        }
-
         PersistentStore store =
             database.persistentStoreCollection.getStore(this);
+        long cardinality = store.elementCount();
 
-        for (int index = 0; index < indexList.length; index++) {
-            store.setAccessor(indexList[index], roots[index]);
-        }
+        store.setAccessors(0, roots, cardinality);
     }
 
     /**
@@ -2842,20 +2803,18 @@ public class Table extends TableBase implements SchemaObject {
             roots[index] = v;
         }
 
-        try {
-            for (int index = 0; index < indexCount; index++) {
-                long v = p.readBigint();
+        for (int index = 0; index < indexCount; index++) {
+            long v = p.readBigint();
 
-                uniqueSize[index] = v;
-            }
-
-            cardinality = p.readBigint();
-        } catch (Exception e) {
-
-            // version 1.x database
+            uniqueSize[index] = v;
         }
 
-        setIndexRoots(roots, uniqueSize, cardinality);
+        cardinality = p.readBigint();
+
+        PersistentStore store =
+            database.persistentStoreCollection.getStore(this);
+
+        store.setAccessors(0, roots, cardinality);
     }
 
     public void generateAndCheckData(Session session, Object[] data) {
