@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -247,9 +247,8 @@ public class TableWorks {
         database.schemaManager.addSchemaObject(c);
         setNewTableInSchema(tn);
 
-        Table mainTable = database.schemaManager.getUserTable(
-            c.core.mainTable.getName().name,
-            c.core.mainTable.getSchemaName().name);
+        Table mainTable =
+            database.schemaManager.getUserTable(c.core.mainTable.getName());
 
         mainTable.addConstraint(new Constraint(mainName, c));
         updateConstraints(tn, emptySet);
@@ -579,7 +578,7 @@ public class TableWorks {
 
         Index newIndex = database.logger.newIndex(index.getName(),
             index.getPersistenceId(), table, columns, modeFlags, modeFlags,
-            colTypes, false, false, false, false);
+            colTypes, false, false, index.isConstraint(), index.isForward());
 
         newIndex.setPosition(position);
 
