@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -104,6 +104,13 @@ public class Token {
 
         Token token = new Token();
 
+        copyTo(token);
+
+        return token;
+    }
+
+    private void copyTo(Token token) {
+
         token.tokenString              = tokenString;
         token.tokenType                = tokenType;
         token.dataType                 = dataType;
@@ -126,8 +133,6 @@ public class Token {
         token.isCoreReservedIdentifier = isCoreReservedIdentifier;
         token.isHostParameter          = isHostParameter;
         token.isMalformed              = isMalformed;
-
-        return token;
     }
 
     public String getFullString() {
@@ -202,6 +207,12 @@ public class Token {
             }
 
             return type.getNameString();
+        } else if (expression instanceof ColumnSchema) {
+            isDelimiter = false;
+
+            ColumnSchema column = (ColumnSchema) expression;
+
+            return column.getName().getSchemaQualifiedStatementName();
         } else if (expression instanceof SchemaObject) {
             isDelimiter = false;
 
@@ -267,17 +278,6 @@ public class Token {
         return sb.toString();
     }
 
-/*
-    for (int i = 0; i < tokens.length; i++) {
-        if (tokens[i].schemaObjectIdentifier instanceof Expression) {
-            ColumnSchema column =
-                ((Expression) tokens[i].schemaObjectIdentifier)
-                    .getColumn();
-
-            tokens[i].schemaObjectIdentifier = column.getName();
-        }
-    }
-*/
     static String getSQL(Token[] tokens) {
 
         boolean       wasDelimiter = true;
