@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ import org.hsqldb.lib.OrderedHashSet;
  * Shared code for TransactionManager classes
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 2.0.0
  */
 class TransactionManagerCommon {
@@ -246,7 +246,7 @@ class TransactionManagerCommon {
 
         if (cs.getCompileTimestamp()
                 < database.schemaManager.getSchemaChangeTimestamp()) {
-            cs = session.statementManager.getStatement(session, cs);
+            cs = session.statementManager.getStatement(cs);
             session.sessionContext.currentStatement = cs;
         }
 
@@ -652,7 +652,7 @@ class TransactionManagerCommon {
                 session.tempSet.add(holder);
             }
 
-            Iterator it = tableReadLocks.get(name);
+            Iterator it = tableReadLocks.getValuesIterator(name);
 
             while (it.hasNext()) {
                 holder = (Session) it.next();
@@ -804,7 +804,7 @@ class TransactionManagerCommon {
                 return false;
             }
 
-            Iterator it = tableReadLocks.get(name);
+            Iterator it = tableReadLocks.getValuesIterator(name);
 
             while (it.hasNext()) {
                 holder = (Session) it.next();
@@ -979,12 +979,9 @@ class TransactionManagerCommon {
                     break;
 
                 case TransactionManager.resetSessionStatement :
-                    if (session == targetSession) {
-                        break;
-                    }
 
                     if (statementTimestamp
-                            < targetSession.statementStartTimestamp) {
+                            != targetSession.statementStartTimestamp) {
                         break;
                     }
 
