@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -261,7 +261,7 @@ implements TransactionManager {
         int     start  = oi.intValue();
 
         while (session.sessionContext.savepoints.size() > index + 1) {
-            session.sessionContext.savepoints.remove(
+            session.sessionContext.savepoints.removeEntry(
                 session.sessionContext.savepoints.size() - 1);
             session.sessionContext.savepointTimestamps.removeLast();
         }
