@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,10 @@
 
 package org.hsqldb.cmdline;
 
-import org.hsqldb.lib.RefCapableRBInterface;
-import org.hsqldb.lib.ValidatingResourceBundle;
+import org.hsqldb.cmdline.libclone.RefCapableRBInterface;
+import org.hsqldb.cmdline.libclone.ValidatingResourceBundle;
 
-/* $Id: SqltoolRB.java 5972 2019-05-01 16:01:58Z fredt $ */
+/* $Id: SqltoolRB.java 6266 2021-01-25 16:08:06Z fredt $ */
 
 /**
  * Resource Bundle for SqlTool and associated classes.
