@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import org.hsqldb.result.Result;
  * @version 2.2.7
  * @since 1.9.0
  */
-public class Error {
+public final class Error {
 
     //
     public static boolean TRACE          = false;
@@ -128,7 +128,7 @@ public class Error {
      * @return an <code>HsqlException</code>
      */
     public static HsqlException error(Throwable t, int code, int subCode,
-                                      final Object[] add) {
+                                      final String[] add) {
 
         String message = getMessage(code, subCode, add);
         int    sqlCode = subCode < ERROR_CODE_BASE ? code
@@ -141,7 +141,7 @@ public class Error {
 
     public static HsqlException parseError(int code, int subCode,
                                            int lineNumber,
-                                           final Object[] add) {
+                                           final String[] add) {
 
         String message = getMessage(code, subCode, add);
 
@@ -195,7 +195,7 @@ public class Error {
      *
      * @return an <code>HsqlException</code>
      */
-    private static String insertStrings(String message, Object[] add) {
+    private static String insertStrings(String message, String[] add) {
 
         StringBuilder sb        = new StringBuilder(message.length() + 32);
         int           lastIndex = 0;
@@ -214,7 +214,7 @@ public class Error {
 
             sb.append(message, lastIndex, escIndex);
             sb.append(add[i] == null ? "null exception message"
-                                     : add[i].toString());
+                                     : add[i]);
 
             lastIndex = escIndex + MESSAGE_TAG.length();
         }
@@ -227,7 +227,7 @@ public class Error {
     }
 
     /**
-     * Returns the error message given the error code.<br/>
+     * Returns the error message given the error code.<p>
      * This method is be used when throwing exception other
      * than <code>HsqlException</code>.
      *
@@ -239,7 +239,7 @@ public class Error {
     }
 
     /**
-     * Returns the error SQL STATE sting given the error code.<br/>
+     * Returns the error SQL STATE sting given the error code.<p>
      * This method is be used when throwing exception based on other exceptions.
      *
      * @param errorCode    the error code associated to the error message
@@ -250,7 +250,8 @@ public class Error {
     }
 
     /**
-     * Returns the error message given the error code.<br/> This method is used
+     * Returns the error message given the error code.<p>
+     * This method is used
      * when throwing exception other than <code>HsqlException</code>.
      *
      * @param code the code for the error message
@@ -259,7 +260,7 @@ public class Error {
      * @return the error message associated with the error code
      */
     public static String getMessage(final int code, int subCode,
-                                    final Object[] add) {
+                                    final String[] add) {
 
         String message = getResourceString(code);
 
