@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@ package org.hsqldb.error;
  * SQL error codes.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.6.0
  * @since 1.9.0
  */
 public interface ErrorCode {
@@ -627,6 +627,8 @@ public interface ErrorCode {
     int X_42610 = 5610;                            // wrong arguments for AGGREGATE function
     int X_42611 = 5611;                            // type incompatible with declared return type
     int X_42612 = 5612;                            // SQL exception already used
+    int X_42613 = 5613;                            // wildcard character * not allowed in routine, view or trigger definition
+    int X_42614 = 5614;                            // duplicate parameter name
 
     // with check option violation - 200x
     int X_44000 = 5700;                            // with check option violation
