@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ import org.hsqldb.types.ClobInputStream;
  * Instances of this class are returned by calls to ResultSet methods.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.0
  * @since  JDK 1.2, HSQLDB 1.9.0
  */
 public class JDBCClobClient implements Clob {
@@ -602,11 +602,11 @@ public class JDBCClobClient implements Clob {
             throw JDBCUtil.notUpdatableColumn();
         }
 
-        startUpdate();
-
-        str = str.substring(offset, offset + len);
-
         try {
+            startUpdate();
+
+            str = str.substring(offset, offset + len);
+
             clob.setString(session, pos - 1, str);
 
             return len;
@@ -751,7 +751,7 @@ public class JDBCClobClient implements Clob {
         resultSet.startUpdate(colIndex + 1);
 
         resultSet.preparedStatement.parameterValues[colIndex] = clob;
-        resultSet.preparedStatement.parameterSet[colIndex]    = Boolean.TRUE;
+        resultSet.preparedStatement.parameterSet[colIndex]    = true;
     }
 
     private void checkClosed() throws SQLException {
