@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -65,13 +65,16 @@ import org.hsqldb.jdbc.JDBCBlobFile.OutputStreamAdapter;
 import org.hsqldb.lib.FileUtil;
 import org.hsqldb.lib.FrameworkLogger;
 import org.hsqldb.lib.HsqlArrayList;
-import org.hsqldb.lib.HsqlList;
 import org.hsqldb.lib.InOutUtil;
+import org.hsqldb.lib.Iterator;
+import org.hsqldb.lib.List;
 
 /**
+ * A client-side file-based implementation of Clob.
+ *
  * <!-- start Release-specific documentation -->
  * <div class="ReleaseSpecificDocumentation">
- * <h3>HSQLDB-Specific Information:</h3> <p>
+ * <h1>HSQLDB-Specific Information:</h1> <p>
  *
  * Starting with 2.1, in addition to HSQLDB driver support for both client-side
  * in-memory and remote SQL CLOB data implementations, this class is provided
@@ -167,8 +170,6 @@ public class JDBCClobFile implements java.sql.Clob {
             InOutUtil.copy(reader, writer, length);
 
             return writer.toString();
-        } catch (SQLException ex) {
-            throw ex;
         } catch (IOException ex) {
             throw JDBCUtil.sqlException(ex);
         } finally {
@@ -377,7 +378,7 @@ public class JDBCClobFile implements java.sql.Clob {
 
         if (start < 1) {
             throw JDBCUtil.outOfRangeArgument("start: " + start);
-        } else if (searchstr == null || searchstr.length() == 0) {
+        } else if (searchstr == null || searchstr.isEmpty()) {
             return -1L;
         }
 
@@ -575,7 +576,7 @@ public class JDBCClobFile implements java.sql.Clob {
      *
      * @param startPos inclusive
      * @param endPos exclusive
-     * @throws SQLException
+     * @throws SQLException exception
      */
     private void fillSpace(final long startPos,
                            long endPos) throws SQLException {
@@ -688,7 +689,7 @@ public class JDBCClobFile implements java.sql.Clob {
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * When the value specified for <code>pos</code> is greater then the
      * length+1, an  <code>SQLException</code> is thrown.
@@ -824,12 +825,11 @@ public class JDBCClobFile implements java.sql.Clob {
 
         m_closed = true;
 
-        final HsqlList streams = m_streams;
+        final List streams = m_streams;
 
         m_streams = null;
 
-        for (org.hsqldb.lib.Iterator itr =
-                streams.iterator(); itr.hasNext(); ) {
+        for (Iterator itr = streams.iterator(); itr.hasNext(); ) {
             final Object stream = itr.next();
 
             closeSafely(stream);
@@ -895,7 +895,7 @@ public class JDBCClobFile implements java.sql.Clob {
     }
 
     /**
-     * Retrieves the canonical <tt>File</tt> object denoting the file that
+     * Retrieves the canonical <code>File</code> object denoting the file that
      * backs this CLOB.
      *
      * @return the file that backs this CLOB.
@@ -952,7 +952,7 @@ public class JDBCClobFile implements java.sql.Clob {
     private CharsetEncoder m_encoder;
     private boolean        m_fixedWidthCharset;
     private int            m_maxCharWidth;
-    private HsqlList       m_streams = new HsqlArrayList();
+    private List           m_streams = new HsqlArrayList();
 
     /**
      * Convenience constructor for {@link
