@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@ import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
 import java.sql.Wrapper;
+import java.util.Arrays;
 import java.util.Properties;
 import java.util.concurrent.atomic.AtomicIntegerArray;
 import javax.naming.NamingException;
@@ -53,9 +54,12 @@ import org.hsqldb.jdbc.pool.JDBCPooledConnection;
 import org.hsqldb.jdbc.pool.JDBCPooledDataSource;
 
 /**
+ *
+ * A fast connection pool.
+ *
  * <!-- start Release-specific documentation -->
  * <div class="ReleaseSpecificDocumentation">
- * <h3>HSQLDB-Specific Information:</h3> <p>
+ * <h1>HSQLDB-Specific Information:</h1> <p>
  *
  * A connection pool for HyperSQL connections. This implementation of
  * {@link javax.sql.DataSource DataSource} is dedicated to HyperSQL and
@@ -547,10 +551,7 @@ public class JDBCPool implements DataSource,
             }
         }
 
-        for (int i = 0; i < connections.length; i++) {
-            connections[i] = null;
-        }
-
+        Arrays.fill(connections, null);
     }
     // ------------------------ internal ------------------------
     interface RefState {
