@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ import org.hsqldb.result.Result;
 import org.hsqldb.result.ResultConstants;
 import org.hsqldb.result.ResultProperties;
 
-/* $Id: JDBCStatement.java 6082 2020-01-18 17:13:43Z fredt $ */
+/* $Id: JDBCStatement.java 6294 2021-02-07 18:08:27Z fredt $ */
 
 // fredt@users   20020320 - patch 1.7.0 - JDBC 2 support and error trapping
 //
@@ -71,7 +71,7 @@ import org.hsqldb.result.ResultProperties;
 
 /**
  * <!-- start generic documentation -->
- * <P>The object used for executing a static SQL statement
+ * The object used for executing a static SQL statement
  * and returning the results it produces.
  * <P>
  * By default, only one <code>ResultSet</code> object per <code>Statement</code>
@@ -85,7 +85,7 @@ import org.hsqldb.result.ResultProperties;
  *
  * <!-- start release-specific documentation -->
  * <div class="ReleaseSpecificDocumentation">
- * <h3>HSQLDB-Specific Information:</h3><p>
+ * <h1>HSQLDB-Specific Information:</h1><p>
  * From version 2.0, the implementation meets the JDBC specification
  * requirement that any existing ResultSet is closed when execute() or
  * executeQuery() methods are called. The connection property close_result=true
@@ -103,7 +103,7 @@ import org.hsqldb.result.ResultProperties;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.6.0
  * @since HSQLDB 1.9.0
  * @see JDBCConnection#createStatement
  * @see JDBCResultSet
@@ -111,6 +111,8 @@ import org.hsqldb.result.ResultProperties;
 public class JDBCStatement extends JDBCStatementBase implements Statement,
         java.sql.Wrapper {
 
+
+    public final static int RETURN_PRIMARY_KEYS = ResultConstants.RETURN_PRIMARY_KEYS;
     /**
      * <!-- start generic documentation -->
      * Executes the given SQL statement, which returns a single
@@ -119,7 +121,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * This method should not be used for statements other than SELECT queries.<p>
      *
@@ -223,7 +225,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Including 1.7.2, HSQLDB always returns zero, meaning there
      * is no limit.
@@ -261,7 +263,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * To present, calls to this method are simply ignored; HSQLDB always
      * stores the full number of bytes when dealing with any of the field types
@@ -373,7 +375,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * To present, HSQLDB always returns zero, meaning there
      * is no limit.
@@ -407,7 +409,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * The maximum number of seconds to wait is 32767.
      * </div>
@@ -444,7 +446,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB version 2.3.4 and later supports aborting an SQL query
      * or data update statement.
@@ -488,7 +490,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * In 2.0, HSQLDB may produces Statement warnings;
      * this method always returns null.
@@ -518,7 +520,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * In HSQLDB 2.0, <code>SQLWarning</code> objects may
      * be produced for Statement Objects; calls to this method clear the warnings.
@@ -535,7 +537,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
         rootWarning = null;
     }
 
-    /** @todo 1.9.0 - implement */
+    /* @todo 1.9.0 - implement */
 
     /**
      * <!-- start generic documentation -->
@@ -558,7 +560,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Including 2.0, HSQLDB does not support named cursors;
      * calls to this method are ignored.
@@ -619,7 +621,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * </div>
      * <!-- end release-specific documentation -->
@@ -693,7 +695,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB accepts all valid parameters. <p>
      * </div>
@@ -739,7 +741,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB returns the fetch direction. <p>
      * </div>
@@ -771,7 +773,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB uses the specified value as a hint, but may process more or fewer
      * rows than specified.
@@ -836,7 +838,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB supports <code>CONCUR_READ_ONLY</code> and
      * <code>CONCUR_UPDATABLE</code> concurrency.
@@ -864,7 +866,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB 1.7.0 and later versions support <code>TYPE_FORWARD_ONLY</code>
      * and <code>TYPE_SCROLL_INSENSITIVE</code>.
@@ -898,7 +900,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with 1.7.2, this feature is supported.
      * </div>
@@ -938,7 +940,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with HSQLDB 1.7.2, this feature is supported.
      * </div>
@@ -1004,7 +1006,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with HSQLDB 1.7.2, this feature is supported. <p>
      *
@@ -1114,7 +1116,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * HSQLDB moves to the next ResultSet and returns the correct result. <p>
      * </div>
@@ -1157,7 +1159,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with version 2.0, HSQLDB supports this feature with single-row
      * and multi-row insert, update and merge statements. <p>
@@ -1206,13 +1208,16 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with version 2.0, HSQLDB supports returning generated columns
      * with single-row and multi-row INSERT, UPDATE and MERGE statements. <p>
      * If the table has an IDENTITY or GENERATED column(s) the values for these
      * columns are returned in the next call to getGeneratedKeys().
      *
+     * HSQLDB also supports returning primary key values from the rows by using the
+     * <code>org.hsqldb.jdbc.JDBCStatement.RETURN_PRIMARY_KEYS</code> constant.
+     *
      * </div>
      * <!-- end release-specific documentation -->
      * @param sql an SQL Data Manipulation Language (DML) statement, such as <code>INSERT</code>, <code>UPDATE</code> or
@@ -1222,9 +1227,9 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * @param autoGeneratedKeys a flag indicating whether auto-generated keys
      *        should be made available for retrieval;
-     *         one of the following constants:
-     *         <code>Statement.RETURN_GENERATED_KEYS</code>
-     *         <code>Statement.NO_GENERATED_KEYS</code>
+     *        one of the following constants:
+     *        <code>Statement.RETURN_GENERATED_KEYS</code>
+     *        <code>Statement.NO_GENERATED_KEYS</code>
      * @return either (1) the row count for SQL Data Manipulation Language (DML) statements
      *         or (2) 0 for SQL statements that return nothing
      *         (:JDBC4 clarification)
@@ -1241,7 +1246,8 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
             int autoGeneratedKeys) throws SQLException {
 
         if (autoGeneratedKeys != Statement.RETURN_GENERATED_KEYS
-                && autoGeneratedKeys != Statement.NO_GENERATED_KEYS) {
+                && autoGeneratedKeys != Statement.NO_GENERATED_KEYS
+                && autoGeneratedKeys != JDBCStatement.RETURN_PRIMARY_KEYS) {
             throw JDBCUtil.invalidArgument("autoGeneratedKeys");
         }
         fetchResult(sql, StatementTypes.RETURN_COUNT, autoGeneratedKeys, null,
@@ -1266,7 +1272,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with version 2.0, HSQLDB supports returning generated columns
      * with single-row and multi-row INSERT, UPDATE and MERGE statements. <p>
@@ -1319,7 +1325,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with version 2.0, HSQLDB supports returning generated columns
      * with single-row and multi-row INSERT, UPDATE and MERGE statements. <p>
@@ -1384,10 +1390,13 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with 2.0, HSQLDB supports this feature.
      *
+     * HSQLDB also supports returning primary key values from the rows by using the
+     * <code>org.hsqldb.result.ResultConstants.RETURN_PRIMARY_KEYS</code> constant.
+     *
      * </div>
      * <!-- end release-specific documentation -->
      *
@@ -1417,7 +1426,8 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
             String sql, int autoGeneratedKeys) throws SQLException {
 
         if (autoGeneratedKeys != Statement.RETURN_GENERATED_KEYS
-                && autoGeneratedKeys != Statement.NO_GENERATED_KEYS) {
+                && autoGeneratedKeys != Statement.NO_GENERATED_KEYS
+                && autoGeneratedKeys != JDBCStatement.RETURN_PRIMARY_KEYS) {
             throw JDBCUtil.invalidArgument("autoGeneratedKeys");
         }
         fetchResult(sql, StatementTypes.RETURN_ANY, autoGeneratedKeys, null,
@@ -1453,7 +1463,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with 2.0, HSQLDB supports this feature.
      *
@@ -1516,7 +1526,7 @@ public class JDBCStatement extends JDBCStatementBase implements Statement,
      *
      * <!-- start release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h3>HSQLDB-Specific Information:</h3> <p>
+     * <h1>HSQLDB-Specific Information:</h1> <p>
      *
      * Starting with 2.0, HSQLDB supports this feature.
      *
