@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,11 @@
 
 package org.hsqldb.lib;
 
+import java.util.Arrays;
 import java.util.NoSuchElementException;
 
 /**
- * Maintains an ordered  long->long lookup table, consisting of two
+ * Maintains an ordered  {@code long->long} lookup table, consisting of two
  * columns, one for keys, the other for values. Equal keys are allowed.<p>
  *
  * The table is sorted on key column.<p>
@@ -102,6 +103,21 @@ public final class DoubleLongIndex implements LongLookup {
         return count;
     }
 
+    public long getTotalValues() {
+
+        long total = 0;
+
+        for (int i = 0; i < count; i++) {
+            total += values[i];
+        }
+
+        return total;
+    }
+
+    public void setSize(int newSize) {
+        count = newSize;
+    }
+
     public boolean addUnsorted(long key, long value) {
 
         if (count == capacity) {
@@ -172,13 +188,22 @@ public final class DoubleLongIndex implements LongLookup {
 
     public void clear() {
 
-        ArrayUtil.clearArray(ArrayUtil.CLASS_CODE_LONG, keys, 0, count);
-        ArrayUtil.clearArray(ArrayUtil.CLASS_CODE_LONG, values, 0, count);
+        Arrays.fill(keys, 0);
+        Arrays.fill(values, 0);
 
         count  = 0;
         sorted = true;
     }
 
+    public LongLookup duplicate() {
+
+        DoubleLongIndex duplicate = new DoubleLongIndex(capacity);
+
+        copyTo(duplicate);
+
+        return duplicate;
+    }
+
     /**
      * @param value the value
      * @return the index
@@ -225,6 +250,45 @@ public final class DoubleLongIndex implements LongLookup {
         return binarySlotSearch(false);
     }
 
+    public boolean compactLookupAsIntervals() {
+
+        if (size() == 0) {
+            return false;
+        }
+
+        if (!sorted) {
+            fastQuickSort();
+        }
+
+        int base = 0;
+
+        for (int i = 1; i < count; i++) {
+            long limit = keys[base] + values[base];
+
+            if (limit == keys[i]) {
+                values[base] += values[i];    // base updated
+            } else {
+                base++;
+
+                keys[base]   = keys[i];
+                values[base] = values[i];
+            }
+        }
+
+        for (int i = base + 1; i < count; i++) {
+            keys[i]   = 0;
+            values[i] = 0;
+        }
+
+        if (count != base + 1) {
+            setSize(base + 1);
+
+            return true;
+        }
+
+        return false;
+    }
+
     /**
      * Returns the index of the lowest element == the given search target,
      * or -1
@@ -257,9 +321,11 @@ public final class DoubleLongIndex implements LongLookup {
     }
 
     /**
-     * Returns the index of the lowest element >= the given search target,
-     * or count
-     *     @return the index
+     * Returns the index of the lowest element >= the given search target, or
+     * count
+     *
+     * @return the index or count
+     * @param fullCompare ignored
      */
     private int binarySlotSearch(boolean fullCompare) {
 
@@ -502,6 +568,13 @@ public final class DoubleLongIndex implements LongLookup {
         capacity *= 2;
     }
 
+    public void copyTo(DoubleLongIndex other) {
+
+        System.arraycopy(keys, 0, other.keys, 0, count);
+        System.arraycopy(values, 0, other.values, 0, count);
+        other.setSize(count);
+    }
+
     public boolean addUnsorted(LongLookup other) {
 
         if (!ensureCapacityToAdd(other.size())) {
