@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -80,7 +80,7 @@ public class FileUtil implements FileAccess {
     throws IOException {
 
         try {
-            return new FileInputStream(new File(streamName));
+            return new FileInputStream(streamName);
         } catch (Throwable e) {
             throw JavaSystem.toIOException(e);
         }
@@ -159,12 +159,12 @@ public class FileUtil implements FileAccess {
 
     public OutputStream openOutputStreamElement(String streamName)
     throws IOException {
-        return new FileOutputStream(new File(streamName), false);
+        return new FileOutputStream(streamName, false);
     }
 
     public OutputStream openOutputStreamElementAppend(String streamName)
     throws IOException {
-        return new FileOutputStream(new File(streamName), true);
+        return new FileOutputStream(streamName, true);
     }
 
     // end of FileAccess implementation
@@ -189,6 +189,9 @@ public class FileUtil implements FileAccess {
 
     /**
      * Delete the named file
+     *
+     * @param filename String
+     * @return true if deleted
      */
     public boolean delete(String filename) {
         return new File(filename).delete();
@@ -215,6 +218,9 @@ public class FileUtil implements FileAccess {
 
     /**
      * Return true or false based on whether the named file exists.
+     *
+     * @param filename String
+     * @return true if exists
      */
     public boolean exists(String filename) {
         return new File(filename).exists();
@@ -222,7 +228,7 @@ public class FileUtil implements FileAccess {
 
     public boolean exists(String fileName, boolean resource, Class cla) {
 
-        if (fileName == null || fileName.length() == 0) {
+        if (fileName == null || fileName.isEmpty()) {
             return false;
         }
 
@@ -232,10 +238,14 @@ public class FileUtil implements FileAccess {
 
     /**
      * Rename the file with oldname to newname. If a file with newname already
-     * exists, it is deleted before the renaming operation proceeds.
+     * exists, it is deleted before the renaming operation proceeds.<p>
      *
      * If a file with oldname does not exist, no file will exist after the
      * operation.
+     *
+     * @param oldname String
+     * @param newname String
+     * @return true if successful
      */
     private boolean renameWithOverwrite(String oldname, String newname) {
 
@@ -269,44 +279,48 @@ public class FileUtil implements FileAccess {
     }
 
     /**
-     * Retrieves the canonical file for the given file, in a
-     * JDK 1.1 complaint way.
+     * Retrieves the canonical file for the given file, in a JDK 1.1 compliant
+     * way.
      *
      * @param f the File for which to retrieve the absolute File
      * @return the canonical File
+     * @throws IOException on error
      */
     public File canonicalFile(File f) throws IOException {
         return new File(f.getCanonicalPath());
     }
 
     /**
-     * Retrieves the canonical file for the given path, in a
-     * JDK 1.1 complaint way.
+     * Retrieves the canonical file for the given path, in a JDK 1.1 compliant
+     * way.
      *
      * @param path the path for which to retrieve the canonical File
      * @return the canonical File
+     * @throws IOException on error
      */
     public File canonicalFile(String path) throws IOException {
         return new File(new File(path).getCanonicalPath());
     }
 
     /**
-     * Retrieves the canonical path for the given File, in a
-     * JDK 1.1 complaint way.
+     * Retrieves the canonical path for the given File, in a JDK 1.1 compliant
+     * way.
      *
      * @param f the File for which to retrieve the canonical path
      * @return the canonical path
+     * @throws IOException on error
      */
     public String canonicalPath(File f) throws IOException {
         return f.getCanonicalPath();
     }
 
     /**
-     * Retrieves the canonical path for the given path, in a
-     * JDK 1.1 complaint way.
+     * Retrieves the canonical path for the given path, in a JDK 1.1 compliant
+     * way.
      *
      * @param path the path for which to retrieve the canonical path
      * @return the canonical path
+     * @throws IOException on error
      */
     public String canonicalPath(String path) throws IOException {
         return new File(path).getCanonicalPath();
@@ -439,7 +453,9 @@ public class FileUtil implements FileAccess {
      * currently exist for a database. The list includes current database files
      * as well as ".new", and ".old" versions of the files, plus any app logs.
      *
-     * @param dbNamePath full path or name of database (without a file extension)
+     * @param dbNamePath full path or name of database (without a file
+     *   extension)
+     * @return File[]
      */
     public static File[] getDatabaseFileList(String dbNamePath) {
 
@@ -452,7 +468,9 @@ public class FileUtil implements FileAccess {
      * Returns a list of existing main files for a database. The list excludes
      * non-essential files.
      *
-     * @param dbNamePath full path or name of database (without a file extension)
+     * @param dbNamePath full path or name of database (without a file
+     *   extension)
+     * @return File[]
      */
     public static File[] getDatabaseMainFileList(String dbNamePath) {
 
@@ -476,10 +494,10 @@ public class FileUtil implements FileAccess {
 
     static class DatabaseFilenameFilter implements FilenameFilter {
 
-        String[]        suffixes      = new String[] {
+        String[] suffixes      = new String[] {
             ".backup", ".properties", ".script", ".data", ".log", ".lobs"
         };
-        String[]        extraSuffixes = new String[] {
+        String[] extraSuffixes = new String[] {
             ".lck", ".sql.log", ".app.log"
         };
         private String  dbName;
@@ -542,7 +560,11 @@ public class FileUtil implements FileAccess {
         }
 
         /**
-         * Accepts all main files as well as ".new" and ".old" versions.
+         * Accepts all HSQLDB main persistence files as well as ".new" and ".old" versions.
+         *
+         * @param dir the directory
+         * @param name file name
+         * @return true if an accepted file
          */
         public boolean accept(File dir, String name) {
 
