@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,22 +31,19 @@
 
 package org.hsqldb.lib;
 
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.InputStream;
 import java.io.IOException;
+import java.io.InputStream;
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
-import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.Map;
-import java.util.Properties;
 import java.util.Set;
 import java.util.logging.ConsoleHandler;
 import java.util.logging.Level;
 import java.util.logging.LogManager;
 import java.util.logging.Logger;
-import java.lang.reflect.InvocationTargetException;
 
 /**
  * A logging framework wrapper that supports java.util.logging and log4j.
@@ -87,7 +84,7 @@ import java.lang.reflect.InvocationTargetException;
  * configuration takes place.
  *
  * @author Blaine Simpson (blaine dot simpson at admc dot com)
- * @version 2.5.0
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class FrameworkLogger {
@@ -125,8 +122,8 @@ public class FrameworkLogger {
     static private Method  log4jGetLogger;
     static private Method  log4jLogMethod;
     static private boolean callerFqcnAvailable = false;
-    private Object        log4jLogger;
-    private Logger        jdkLogger;
+    private Object         log4jLogger;
+    private Logger         jdkLogger;
 
     // No need for more than one static, since we have only one console
     static private boolean noopMode;    // If true, then logging calls do nothing
@@ -151,10 +148,10 @@ public class FrameworkLogger {
      */
     public static synchronized void clearLoggers(String prefixToZap) {
 
-        Set                targetKeys = new HashSet();
-        java.util.Iterator it         = loggerInstances.keySet().iterator();
-        String             k;
-        String             dottedPrefix = prefixToZap + '.';
+        Set      targetKeys = new HashSet();
+        Iterator it         = loggerInstances.keySet().iterator();
+        String   k;
+        String   dottedPrefix = prefixToZap + '.';
 
         while (it.hasNext()) {
             k = (String) it.next();
@@ -167,22 +164,19 @@ public class FrameworkLogger {
         loggerInstances.keySet().removeAll(targetKeys);
     }
 
-    private static synchronized void
-            populateJdkToLog4jLevels(String classString)
+    private static synchronized void populateJdkToLog4jLevels(
+            String classString)
             throws ClassNotFoundException, IllegalAccessException,
-            NoSuchMethodException, InvocationTargetException {
-        Method log4jToLevel = Class.forName(classString).getMethod(
-            "toLevel", new Class[]{ String.class });
+                   NoSuchMethodException, InvocationTargetException {
+
+        Method log4jToLevel = Class.forName(classString).getMethod("toLevel",
+                                            new Class[]{ String.class });
 
         jdkToLog4jLevels.put(Level.ALL,
-                             log4jToLevel.invoke(null,
-                                 new Object[]{ "ALL" }));
+                             log4jToLevel.invoke(null, new Object[]{ "ALL" }));
         jdkToLog4jLevels.put(Level.FINER,
                              log4jToLevel.invoke(null,
                                  new Object[]{ "DEBUG" }));
-        jdkToLog4jLevels.put(Level.WARNING,
-                             log4jToLevel.invoke(null,
-                                 new Object[]{ "ERROR" }));
         jdkToLog4jLevels.put(Level.SEVERE,
                              log4jToLevel.invoke(null,
                                  new Object[]{ "FATAL" }));
@@ -190,8 +184,7 @@ public class FrameworkLogger {
                              log4jToLevel.invoke(null,
                                  new Object[]{ "INFO" }));
         jdkToLog4jLevels.put(Level.OFF,
-                             log4jToLevel.invoke(null,
-                                 new Object[]{ "OFF" }));
+                             log4jToLevel.invoke(null, new Object[]{ "OFF" }));
         jdkToLog4jLevels.put(Level.FINEST,
                              log4jToLevel.invoke(null,
                                  new Object[]{ "TRACE" }));
@@ -200,31 +193,37 @@ public class FrameworkLogger {
                                  new Object[]{ "WARN" }));
     }
 
+    /**
+     * Reconfigure log4j if present.
+     * (TODO:  Class-presence test is inadequate.  Should check
+     * Log4j is actuall used).
+     * Reconfigure java.util.logging otherwise
+     */
     static void reconfigure() {
 
         noopMode = false;
 
-        Class log4jLoggerClass = null;
+        Class log4jLoggerClass  = null;
         Class log4jManagerClass = null;
 
         loggerInstances.clear();
         jdkToLog4jLevels.clear();
 
-        log4jGetLogger   = null;
-        log4jLogMethod   = null;
+        log4jGetLogger      = null;
+        log4jLogMethod      = null;
         callerFqcnAvailable = false;
 
         // Precedence:
         //   1) Use log4j v2 if available and class initialization succeeds
         //   2) Use log4j v1 if available and class initialization succeeds
         //   3) JUL
-
         try {
+
             // log4j v2 available?
-            log4jLoggerClass = Class.forName(
-                    "org.apache.logging.log4j.Logger");
-            log4jManagerClass = Class.forName(
-                    "org.apache.logging.log4j.LogManager");
+            log4jLoggerClass =
+                Class.forName("org.apache.logging.log4j.Logger");
+            log4jManagerClass =
+                Class.forName("org.apache.logging.log4j.LogManager");
         } catch (Exception e) {
 
             // The class will only load successfully if Log4j v2 thinks it is
@@ -244,11 +243,12 @@ public class FrameworkLogger {
                 });
                 log4jGetLogger = log4jManagerClass.getMethod("getLogger",
                         new Class[]{ String.class });
+
                 // This last object is what we toggle on to generate either
                 // Log4j or Jdk Logger objects (to wrap).
-
                 return;    // Success for Log4j v2
             } catch (Exception e) {
+
                 // This is an unexpected  problem, because our Log4j try block will
                 // only be attempted if Log4j itself initialized (even if it
                 // successfully initialized with warnings due to bad config).
@@ -267,15 +267,17 @@ public class FrameworkLogger {
         }
 
         // Reset
-        log4jLoggerClass = null;
+        log4jLoggerClass  = null;
         log4jManagerClass = null;
-        log4jLogMethod   = null;
-        log4jGetLogger   = null;
+        log4jLogMethod    = null;
+        log4jGetLogger    = null;
+
         jdkToLog4jLevels.clear();
 
         try {
+
             // log4j v1 available?
-            log4jLoggerClass = Class.forName("org.apache.log4j.Logger");
+            log4jLoggerClass  = Class.forName("org.apache.log4j.Logger");
             log4jManagerClass = log4jLoggerClass;
         } catch (Exception e) {
 
@@ -296,12 +298,14 @@ public class FrameworkLogger {
                 });
                 log4jGetLogger = log4jManagerClass.getMethod("getLogger",
                         new Class[]{ String.class });
+
                 // This last object is what we toggle on to generate either
                 // Log4j or Jdk Logger objects (to wrap).
                 callerFqcnAvailable = true;
 
                 return;    // Success for Log4j v1
             } catch (Exception e) {
+
                 // This is an unexpected  problem, because our Log4j try block will
                 // only be attempted if Log4j itself initialized (even if it
                 // successfully initialized with warnings due to bad config).
@@ -320,11 +324,12 @@ public class FrameworkLogger {
         }
 
         // Reset
-        log4jLoggerClass = null;
-        log4jManagerClass = null;
-        log4jLogMethod   = null;
-        log4jGetLogger   = null;
+        log4jLoggerClass    = null;
+        log4jManagerClass   = null;
+        log4jLogMethod      = null;
+        log4jGetLogger      = null;
         callerFqcnAvailable = false;
+
         jdkToLog4jLevels.clear();
 
         String propVal = System.getProperty("hsqldb.reconfig_logging");
@@ -333,49 +338,62 @@ public class FrameworkLogger {
             return;
         }
 
+        // Set up java.util.logging
         InputStream istream = null;
-        Logger cmdlineLogger;
+
         try {
             LogManager lm = LogManager.getLogManager();
-            String path =
-                "/org/hsqldb/resources/jdklogging-default.properties";
 
-            if (isDefaultJdkConfig()) {
-                lm.reset();
+            //lm.reset();
+            if (System.getProperty("java.util.logging.config.class") != null
+                    || System.getProperty("java.util.logging.config.file")
+                       != null) {
 
-                ConsoleHandler consoleHandler = new ConsoleHandler();
-
-                consoleHandler.setFormatter(
-                    new BasicTextJdkLogFormatter(false));
-                consoleHandler.setLevel(Level.INFO);
-
-                istream = FrameworkLogger.class.getResourceAsStream(path);
-
-                lm.readConfiguration(istream);
-
-                cmdlineLogger = Logger.getLogger("org.hsqldb.cmdline");
-
-                cmdlineLogger.addHandler(consoleHandler);
-                cmdlineLogger.setUseParentHandlers(false);
-            } else {
-
-                // Do not intervene.  Use JDK logging exactly as configured
-                // by user.
+                // App has explicitly configured logging, so do not
+                // apply hsqldb customizations, but still do not run
+                // updateConfiguration in case previously loaded hsqldb
+                // customizations before app customized.
                 lm.readConfiguration();
 
-                // The only bad thing about doing this is that if the app
-                // has programmatically changed the logging config after
-                // starting the program but before using FrameworkLogger,
-                // we will clobber those customizations.
-                // Set sys srop 'hsqldb.reconfig_logging' to false to
-                // prevent this.
+                //lm.updateConfiguration(null);
+                /* This only for system debugging:
+                System.err.println(FrameworkLogger.class.getName()
+                  + " reconfigured HANDS-OFF");
+                */
+                return;
             }
+
+            String path =
+                "/org/hsqldb/resources/jdklogging-default.properties";
+            ConsoleHandler consoleHandler = new ConsoleHandler();
+
+            consoleHandler.setFormatter(new BasicTextJdkLogFormatter(false));
+            consoleHandler.setLevel(Level.INFO);
+
+            istream = FrameworkLogger.class.getResourceAsStream(path);
+
+            if (istream == null) {
+                throw new Exception(
+                    "Failed to resolve default logging config from'" + path
+                    + "'");
+            }
+
+            lm.readConfiguration(istream);
+
+            Logger cmdlineLogger = Logger.getLogger("org.hsqldb.cmdline");
+
+            cmdlineLogger.addHandler(consoleHandler);
+            cmdlineLogger.setUseParentHandlers(false);
+            /* This only for system debugging:
+            System.err.println(FrameworkLogger.class.getName()
+              + " reconfigured HSQLDB with file '" + path + "'");
+             */
         } catch (Exception e) {
             noopMode = true;
 
             System.err.println(
                 "<clinit> failure initializing JDK logging system.  "
-                + "Continuing without Application logging.");
+                + "Continuing without Application logging.  " + e);
             e.printStackTrace();
         } finally {
             if (istream != null) {
@@ -420,7 +438,6 @@ public class FrameworkLogger {
      * work with static (class-level) pointers to logger instances, for
      * performance efficiency. See the class-level JavaDoc for a usage example.
      *
-     * @see FrameworkLogger
      * @param c Class
      * @return FrameworkLogger
      */
@@ -511,8 +528,8 @@ public class FrameworkLogger {
 
         if (log4jLogger == null) {
             StackTraceElement[] elements = new Throwable().getStackTrace();
-            String            c          = "";
-            String            m          = "";
+            String              c        = "";
+            String              m        = "";
 
             if (elements.length > revertMethods) {
                 c = elements[revertMethods].getClassName();
@@ -526,13 +543,14 @@ public class FrameworkLogger {
             }
         } else {
             try {
-                log4jLogMethod.invoke(log4jLogger, callerFqcnAvailable
-                         ? new Object[] {
-                            skipClass.getName(), jdkToLog4jLevels.get(level),
-                            message, t}
-                         : new Object[] {
-                            jdkToLog4jLevels.get(level), message, t}
-                );
+                log4jLogMethod.invoke(log4jLogger,
+                                      callerFqcnAvailable ? new Object[] {
+                    skipClass.getName(), jdkToLog4jLevels.get(level), message,
+                    t
+                }
+                                                          : new Object[] {
+       jdkToLog4jLevels.get(level), message, t
+   });
             } catch (Exception e) {
                 throw new RuntimeException(
                     "Logging failed when attempting to log: " + message, e);
@@ -557,13 +575,15 @@ public class FrameworkLogger {
             jdkLogger.logp(level, c, m, message);
         } else {
             try {
-                log4jLogMethod.invoke(log4jLogger, callerFqcnAvailable
-                        ? new Object[] {
-                           FrameworkLogger.class.getName(),
-                           jdkToLog4jLevels.get(level), message, null}
-                        : new Object[] {
-                           jdkToLog4jLevels.get(level), message, null}
-                );
+                Object[] args = callerFqcnAvailable ? new Object[] {
+                    FrameworkLogger.class.getName(),
+                    jdkToLog4jLevels.get(level), message, null
+                }
+                                                    : new Object[] {
+                    jdkToLog4jLevels.get(level), message, null
+                };
+
+                log4jLogMethod.invoke(log4jLogger, args);
 
                 // Test where SqlFile correct here.
             } catch (Exception e) {
@@ -701,65 +721,4 @@ public class FrameworkLogger {
     public void error(String message, Throwable t) {
         privlog(Level.WARNING, message, t, 2, FrameworkLogger.class);
     }
-
-    /**
-     * Whether this JVM is configured with java.util.logging defaults. If the
-     * JRE-provided config file is not in the expected place, then we return
-     * false.
-     *
-     * @return boolean
-     */
-    public static boolean isDefaultJdkConfig() {
-
-        File globalCfgFile = new File(System.getProperty("java.home"),
-                                      "lib/logging.properties");
-
-        if (!globalCfgFile.isFile()) {
-            return false;
-        }
-
-        FileInputStream fis = null;
-        LogManager      lm  = LogManager.getLogManager();
-
-        try {
-            fis = new FileInputStream(globalCfgFile);
-
-            Properties defaultProps = new Properties();
-
-            defaultProps.load(fis);
-
-            Enumeration names = defaultProps.propertyNames();
-            int         i     = 0;
-            String      name;
-            String      liveVal;
-
-            while (names.hasMoreElements()) {
-                i++;
-
-                name    = (String) names.nextElement();
-                liveVal = lm.getProperty(name);
-
-                if (liveVal == null) {
-                    return false;
-                }
-
-                if (!lm.getProperty(name).equals(liveVal)) {
-                    return false;
-                }
-            }
-
-            return true;
-        } catch (IOException ioe) {
-            return false;
-        } finally {
-            if (fis != null) {
-                try {
-                    fis.close();
-                } catch (IOException ioe) {
-
-                    // Intentional no-op
-                }
-            }
-        }
-    }
 }
