@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,10 +37,10 @@ import org.hsqldb.map.BaseHashMap;
  * This class does not store null keys.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.7.2
  */
-public class HashSet extends BaseHashMap implements Set {
+public class HashSet<E> extends BaseHashMap implements Set<E> {
 
     public HashSet() {
         this(8);
@@ -51,17 +51,22 @@ public class HashSet extends BaseHashMap implements Set {
               BaseHashMap.noKeyOrValue, false);
     }
 
-    public void setComparator(ObjectComparator comparator) {
-        super.setComparator(comparator);
+    public HashSet(int initialCapacity,
+                   ObjectComparator comparator)
+                   throws IllegalArgumentException {
+
+        this(initialCapacity);
+
+        this.comparator = comparator;
     }
 
     public boolean contains(Object key) {
         return super.containsKey(key);
     }
 
-    public boolean containsAll(Collection col) {
+    public boolean containsAll(Collection<?> col) {
 
-        Iterator it = col.iterator();
+        Iterator<?> it = col.iterator();
 
         while (it.hasNext()) {
             if (contains(it.next())) {
@@ -74,9 +79,13 @@ public class HashSet extends BaseHashMap implements Set {
         return true;
     }
 
-    public Object getOrAdd(Object key) {
+    public E getOrAdd(E key) {
 
-        Object value = get(key);
+        if (key == null) {
+            throw new NullPointerException();
+        }
+
+        E value = get(key);
 
         if (value == null) {
             value = key;
@@ -87,40 +96,44 @@ public class HashSet extends BaseHashMap implements Set {
         return value;
     }
 
-    public Object get(Object key) {
+    public E get(E key) {
 
-        int hashCode;
-
-        if (comparator == null) {
-            hashCode = key.hashCode();
-        } else {
-            hashCode = comparator.hashCode(key);
+        if (key == null) {
+            throw new NullPointerException();
         }
 
-        int lookup = getLookup(key, hashCode);
+        int lookup = getLookup(key);
 
         if (lookup < 0) {
             return null;
         } else {
-            return objectKeyTable[lookup];
+            return (E) objectKeyTable[lookup];
         }
     }
 
-    /** returns true if added */
-    public boolean add(Object key) {
+    /**
+     * returns true if element is added
+     *
+     * @param key the element
+     * @return true if added
+     */
+    public boolean add(E key) {
+        if (key == null) {
+            throw new NullPointerException();
+        }
 
-        int count = size();
-
-        super.addOrRemove(0, 0, key, null, false);
-
-        return count != size();
+        return (Boolean) super.addOrUpdate(0, 0, key, null);
     }
 
-    /** returns true if any added */
-    public boolean addAll(Collection c) {
+    /** returns true if any  element is added
+     *
+     * @param c the Collection to add
+     * @return true if any element is added
+     */
+    public boolean addAll(Collection<? extends E> c) {
 
-        boolean  changed = false;
-        Iterator it      = c.iterator();
+        boolean               changed = false;
+        Iterator<? extends E> it      = c.iterator();
 
         while (it.hasNext()) {
             changed |= add(it.next());
@@ -129,8 +142,12 @@ public class HashSet extends BaseHashMap implements Set {
         return changed;
     }
 
-    /** returns true if any added */
-    public boolean addAll(Object[] keys) {
+    /** returns true if any element is added
+    *
+    * @param keys the array of elements to add
+    * @return true if any element is added
+    */
+    public boolean addAll(E[] keys) {
 
         boolean changed = false;
 
@@ -141,8 +158,15 @@ public class HashSet extends BaseHashMap implements Set {
         return changed;
     }
 
-    /** returns true if any added */
-    public boolean addAll(Object[] keys, int start, int limit) {
+    /**
+     * returns true if any added
+     *
+     * @param keys array of keys to add
+     * @param start first index to add
+     * @param limit limit of index to add
+     * @return true if any element was added
+     */
+    public boolean addAll(E[] keys, int start, int limit) {
 
         boolean changed = false;
 
@@ -153,15 +177,30 @@ public class HashSet extends BaseHashMap implements Set {
         return changed;
     }
 
-    /** returns true if removed */
+    /**
+     * returns true if removed
+     *
+     * @param key Object to remove
+     * @return true if removed
+     */
     public boolean remove(Object key) {
-        return super.removeObject(key, false) != null;
+
+        if (key == null) {
+            throw new NullPointerException();
+        }
+
+        return (Boolean) super.remove(0, 0, key, null, false, false);
     }
 
-    /** returns true if all were removed */
-    public boolean removeAll(Collection c) {
+    /**
+     * returns true if all were removed
+     *
+     * @param c Collection of elements to remove
+     * @return true if all removed
+     */
+    public boolean removeAll(Collection<?> c) {
 
-        Iterator it     = c.iterator();
+        Iterator<?> it = c.iterator();
         boolean  result = true;
 
         while (it.hasNext()) {
@@ -171,19 +210,29 @@ public class HashSet extends BaseHashMap implements Set {
         return result;
     }
 
-    public void intersect(Set c) {
+    public boolean retainAll(Collection<?> c) {
 
-        Iterator it = iterator();
+        boolean changed = false;
+
+        Iterator<?> it = iterator();
 
         while (it.hasNext()) {
             if (!c.contains(it.next())) {
                 it.remove();
+                changed = true;
             }
         }
+
+        return changed;
     }
 
-    /** returns true if all were removed */
-    public boolean removeAll(Object[] keys) {
+    /**
+     * returns true if all were removed
+     *
+     * @param keys E[]
+     * @return boolean
+     */
+    public boolean removeAll(E[] keys) {
 
         boolean result = true;
 
@@ -194,35 +243,38 @@ public class HashSet extends BaseHashMap implements Set {
         return result;
     }
 
-    public void toArray(Object[] a) {
+    public int getCommonElementCount(Set<E> other) {
 
-        Iterator it = iterator();
+        int count = 0;
 
-        for (int i = 0; it.hasNext(); i++) {
-            a[i] = it.next();
+        Iterator<E> it = iterator();
+
+        while (it.hasNext()) {
+            if (other.contains(it.next())) {
+                count++;
+            }
         }
+
+        return count;
+    }
+
+    public <T> T[] toArray(T[] a) {
+        return toArray(a, true);
     }
 
     public Object[] toArray() {
-
-        if (isEmpty()) {
-            return emptyObjectArray;
-        }
-
-        Object[] array = new Object[size()];
-
-        toArray(array);
-
-        return array;
+        return toArray(true);
     }
 
-    public Iterator iterator() {
+    public Iterator<E> iterator() {
         return new BaseHashIterator(true);
     }
 
     /**
      * Returns a String like "[Drei, zwei, Eins]", exactly like
      * java.util.HashSet.
+     *
+     * @return String representation
      */
     public String toString() {
 
