@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,39 +31,65 @@
 
 package org.hsqldb.lib;
 
+import java.util.ListIterator;
+
+
 /**
- * Implementation of an ordered Set which maintains the inserted order of
- * elements and allows access by index. Iterators return the
- * elements in the index order.
+ * A list which is also a Set which maintains the inserted order of elements and
+ * allows access by index. Iterators return the elements in the index order.<p>
  *
  * This class does not store null elements.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.6.0
  * @since 1.9.0
  */
-public class OrderedHashSet extends HashSet implements HsqlList, Set {
+public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
 
     public OrderedHashSet() {
-
         super(8);
 
-        isList = true;
+        this.isList = true;
+    }
+
+    public OrderedHashSet(int initialCapacity) {
+        super(initialCapacity);
+
+        this.isList = true;
+    }
+
+    public OrderedHashSet(int initialCapacity, ObjectComparator<E> comparator) {
+        super(initialCapacity, comparator);
+
+        this.isList = true;
     }
 
     public boolean remove(Object key) {
-        return super.removeObject(key, true) != null;
+
+        if (key == null) {
+            throw new NullPointerException();
+        }
+
+        return (Boolean) super.remove(0, 0, key, null, false, true);
     }
 
-    public Object remove(int index) throws IndexOutOfBoundsException {
+    public E remove(int index) {
 
         checkRange(index);
 
-        return super.removeObject(objectKeyTable[index], true);
+        E key = (E)objectKeyTable[index];
+
+        super.remove(0, 0, key, null, false, true);
+
+        return key;
+    }
+
+    public void removeEntry(int index) throws IndexOutOfBoundsException {
+        remove(index);
     }
 
     public boolean insert(int index,
-                          Object key) throws IndexOutOfBoundsException {
+                          E key) throws IndexOutOfBoundsException {
 
         if (index < 0 || index > size()) {
             throw new IndexOutOfBoundsException();
@@ -73,64 +99,77 @@ public class OrderedHashSet extends HashSet implements HsqlList, Set {
             return false;
         }
 
-        if (index == size()) {
-            return add(key);
+        if (index < size()) {
+            super.insertRow(index);
         }
 
-        Object[] array = new Object[size()];
+        return add(key);
+    }
 
-        toArray(array);
-        super.clear();
-
-        for (int i = 0; i < index; i++) {
-            add(array[i]);
+    public E set(int index, E key) {
+        if (key == null) {
+            throw new NullPointerException();
         }
 
-        add(key);
-
-        for (int i = index; i < array.length; i++) {
-            add(array[i]);
-        }
-
-        return true;
-    }
-
-    public Object set(int index, Object key) throws IndexOutOfBoundsException {
-        throw new IndexOutOfBoundsException();
-    }
-
-    public void add(int index, Object key) throws IndexOutOfBoundsException {
-        throw new IndexOutOfBoundsException();
-    }
-
-    public Object get(int index) throws IndexOutOfBoundsException {
-
         checkRange(index);
 
-        return objectKeyTable[index];
+        if (contains(key) && getIndex(key) != index) {
+            throw new IllegalArgumentException();
+        }
+
+        E oldKey = (E) objectKeyTable[index];
+
+        super.remove(0, 0, oldKey, null, false, false);
+
+        add(key);
+
+        return oldKey;
     }
 
-    public void toArray(Object[] array) {
-        System.arraycopy(super.objectKeyTable, 0, array, 0, array.length);
-    }
+    public void add(int index, E key) {
+        boolean result = insert(index, key);
 
-    public void addAll(OrderedHashSet other) {
-
-        for (int i = 0, size = other.size(); i < size; i++) {
-            add(other.get(i));
+        if (!result) {
+            throw new IllegalArgumentException();
         }
     }
 
-    public int getIndex(Object key) {
-        return getLookup(key, key.hashCode());
+    public E get(int index) {
+
+        checkRange(index);
+
+        return (E) objectKeyTable[index];
     }
 
-    public int getLargestIndex(OrderedHashSet other) {
+    public Object[] toArray() {
+        Object[] array = new Object[size()];
+        return toArray(array);
+    }
+
+    public <T> T[] toArray(T[] array) {
+        System.arraycopy(super.objectKeyTable, 0, array, 0, array.length);
+
+        return array;
+    }
+
+    public int indexOf(Object key) {
+        return getLookup(key);
+    }
+
+    public int getIndex(Object key) {
+        return getLookup(key);
+    }
+
+    public int lastIndexOf(Object o) {
+        return indexOf(o);
+    }
+
+    public int getLargestIndex(OrderedHashSet<E> other) {
 
         int max = -1;
 
         for (int i = 0, size = other.size(); i < size; i++) {
-            int index = getIndex(other.get(i));
+            int index = indexOf(other.get(i));
 
             if (index > max) {
                 max = index;
@@ -140,12 +179,12 @@ public class OrderedHashSet extends HashSet implements HsqlList, Set {
         return max;
     }
 
-    public int getSmallestIndex(OrderedHashSet other) {
+    public int getSmallestIndex(OrderedHashSet<E> other) {
 
         int min = -1;
 
         for (int i = 0, size = other.size(); i < size; i++) {
-            int index = getIndex(other.get(i));
+            int index = indexOf(other.get(i));
 
             if (index != -1) {
                 if (min == -1 || index < min) {
@@ -157,12 +196,12 @@ public class OrderedHashSet extends HashSet implements HsqlList, Set {
         return min;
     }
 
-    public int getCommonElementCount(Set other) {
+    public int getCommonElementCount(Set<E> other) {
 
         int count = 0;
 
         for (int i = 0, size = size(); i < size; i++) {
-            if (other.contains(objectKeyTable[i])) {
+            if (other.contains((E) objectKeyTable[i])) {
                 count++;
             }
         }
@@ -170,15 +209,15 @@ public class OrderedHashSet extends HashSet implements HsqlList, Set {
         return count;
     }
 
-    public static OrderedHashSet addAll(OrderedHashSet first,
-                                        OrderedHashSet second) {
+    public static <E> OrderedHashSet<E> addAll(OrderedHashSet<E> first,
+                                        OrderedHashSet<E> second) {
 
         if (second == null) {
             return first;
         }
 
         if (first == null) {
-            first = new OrderedHashSet();
+            first = new OrderedHashSet<E>();
         }
 
         first.addAll(second);
@@ -186,14 +225,14 @@ public class OrderedHashSet extends HashSet implements HsqlList, Set {
         return first;
     }
 
-    public static OrderedHashSet add(OrderedHashSet first, Object value) {
+    public static <E> OrderedHashSet<E> add(OrderedHashSet<E> first, E value) {
 
         if (value == null) {
             return first;
         }
 
         if (first == null) {
-            first = new OrderedHashSet();
+            first = new OrderedHashSet<E>();
         }
 
         first.add(value);
