@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import java.util.ResourceBundle;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-/* $Id: RefCapablePropertyResourceBundle.java 6118 2020-05-12 20:24:04Z fredt $ */
+/* $Id: RefCapablePropertyResourceBundle.java 6266 2021-01-25 16:08:06Z fredt $ */
 
 /**
  * Just like PropertyResourceBundle, except keys mapped to nothing in the
@@ -80,7 +80,7 @@ import java.util.regex.Pattern;
  * To eliminate the need to prohibit the use of any strings in the .properties
  * values, and to enforce consistency, you <b>must</b> use the following rules
  * to when putting your referenced files into place.
- * <P/>
+ * <P>
  * REFERENCED FILE DIRECTORY is a directory named with the base name of the
  * properties file, and in the same parent directory.  So, the referenced
  * file directory <CODE>/a/b/c/greentea</CODE> is used to hold all reference
@@ -92,7 +92,7 @@ import java.util.regex.Pattern;
  * REFERENCED FILES themselves all have the base name of the property key,
  * with locale appendages exactly as the <i>referring</i> properties files
  * has, plus the suffix <CODE>.text</CODE>.
- * <P/>
+ * <P>
  * So, if we have the following line in
  * <CODE>/a/b/c/greentea_de.properties</CODE>:
  * <PRE>
@@ -100,7 +100,7 @@ import java.util.regex.Pattern;
  * </PRE>
  * then you <b>must</b> have a reference text file
  * <CODE>/a/b/c/greentea/1_de.properties</CODE>:
- * <P/>
+ * <P>
  * In reference text files,
  * sequences of "\r", "\n" and "\r\n" are all translated to the line
  * delimiter for your platform (System property <CODE>line.separator</CODE>).
@@ -109,18 +109,18 @@ import java.util.regex.Pattern;
  * end your file with two of them).
  * (The file itself is never modified-- I'm talking about the value returned
  * by <CODE>getString(String)</CODE>).
- * <P/>
+ * <P>
  * To prevent throwing at runtime due to unset variables, use a wrapper class
  * like SqltoolRB (use SqltoolRB.java as a template).
  * To prevent throwing at runtime due to unset System Properties, or
  * insufficient parameters passed to getString(String, String[]), set the
  * behavior values appropriately.
- * <P/>
+ * <P>
  * Just like all Properties files, referenced files must use ISO-8859-1
  * encoding, with unicode escapes for characters outside of ISO-8859-1
  * character set.  But, unlike Properties files, \ does not need to be
  * escaped for normal usage.
- * <P/>
+ * <P>
  * The getString() methods with more than one parameter substitute for
  * "positional" parameters of the form "%{1}".
  * The getExpandedString() methods substitute for System Property names
@@ -166,7 +166,7 @@ public class RefCapablePropertyResourceBundle {
             "(?s)\\Q${\\E([^}]+?)(?:\\Q:+\\E([^}]+))?\\Q}");
     private Pattern posPattern = Pattern.compile(
             "(?s)\\Q%{\\E(\\d)(?:\\Q:+\\E([^}]+))?\\Q}");
-    private ClassLoader loader;  // Needed to load referenced files
+    private Class<? extends Enum<?>> loaderClass;
 
     public static final int THROW_BEHAVIOR = 0;
     public static final int EMPTYSTRING_BEHAVIOR = 1;
@@ -177,11 +177,12 @@ public class RefCapablePropertyResourceBundle {
     }
 
     private RefCapablePropertyResourceBundle(String baseName,
-            PropertyResourceBundle wrappedBundle, ClassLoader loader) {
+            PropertyResourceBundle wrappedBundle,
+            Class<? extends Enum<?>> loaderClass) {
         this.baseName = baseName;
         this.wrappedBundle = wrappedBundle;
         Locale locale = wrappedBundle.getLocale();
-        this.loader = loader;
+        this.loaderClass = loaderClass;
         language = locale.getLanguage();
         country = locale.getCountry();
         variant = locale.getVariant();
@@ -345,9 +346,9 @@ public class RefCapablePropertyResourceBundle {
      * @see ResourceBundle#getBundle(String)
      */
     public static RefCapablePropertyResourceBundle getBundle(String baseName,
-            ClassLoader loader) {
+            ClassLoader loader, Class<? extends Enum<?>> loaderClass) {
         return getRef(baseName, ResourceBundle.getBundle(baseName,
-                Locale.getDefault(), loader), loader);
+                Locale.getDefault(), loader), loaderClass);
     }
     /**
      * Use exactly like java.util.ResourceBundle.get(String, Locale, ClassLoader).
@@ -355,9 +356,10 @@ public class RefCapablePropertyResourceBundle {
      * @see ResourceBundle#getBundle(String, Locale, ClassLoader)
      */
     public static RefCapablePropertyResourceBundle
-            getBundle(String baseName, Locale locale, ClassLoader loader) {
-        return getRef(baseName,
-                ResourceBundle.getBundle(baseName, locale, loader), loader);
+            getBundle(String baseName, Locale locale, ClassLoader loader,
+            Class<? extends Enum<?>> loaderClass) {
+        return getRef(baseName, ResourceBundle.getBundle(
+          baseName, locale, loader), loaderClass);
     }
 
     /**
@@ -365,7 +367,7 @@ public class RefCapablePropertyResourceBundle {
      * or throw a MissingResourceException.
      */
     static private RefCapablePropertyResourceBundle getRef(String baseName,
-            ResourceBundle rb, ClassLoader loader) {
+            ResourceBundle rb, Class<? extends Enum<?>> loaderClass) {
         if (!(rb instanceof PropertyResourceBundle))
             throw new MissingResourceException(
                     "Found a Resource Bundle, but it is a "
@@ -374,27 +376,34 @@ public class RefCapablePropertyResourceBundle {
         if (allBundles.containsKey(rb)) return allBundles.get(rb);
         RefCapablePropertyResourceBundle newPRAFP =
                 new RefCapablePropertyResourceBundle(baseName,
-                        (PropertyResourceBundle) rb, loader);
+                        (PropertyResourceBundle) rb, loaderClass);
         allBundles.put(rb, newPRAFP);
         return newPRAFP;
     }
 
     /**
-     * Recursive
+     * Recursive.
+     * For consistency we do not allow paths relative to anything other
+     * than root.  Even though we load via Class, baseNames are resolved
+     * as if absolute, just like ClassLoader lookups.
      */
     private InputStream getMostSpecificStream(
             String key, String l, String c, String v) {
-        final String filePath = baseName.replace('.', '/') + '/' + key
+        // Now that using a Class to look up resource for this special case,
+        // absolute paths need to begin with slash.
+        final String filePath =
+               (baseName.matches("^[^./].*[./].+") ? "/" : "")
+                + baseName.replace('.', '/') + '/' + key
                 + ((l == null) ? "" : ("_" + l))
                 + ((c == null) ? "" : ("_" + c))
                 + ((v == null) ? "" : ("_" + v))
                 + ".text";
-        // System.err.println("Seeking " + filePath);
+        //System.err.println("Seeking " + filePath + " FOR " + baseName);
         InputStream is = (InputStream) AccessController.doPrivileged(
             new PrivilegedAction<InputStream>() {
 
             public InputStream run() {
-                return loader.getResourceAsStream(filePath);
+                return loaderClass.getResourceAsStream(filePath);
             }
         });
         // N.b.  If were using Class.getRes... instead of ClassLoader.getRes...
