@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@ import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Set;
 
-/* $Id: ValidatingResourceBundle.java 5969 2019-04-27 14:59:54Z fredt $ */
+/* $Id: ValidatingResourceBundle.java 6266 2021-01-25 16:08:06Z fredt $ */
 
 /**
  * Purpose of this class is to wrap a RefCapablePropertyResourceBundle to
@@ -71,7 +71,7 @@ public class ValidatingResourceBundle {
         this.enumType = enumType;
         try {
             wrappedRCPRB = RefCapablePropertyResourceBundle.getBundle(baseName,
-                    enumType.getClassLoader());
+                    enumType.getClassLoader(), enumType);
             validate();
         } catch (RuntimeException re) {
             System.err.println("Failed to initialize resource bundle: " + re);
