@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * Implementation of RowSetNavigator using a table as the data store.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class RowSetNavigatorDataTable extends RowSetNavigatorData {
@@ -63,7 +63,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
     public RowSetNavigatorDataTable(Session session,
                                     QuerySpecification select) {
 
-        super(session);
+        super(session, select.sortAndSlice);
 
         rangePosition      = select.resultRangePosition;
         visibleColumnCount = select.indexLimitVisible;
@@ -98,7 +98,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
     public RowSetNavigatorDataTable(Session session,
                                     QueryExpression queryExpression) {
 
-        super(session);
+        super(session, queryExpression.sortAndSlice);
 
         table              = queryExpression.resultTable.duplicate();
         visibleColumnCount = table.getColumnCount();
@@ -110,14 +110,14 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
     public RowSetNavigatorDataTable(Session session, Table table) {
 
-        super(session);
+        super(session, SortAndSlice.noSort);
 
         this.table         = table;
         visibleColumnCount = table.getColumnCount();
         mainIndex          = table.getPrimaryIndex();
         fullIndex          = table.getFullIndex(session);
         store              = table.getRowStore(session);
-        this.size          = (int) store.elementCount();
+        size               = (int) store.elementCount();
 
         reset();
     }
@@ -323,8 +323,6 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
             addAdjusted(currentData, rightColumnIndexes);
         }
-
-        other.release();
     }
 
     public void union(RowSetNavigatorData other) {
@@ -351,7 +349,6 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             it.release();
         }
 
-        other.release();
         reset();
     }
 
@@ -369,7 +366,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             }
         }
 
-        other.release();
+        reset();
     }
 
     public void intersectAll(RowSetNavigatorData other) {
@@ -410,7 +407,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             removeCurrent();
         }
 
-        other.release();
+        reset();
     }
 
     public void except(RowSetNavigatorData other) {
@@ -427,7 +424,24 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             }
         }
 
-        other.release();
+        reset();
+    }
+
+    public void exceptNoDedup(RowSetNavigatorData other) {
+
+        other.sortFull();
+        reset();
+
+        while (next()) {
+            Object[] currentData = getCurrent();
+            boolean  hasRow      = other.containsRow(currentData);
+
+            if (hasRow) {
+                removeCurrent();
+            }
+        }
+
+        reset();
     }
 
     public void exceptAll(RowSetNavigatorData other) {
@@ -465,7 +479,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             }
         }
 
-        other.release();
+        reset();
     }
 
     public boolean hasUniqueNotNullRows() {
@@ -548,6 +562,8 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
         while (next()) {
             removeCurrent();
         }
+
+        reset();
     }
 
     boolean hasNull(Object[] data) {
