@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 package org.hsqldb.persist;
 
+import java.util.Comparator;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import org.hsqldb.error.Error;
@@ -51,7 +52,7 @@ import org.hsqldb.map.BaseHashMap;
  * to DataFileCache.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.8.0
  */
 public class Cache extends BaseHashMap {
@@ -200,7 +201,7 @@ public class Cache extends BaseHashMap {
 
     private void putNoCheck(CachedObject row) {
 
-        Object existing = addOrRemoveObject(row, row.getPos(), false);
+        Object existing = addOrRemoveObject(row.getPos(), row, false);
 
         if (existing != null) {
             dataFileCache.logSevereEvent("existing object in Cache.put() "
@@ -218,7 +219,7 @@ public class Cache extends BaseHashMap {
      */
     CachedObject release(long pos) {
 
-        CachedObject r = (CachedObject) addOrRemoveObject(null, pos, true);
+        CachedObject r = (CachedObject) addOrRemoveObject(pos, null, true);
 
         if (r == null) {
             return null;
@@ -471,7 +472,8 @@ public class Cache extends BaseHashMap {
         return accessCount;
     }
 
-    static final class CachedObjectComparator implements ObjectComparator {
+    static final class CachedObjectComparator
+    implements Comparator<CachedObject>, ObjectComparator<CachedObject> {
 
         static final int COMPARE_LAST_ACCESS = 0;
         static final int COMPARE_POSITION    = 1;
@@ -486,7 +488,7 @@ public class Cache extends BaseHashMap {
             compareCount = 0;
         }
 
-        public int compare(Object a, Object b) {
+        public int compare(CachedObject a, CachedObject b) {
 
             long diff;
 
@@ -495,13 +497,11 @@ public class Cache extends BaseHashMap {
             switch (compareType) {
 
                 case COMPARE_POSITION :
-                    diff = ((CachedObject) a).getPos()
-                           - ((CachedObject) b).getPos();
+                    diff = a.getPos() - b.getPos();
                     break;
 
                 case COMPARE_SIZE :
-                    diff = ((CachedObject) a).getStorageSize()
-                           - ((CachedObject) b).getStorageSize();
+                    diff = a.getStorageSize() - b.getStorageSize();
                     break;
 
                 default :
@@ -513,12 +513,16 @@ public class Cache extends BaseHashMap {
                                         : -1;
         }
 
-        public int hashCode(Object o) {
+        public boolean equals(CachedObject a, CachedObject b) {
+            return compare(a, b) == 0;
+        }
+
+        public int hashCode(CachedObject o) {
             return o.hashCode();
         }
 
-        public long longKey(Object o) {
-            return ((CachedObject) o).getPos();
+        public long longKey(CachedObject o) {
+            return o.getPos();
         }
     }
 }
