@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import org.hsqldb.lib.StringUtil;
  * Manages a .properties file for a database.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.7.0
  */
 public class HsqlDatabaseProperties extends HsqlProperties {
@@ -154,19 +154,19 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
 //#ifdef JAVA8
 
-    public static final String THIS_VERSION         = "2.5.1";
-    public static final String THIS_FULL_VERSION    = "2.5.1";
+    public static final String THIS_VERSION         = "2.6.1";
+    public static final String THIS_FULL_VERSION    = "2.6.1";
     public static final int    MAJOR                = 2,
-                               MINOR                = 5,
+                               MINOR                = 6,
                                REVISION             = 1;
 
 //#else
 /*
-    public static final String THIS_VERSION      = "2.3.8";
-    public static final String THIS_FULL_VERSION = "2.3.8";
+    public static final String THIS_VERSION      = "2.3.9";
+    public static final String THIS_FULL_VERSION = "2.3.9";
     public static final int    MAJOR             = 2,
                                MINOR             = 3,
-                               REVISION          = 8;
+                               REVISION          = 9;
 */
 
 //#endif JAVA8
@@ -293,6 +293,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String sql_ignore_case     = "sql.ignore_case";
     public static final String sql_live_object     = "sql.live_object";
     public static final String sql_sys_index_names = "sql.sys_index_names";
+    public static final String sql_lowercase_ident = "sql.lowercase_ident";
 
     //
     public static final String textdb_cache_scale = "textdb.cache_scale";
@@ -310,7 +311,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String textdb_qc           = "textdb.qc";
     public static final String textdb_null_def     = "textdb.null_def";
 
-    //
+    // obsolete property from version 2.5.1
     public static final String hsqldb_min_reuse = "hsqldb.min_reuse";
 
     static {
@@ -509,6 +510,9 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         dbMeta.put(sql_sys_index_names,
                    HsqlProperties.getMeta(sql_sys_index_names, SQL_PROPERTY,
                                           false));
+        dbMeta.put(sql_lowercase_ident,
+                   HsqlProperties.getMeta(sql_lowercase_ident, SQL_PROPERTY,
+                                          false));
         dbMeta.put(hsqldb_files_space,
                    HsqlProperties.getMeta(hsqldb_files_space, SQL_PROPERTY, 0,
                                           new int[] {
@@ -612,7 +616,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             exists = super.load();
         } catch (Throwable t) {
             throw Error.error(t, ErrorCode.FILE_IO_ERROR,
-                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new Object[] {
+                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new String[] {
                 t.toString(), fileName
             });
         }
@@ -675,7 +679,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             database.logger.logSevereEvent("save failed", t);
 
             throw Error.error(t, ErrorCode.FILE_IO_ERROR,
-                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new Object[] {
+                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new String[] {
                 t.toString(), fileName
             });
         }
