@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -213,7 +213,7 @@ public class HsqlProperties {
 
     public boolean load() throws Exception {
 
-        if (fileName == null || fileName.length() == 0) {
+        if (fileName == null || fileName.isEmpty()) {
             throw new FileNotFoundException(
                 Error.getMessage(ErrorCode.M_HsqlProperties_load));
         }
@@ -244,7 +244,7 @@ public class HsqlProperties {
      */
     public void save() throws Exception {
 
-        if (fileName == null || fileName.length() == 0) {
+        if (fileName == null || fileName.isEmpty()) {
             throw new java.io.FileNotFoundException(
                 Error.getMessage(ErrorCode.M_HsqlProperties_load));
         }
