@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,9 +50,9 @@ import org.hsqldb.Statement;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HsqlByteArrayInputStream;
 import org.hsqldb.lib.LineGroupReader;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.navigator.RowSetNavigator;
 import org.hsqldb.result.Result;
@@ -68,7 +68,7 @@ import org.hsqldb.types.Types;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public class LobManager {
@@ -123,7 +123,7 @@ public class LobManager {
     Lock          writeLock = lock.writeLock();
 
     // LOBS columns
-    private interface LOBS {
+    interface LOBS {
 
         int BLOCK_ADDR   = 0;
         int BLOCK_COUNT  = 1;
@@ -250,7 +250,7 @@ public class LobManager {
 
         sysLobSession = database.sessionManager.getSysLobSession();
 
-        HashMappedList map = LineGroupReader.getStatementMap(resourceFileName);
+        OrderedHashMap map = LineGroupReader.getStatementMap(resourceFileName);
         String         sql = (String) map.get("/*lob_schema_definition*/");
         Statement      statement = sysLobSession.compileStatement(sql);
         Result         result    = statement.execute(sysLobSession);
@@ -551,6 +551,10 @@ public class LobManager {
         return usageChanged;
     }
 
+    public void setUsageChanged() {
+        usageChanged += lobBlockSize;
+    }
+
     public Result deleteUnusedLobs() {
 
         writeLock.lock();
@@ -563,6 +567,7 @@ public class LobManager {
             long           limitLobID = Long.MAX_VALUE;
             ResultMetaData meta = deleteUnusedLobs.getParametersMetaData();
             Object[]       params     = new Object[meta.getColumnCount()];
+            int            deleteCount = 0;
 
             params[0] = Long.valueOf(limitLobID);
 
@@ -575,9 +580,9 @@ public class LobManager {
             }
 
             if (params[1] != null) {
-                int total = ((Number) params[1]).intValue();
+                deleteCount = ((Number) params[1]).intValue();
 
-                if (total < 1) {
+                if (deleteCount < 1) {
                     return Result.updateZeroResult;
                 }
             }
@@ -630,7 +635,7 @@ public class LobManager {
                     "lob file reported smaller than usage");
             }
 
-            return Result.updateOneResult;
+            return Result.newUpdateCountResult(deleteCount);
         } finally {
             writeLock.unlock();
         }
@@ -752,7 +757,7 @@ public class LobManager {
         }
     }
 
-    /** @todo - implement as compareText() */
+    /* @todo - implement as compareText() */
     public int compare(Collation collation, long lobId, String b) {
 
         writeLock.lock();
@@ -767,11 +772,11 @@ public class LobManager {
             int aOffset = 0;
 
             if (aLength == 0) {
-                return b.length() == 0 ? 0
-                                       : -1;
+                return b.isEmpty() ? 0
+                                   : -1;
             }
 
-            if (b.length() == 0) {
+            if (b.isEmpty()) {
                 return 1;
             }
 
@@ -919,7 +924,7 @@ public class LobManager {
                                  : -1;
     }
 
-    /** @todo - word-separator and end block zero issues */
+    /* @todo - word-separator and end block zero issues */
     private int compareTextNormal(Collation collation, long aID, long bID) {
 
         Object[] data    = getLobHeader(aID);
@@ -1124,7 +1129,7 @@ public class LobManager {
         }
     }
 
-    /** @todo - currently unused and returns whole length */
+    /* @todo - currently unused and returns whole length */
     public Result getTruncateLength(long lobID) {
 
         writeLock.lock();
