@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -295,11 +295,11 @@ public class RAShadowFile {
             return count;
         }
 
-        public long skip(long count) throws IOException {
+        public long skip(long count) {
             return 0;
         }
 
-        public int available() throws IOException {
+        public int available() {
             return 0;
         }
 
