@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,7 +63,7 @@ import org.hsqldb.types.Type;
  * Base implementation of PersistentStore for different table types.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.9.0
  */
 public abstract class RowStoreAVL implements PersistentStore {
@@ -172,7 +172,8 @@ public abstract class RowStoreAVL implements PersistentStore {
                                           int[] colMap, boolean isMV) {
 
         synchronized (row) {
-            return RowAction.addDeleteAction(session, table, row, colMap);
+            return RowAction.addDeleteAction(session, table, this, row,
+                                             colMap);
         }
     }
 
@@ -358,6 +359,10 @@ public abstract class RowStoreAVL implements PersistentStore {
         return index.firstRow(this);
     }
 
+    public void setAccessors(long base, long[] accessors, long cardinality) {
+        throw Error.runtimeError(ErrorCode.U_S0500, "RowStoreAVL");
+    }
+
     public void setAccessor(Index key, CachedObject accessor) {
         accessorList[key.getPosition()] = accessor;
     }
@@ -523,7 +528,7 @@ public abstract class RowStoreAVL implements PersistentStore {
         return 0;
     }
 
-    public void setElementCount(Index key, long size, long uniqueSize) {
+    final void setElementCount(long size) {
         elementCount.set(size);
     }
 
@@ -760,7 +765,7 @@ public abstract class RowStoreAVL implements PersistentStore {
                     break;
                 }
 
-                backnode = ((RowAVL) row).getNode(position - 1);
+                backnode       = ((RowAVL) row).getNode(position - 1);
                 backnode.nNext = backnode.nNext.nNext;
             }
 
