@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -119,7 +119,7 @@ public class RowStoreAVLDiskData extends RowStoreAVL {
             object.setPos(pos);
 
             if (tx) {
-                RowAction.addInsertAction(session, table, (Row) object);
+                RowAction.addInsertAction(session, table, this, (Row) object);
             }
 
             cache.add(object, false);
@@ -130,15 +130,11 @@ public class RowStoreAVLDiskData extends RowStoreAVL {
 
     public CachedObject get(RowInputInterface in) {
 
-        try {
-            RowAVLDiskData row = new RowAVLDiskData(this, table, in);
+        RowAVLDiskData row = new RowAVLDiskData(this, table, in);
 
-            cache.cache.put(row);
+        cache.cache.put(row);
 
-            return row;
-        } catch (IOException e) {
-            throw Error.error(ErrorCode.TEXT_FILE_IO, e);
-        }
+        return row;
     }
 
     public CachedObject get(CachedObject object, RowInputInterface in) {
