@@ -69,7 +69,7 @@ import org.hsqldb.types.Type;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public class Result {
@@ -255,7 +255,7 @@ public class Result {
 
     public static Result newResult(Session session, int mode,
                                    DataInputStream dataInput,
-                                   RowInputInterface in) throws IOException {
+                                   RowInputInterface in) {
 
         try {
             if (mode == ResultConstants.LARGE_OBJECT_OP) {
@@ -499,8 +499,7 @@ public class Result {
                 result.queryTimeout = in.readShort();
 
                 Statement statement =
-                    session.statementManager.getStatement(session,
-                        result.statementID);
+                    session.statementManager.getStatement(result.statementID);
 
                 if (statement == null) {
 
@@ -851,13 +850,12 @@ public class Result {
         return result;
     }
 
-    public static Result newDoubleColumnResult(String colNameA,
-            String colNameB) {
+    public static Result newMultiColumnResult(String[] names,
+            Type[] types) {
 
-        Result result = newResult(ResultConstants.DATA);
+        Result   result = newResult(ResultConstants.DATA);
 
-        result.metaData = ResultMetaData.newDoubleColumnMetaData(colNameA,
-                colNameB);
+        result.metaData  = ResultMetaData.newMetaData(names, types);
         result.navigator = new RowSetNavigatorClient(8);
 
         return result;
@@ -1626,15 +1624,6 @@ public class Result {
         }
     }
 
-    public void addRow(String[] sql) {
-
-        if (sql == null) {
-            return;
-        }
-
-        initialiseNavigator().add(sql);
-    }
-
     private static Object[] readSimple(RowInputInterface in,
                                        ResultMetaData meta)
                                        throws IOException {
