@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -72,7 +72,7 @@ import org.hsqldb.types.Type;
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  * @author Blaine Simpson (blaine dot simpson at admc dot com)
  *
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.8.0
  */
 public class Grantee implements SchemaObject {
@@ -318,7 +318,7 @@ public class Grantee implements SchemaObject {
             }
         }
 
-        Iterator it = directRightsMap.get(name);
+        Iterator it = directRightsMap.getValuesIterator(name);
 
         while (it.hasNext()) {
             Right existing = (Right) it.next();
@@ -373,7 +373,7 @@ public class Grantee implements SchemaObject {
             name = ((Routine) object).getSpecificName();
         }
 
-        Iterator it       = directRightsMap.get(name);
+        Iterator it       = directRightsMap.getValuesIterator(name);
         Right    existing = null;
 
         while (it.hasNext()) {
@@ -431,7 +431,7 @@ public class Grantee implements SchemaObject {
      */
     void updateRightsForNewColumn(HsqlName tableName, HsqlName columnName) {
 
-        Iterator it       = directRightsMap.get(tableName);
+        Iterator it       = directRightsMap.getValuesIterator(tableName);
         Right    existing = null;
 
         while (it.hasNext()) {
@@ -451,7 +451,7 @@ public class Grantee implements SchemaObject {
      */
     void updateRightsForNewColumn(HsqlName tableName) {
 
-        Iterator it       = grantedRightsMap.get(tableName);
+        Iterator it       = grantedRightsMap.getValuesIterator(tableName);
         Right    existing = null;
 
         while (it.hasNext()) {
@@ -513,7 +513,7 @@ public class Grantee implements SchemaObject {
             name = ((Routine) object).getSpecificName();
         }
 
-        Iterator rights = directRightsMap.get(name);
+        Iterator rights = directRightsMap.getValuesIterator(name);
 
         if (rights.hasNext()) {
             OrderedHashSet set = new OrderedHashSet();
@@ -536,7 +536,7 @@ public class Grantee implements SchemaObject {
             name = ((Routine) object).getSpecificName();
         }
 
-        Iterator rights = grantedRightsMap.get(name);
+        Iterator rights = grantedRightsMap.getValuesIterator(name);
 
         if (rights.hasNext()) {
             OrderedHashSet set = new OrderedHashSet();
@@ -697,10 +697,10 @@ public class Grantee implements SchemaObject {
      * Checks if this object can modify schema objects or grant access rights
      * to them.
      */
-    public void checkSchemaUpdateOrGrantRights(String schemaName) {
+    public void checkSchemaUpdateOrGrantRights(HsqlName schemaName) {
 
         if (!hasSchemaUpdateOrGrantRights(schemaName)) {
-            throw Error.error(ErrorCode.X_42501, schemaName);
+            throw Error.error(ErrorCode.X_42501, schemaName.name);
         }
     }
 
@@ -708,7 +708,7 @@ public class Grantee implements SchemaObject {
      * Checks if this object can modify schema objects or grant access rights
      * to them.
      */
-    public boolean hasSchemaUpdateOrGrantRights(String schemaName) {
+    public boolean hasSchemaUpdateOrGrantRights(HsqlName schemaName) {
 
         // If a DBA
         if (isAdmin()) {
@@ -716,7 +716,8 @@ public class Grantee implements SchemaObject {
         }
 
         Grantee schemaOwner =
-            granteeManager.database.schemaManager.toSchemaOwner(schemaName);
+            granteeManager.database.schemaManager.toSchemaOwner(
+                schemaName.name);
 
         // If owner of Schema
         if (schemaOwner == this) {
@@ -806,6 +807,13 @@ public class Grantee implements SchemaObject {
         return isAdmin || hasRole(granteeManager.changeAuthRole);
     }
 
+    /**
+     * Returns true if this Grantee can change to a different user.
+     */
+    public boolean canPerformScriptOps() {
+        return isAdmin || hasRole(granteeManager.scriptOpsRole);
+    }
+
     /**
      * Returns true if this grantee object is for the PUBLIC role.
      */
@@ -928,10 +936,8 @@ public class Grantee implements SchemaObject {
     /**
      * Method used with all Grantee objects to set the full set of rights
      * according to those inherited form ROLE Grantee objects and those
-     * granted to the object itself.
-     */
-
-    /**
+     * granted to the object itself.<p>
+     *
      * @todo -- see if this is correct and the currentRole.fullRightsMap
      * is always updated prior to being added to this.fullRightsMap
      */
@@ -997,7 +1003,7 @@ public class Grantee implements SchemaObject {
 
         while (it.hasNext()) {
             Object   key      = it.next();
-            Iterator values   = map.get(key);
+            Iterator values   = map.getValuesIterator(key);
             Right    existing = (Right) fullRightsMap.get(key);
 
             while (values.hasNext()) {
@@ -1119,7 +1125,7 @@ public class Grantee implements SchemaObject {
         HsqlArrayList list       = new HsqlArrayList();
         String        roleString = roleMapToString(roles);
 
-        if (roleString.length() != 0) {
+        if (!roleString.isEmpty()) {
             StringBuilder sb = new StringBuilder(128);
 
             sb.append(Tokens.T_GRANT).append(' ').append(roleString);
@@ -1133,7 +1139,7 @@ public class Grantee implements SchemaObject {
 
         while (dbObjects.hasNext()) {
             Object   nameObject = dbObjects.next();
-            Iterator rights     = rightsMap.get(nameObject);
+            Iterator rights     = rightsMap.getValuesIterator(nameObject);
 
             while (rights.hasNext()) {
                 Right         right    = (Right) rights.next();
