@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,10 +46,10 @@ import org.hsqldb.Tokens;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.Collection;
-import org.hsqldb.lib.HashMappedList;
 import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.IntValueHashMap;
 import org.hsqldb.lib.Iterator;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.lib.OrderedHashSet;
 import org.hsqldb.lib.Set;
 import org.hsqldb.lib.StringConverter;
@@ -65,7 +65,7 @@ import org.hsqldb.lib.java.JavaSystem;
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  * @author Blaine Simpson (blaine dot simpson at admc dot com)
  *
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.8.0
  * @see Grantee
  */
@@ -97,13 +97,13 @@ public class GranteeManager {
      * Map of grantee-String-to-Grantee-objects.<p>
      * Keys include all USER and ROLE names
      */
-    private HashMappedList map = new HashMappedList();
+    private OrderedHashMap map = new OrderedHashMap();
 
     /**
      * Map of role-Strings-to-Grantee-object.<p>
      * Keys include all ROLES names
      */
-    private HashMappedList roleMap = new HashMappedList();
+    private OrderedHashMap roleMap = new OrderedHashMap();
 
     /**
      * Used only to pass the SchemaManager to Grantees for checking
@@ -141,6 +141,11 @@ public class GranteeManager {
      */
     Grantee changeAuthRole;
 
+    /**
+     * The role for script operations rights.
+     */
+    Grantee scriptOpsRole;
+
     /**
      * Construct the GranteeManager for a Database. Construct special Grantee
      * objects for _SYSTEM, PUBLIC and DBA, and add them to the Grantee map.
@@ -181,6 +186,13 @@ public class GranteeManager {
                 SchemaObject.GRANTEE));
 
         changeAuthRole = getRole(SqlInvariants.CHANGE_AUTH_ROLE_NAME);
+
+        addRole(
+            this.database.nameManager.newHsqlName(
+                SqlInvariants.SCRIPT_OPS_ROLE_NAME, false,
+                SchemaObject.GRANTEE));
+
+        scriptOpsRole = getRole(SqlInvariants.SCRIPT_OPS_ROLE_NAME);
     }
 
     static final IntValueHashMap rightsStringLookup = new IntValueHashMap(7);
@@ -218,7 +230,7 @@ public class GranteeManager {
      *  table.getName(); if a different HsqlName
      *  object with an identical name attribute is specified, then
      *  rights checks and tests will fail, since the HsqlName
-     *  class implements its {@link HsqlName#hashCode hashCode} and
+     *  class implements its {@link HsqlName#hashCode() hashCode} and
      *  {@link HsqlName#equals equals} methods based on pure object
      *  identity, rather than on attribute values. <p>
      */
@@ -353,7 +365,7 @@ public class GranteeManager {
 
             // campbell-burnet@users
 
-            /** @todo: Correct reporting of actual grant path */
+            /* @todo: Correct reporting of actual grant path */
             throw Error.error(ErrorCode.X_0P501, roleName);
         }
 
@@ -390,11 +402,11 @@ public class GranteeManager {
 
             if (grant) {
                 if (grantee.getDirectRoles().contains(role)) {
-                    /** no-op */
+                    /* no-op */
                 }
             } else {
                 if (!grantee.getDirectRoles().contains(role)) {
-                    /** no-op */
+                    /* no-op */
                 }
             }
 
@@ -757,7 +769,8 @@ public class GranteeManager {
         return name.equals(SqlInvariants.SYSTEM_AUTHORIZATION_NAME)
                || name.equals(SqlInvariants.DBA_ADMIN_ROLE_NAME)
                || name.equals(SqlInvariants.SCHEMA_CREATE_ROLE_NAME)
-               || name.equals(SqlInvariants.CHANGE_AUTH_ROLE_NAME);
+               || name.equals(SqlInvariants.CHANGE_AUTH_ROLE_NAME)
+               || name.equals(SqlInvariants.SCRIPT_OPS_ROLE_NAME);
     }
 
     public static boolean isReserved(String name) {
@@ -766,6 +779,7 @@ public class GranteeManager {
                || name.equals(SqlInvariants.DBA_ADMIN_ROLE_NAME)
                || name.equals(SqlInvariants.SCHEMA_CREATE_ROLE_NAME)
                || name.equals(SqlInvariants.CHANGE_AUTH_ROLE_NAME)
+               || name.equals(SqlInvariants.SCRIPT_OPS_ROLE_NAME)
                || name.equals(SqlInvariants.PUBLIC_ROLE_NAME);
     }
 
