@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -60,7 +60,7 @@ import org.hsqldb.types.Type;
  * corresponds to ScriptWriterText.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- *  @version 2.5.1
+ *  @version 2.6.0
  *  @since 1.7.2
  */
 public class ScriptReaderText extends ScriptReaderBase {
@@ -366,8 +366,8 @@ public class ScriptReaderText extends ScriptReaderBase {
 
         return Error.error(t, ErrorCode.ERROR_IN_SCRIPT_FILE,
                            ErrorCode.M_DatabaseScriptReader_read,
-                           new Object[] {
-            Long.valueOf(lineCount), t.toString()
+                           new String[] {
+            String.valueOf(lineCount), t.toString()
         });
     }
 
