@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@ import org.hsqldb.result.Result;
 import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.TimestampData;
 
-/**
+/*
  * @todo - can lock the database engine as readonly in a wrapper for this when
  * used at checkpoint
  */
@@ -279,7 +279,7 @@ public abstract class ScriptWriterBase implements Runnable {
             fileStreamOut = new BufferedOutputStream(fos, 1 << 14);
         } catch (IOException e) {
             throw Error.error(e, ErrorCode.FILE_IO_ERROR,
-                              ErrorCode.M_Message_Pair, new Object[] {
+                              ErrorCode.M_Message_Pair, new String[] {
                 e.toString(), outFile
             });
         }
@@ -484,7 +484,7 @@ public abstract class ScriptWriterBase implements Runnable {
                 sync();
             }
 
-            /** @todo: can do Cache.cleanUp() here, too */
+            /* @todo: can do Cache.cleanUp() here, too */
         } catch (Exception e) {
 
             // ignore exceptions
