@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,8 +39,10 @@ import java.net.Socket;
 import java.net.UnknownHostException;
 import java.sql.DriverManager;
 import java.util.Enumeration;
+import java.util.Properties;
 import java.util.StringTokenizer;
 
+import org.hsqldb.Database;
 import org.hsqldb.DatabaseManager;
 import org.hsqldb.DatabaseURL;
 import org.hsqldb.HsqlDateTime.SystemTimeString;
@@ -61,8 +63,6 @@ import org.hsqldb.resources.ResourceBundleHandler;
 import org.hsqldb.result.Result;
 import org.hsqldb.result.ResultConstants;
 
-import java.util.Properties;
-
 // fredt@users 20020215 - patch 1.7.0
 // methods reorganised to use new HsqlProperties class
 // fredt@users 20020424 - patch 1.7.0 - shutdown without exit
@@ -78,7 +78,7 @@ import java.util.Properties;
 // unnecessary and could cause deadlock
 
 /**
- * The HSQLDB HSQL protocol network database server. <p>
+ * The HyperSQL hsql: and hsqls: protocol network database server. <p>
  *
  * A Server object acts as a network database server and is one way of using
  * the client-server mode of HSQLDB Database Engine. Instances of this
@@ -234,7 +234,7 @@ import java.util.Properties;
  * is started as part of a larger framework. <p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.7.2
  */
 public class Server implements HsqlSocketRequestHandler, Notified {
@@ -248,7 +248,8 @@ public class Server implements HsqlSocketRequestHandler, Notified {
     ServerProperties serverProperties;
 
 //
-    HashSet serverConnSet;
+    HashSet      serverConnSet;
+    final Object serverConnSetSync = new Object();
 
 //  As of HSQLDB 1.9.0, the following arrays are used starting from 0.
 //  The indexes do not correspond to the user-specified indexes.
@@ -398,7 +399,7 @@ public class Server implements HsqlSocketRequestHandler, Notified {
 
         printWithThread("signalCloseAllServerConnections() entered");
 
-        synchronized (serverConnSet) {
+        synchronized (serverConnSetSync) {
 
             // snapshot
             array = new ServerConnection[serverConnSet.size()];
@@ -1009,10 +1010,9 @@ public class Server implements HsqlSocketRequestHandler, Notified {
     }
 
     /**
-     * Sets whether server thread is a daemon. Used before starting.
-     * The default is false.
+     * No-op as deprecated.
      *
-     * @param daemon if true, start the thread as a daemon thread
+     * @param daemon ignored
      */
     public void setDaemon(boolean daemon) {
 
@@ -1247,6 +1247,8 @@ public class Server implements HsqlSocketRequestHandler, Notified {
         for (int i = 0; i < dbID.length; i++) {
             if (dbAlias[i] != null) {
                 shutdown = false;
+
+                break;
             }
         }
 
@@ -1279,7 +1281,7 @@ public class Server implements HsqlSocketRequestHandler, Notified {
             }
         }
 
-        synchronized (serverConnSet) {
+        synchronized (serverConnSetSync) {
             array = new ServerConnection[serverConnSet.size()];
 
             serverConnSet.toArray(array);
@@ -1892,7 +1894,7 @@ public class Server implements HsqlSocketRequestHandler, Notified {
                     ServerConfiguration.listLocalInetAddressNames();
 
                 int      messageID;
-                Object[] messageParameters;
+                String[] messageParameters;
 
                 if (candidateAddrs.length > 0) {
                     messageID = ErrorCode.M_SERVER_OPEN_SERVER_SOCKET_1;
@@ -1907,12 +1909,12 @@ public class Server implements HsqlSocketRequestHandler, Notified {
                         sb.append(candidateAddrs[i]);
                     }
 
-                    messageParameters = new Object[] {
+                    messageParameters = new String[] {
                         address, sb.toString()
                     };
                 } else {
                     messageID = ErrorCode.M_SERVER_OPEN_SERVER_SOCKET_2;
-                    messageParameters = new Object[]{ address };
+                    messageParameters = new String[]{ address };
                 }
 
                 throw new UnknownHostException(Error.getMessage(messageID, 0,
@@ -2007,9 +2009,8 @@ public class Server implements HsqlSocketRequestHandler, Notified {
      */
     private void run() {
 
-        StopWatch   sw;
-        ThreadGroup tg;
-        String      tgName;
+        StopWatch sw;
+        String    tgName;
 
         printWithThread("run() entered");
         print("Initiating startup sequence...");
@@ -2036,11 +2037,7 @@ public class Server implements HsqlSocketRequestHandler, Notified {
 
         tgName = "HSQLDB Connections @"
                  + Integer.toString(this.hashCode(), 16);
-        tg = new ThreadGroup(tgName);
-
-        tg.setDaemon(false);
-
-        serverConnectionThreadGroup = tg;
+        serverConnectionThreadGroup = new ThreadGroup(tgName);
 
         // Mount the databases this server is supposed to host.
         // This may take some time if the databases are not all
@@ -2105,14 +2102,20 @@ public class Server implements HsqlSocketRequestHandler, Notified {
      * The shutdownMode must be one of:
      *
      * <ul>
-     * <li>org.hsqldb.Database.CLOSEMODE_IMMEDIATELY
-     * <li>org.hsqldb.Database.CLOSEMODE_NORMAL
-     * <li>org.hsqldb.Database.CLOSEMODE_COMPACT
-     * <li>org.hsqldb.Database.CLOSEMODE_SCRIPT
+     * <li>org.hsqldb.Database.CLOSEMODE_IMMEDIATELY = 1
+     * <li>org.hsqldb.Database.CLOSEMODE_NORMAL = 2
+     * <li>org.hsqldb.Database.CLOSEMODE_COMPACT = 3
+     * <li>org.hsqldb.Database.CLOSEMODE_SCRIPT = 4
      * </ul>
-     * @param shutdownMode a value between 0-4, usually 0 or 1.
+     * @param shutdownMode a value between 1-4, usually 2 for NORMAL.
      */
     public void shutdownCatalogs(int shutdownMode) {
+
+        if (shutdownMode < Database.CLOSEMODE_IMMEDIATELY
+                || shutdownMode > Database.CLOSEMODE_SCRIPT) {
+            throw new IllegalArgumentException("must be between 1 and 4");
+        }
+
         DatabaseManager.shutdownDatabases(this, shutdownMode);
     }
 
@@ -2125,15 +2128,20 @@ public class Server implements HsqlSocketRequestHandler, Notified {
      * The shutdownMode must be one of:
      *
      * <ul>
-     * <li>org.hsqldb.Database.CLOSEMODE_IMMEDIATELY
-     * <li>org.hsqldb.Database.CLOSEMODE_NORMAL
-     * <li>org.hsqldb.Database.CLOSEMODE_COMPACT
-     * <li>org.hsqldb.Database.CLOSEMODE_SCRIPT
+     * <li>org.hsqldb.Database.CLOSEMODE_IMMEDIATELY = 1
+     * <li>org.hsqldb.Database.CLOSEMODE_NORMAL = 2
+     * <li>org.hsqldb.Database.CLOSEMODE_COMPACT = 3
+     * <li>org.hsqldb.Database.CLOSEMODE_SCRIPT = 4
      * </ul>
-     * @param shutdownMode a value between 0-4, usually 0 or 1.
+     * @param shutdownMode a value between 1-4, usually 2 for NORMAL.
      */
     public void shutdownWithCatalogs(int shutdownMode) {
 
+        if (shutdownMode < Database.CLOSEMODE_IMMEDIATELY
+                || shutdownMode > Database.CLOSEMODE_SCRIPT) {
+            throw new IllegalArgumentException("must be between 1 and 4");
+        }
+
         // If an unchecked exception is thrown, isShuttingDown will be left true,
         // which is good from a security standpoint.
         isShuttingDown = true;
@@ -2181,28 +2189,15 @@ public class Server implements HsqlSocketRequestHandler, Notified {
         // Be nice and let applications exit if there are no
         // running connection threads - wait at most 100 ms per active thread
         if (serverConnectionThreadGroup != null) {
-            if (!serverConnectionThreadGroup.isDestroyed()) {
-                int count = serverConnectionThreadGroup.activeCount();
-
-                for (; count > 0
-                        && serverConnectionThreadGroup.activeCount() > 0;
-                        count--) {
-                    try {
-                        Thread.sleep(100);
-                    } catch (Exception e) {
-
-                        // e.getMessage();
-                    }
-                }
+            int count = serverConnectionThreadGroup.activeCount();
 
+            for (; count > 0 && serverConnectionThreadGroup.activeCount() > 0;
+                    count--) {
                 try {
-                    serverConnectionThreadGroup.destroy();
-                    printWithThread(serverConnectionThreadGroup.getName()
-                                    + " destroyed");
-                } catch (Throwable t) {
-                    printWithThread(serverConnectionThreadGroup.getName()
-                                    + " not destroyed");
-                    printWithThread(t.toString());
+                    Thread.sleep(100);
+                } catch (Exception e) {
+
+                    // e.getMessage();
                 }
             }
 
@@ -2295,9 +2290,9 @@ public class Server implements HsqlSocketRequestHandler, Notified {
     }
 
     /**
-     * Creates and starts a new Server.  <p>
+     * Creates and starts a new Server.<p>
      *
-     * Allows starting a Server via the command line interface. <p>
+     * Allows starting a Server via the command line interface.<p>
      *
      * @param args the command line arguments for the Server instance
      */
