@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2020, The HSQL Development Group
+ * Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -122,7 +122,7 @@ import org.hsqldb.types.Type;
  *
  * @author Blaine Simpson (unsaved@users dot sourceforge.net
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  * @since 1.6.2
  */
 class ServerConnection implements Runnable {
@@ -198,7 +198,7 @@ class ServerConnection implements Runnable {
         this.server  = server;
         this.mThread = mCurrentThread.getAndIncrement();
 
-        synchronized (server.serverConnSet) {
+        synchronized (server.serverConnSetSync) {
             server.serverConnSet.add(this);
         }
     }
@@ -246,7 +246,7 @@ class ServerConnection implements Runnable {
             socket = null;
         }
 
-        synchronized (server.serverConnSet) {
+        synchronized (server.serverConnSetSync) {
             server.serverConnSet.remove(this);
         }
 
@@ -456,7 +456,7 @@ class ServerConnection implements Runnable {
             throw cleanExit;    // not "clean", but handled
         }
 
-        /**
+        /*
          * ODBC Service State Machine  (the remainder of this method)
          */
         switch (odbcCommMode) {
@@ -618,7 +618,7 @@ class ServerConnection implements Runnable {
                         }
                     }
 
-                    /** ******************************************* */
+                    /* ******************************************* */
                     String normalized = sql.trim().toLowerCase();
 
                     if (server.isTrace()) {
@@ -1630,7 +1630,7 @@ class ServerConnection implements Runnable {
      * if client connects with hsqls to a https server; or
      * hsql to a http server.
      * All other client X server combinations are handled gracefully.
-     * <P/>
+     * <P>
      * If returns (a.o.t. throws), then state variable streamProtocol will
      * be set.
      *
@@ -2010,7 +2010,7 @@ class ServerConnection implements Runnable {
 
     class OdbcInResultProcessor implements InResultProcessor {
 
-        public void receiveConnection(int type) throws CleanExit, IOException {
+        public void receiveConnection(int type) throws IOException {
             ServerConnection.this.odbcConnect(type);
         }
 
