@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -259,8 +259,7 @@ class WebServerConnection implements Runnable {
      * POST is used only for database access. So we can assume the strings
      * are those generated by ClientConnectionHTTP
      */
-    private void processPost(InputStream inStream,
-                             String name) throws IOException {
+    private void processPost(InputStream inStream, String name) {
 
         try {
 
