@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,14 +38,14 @@ import java.util.Vector;
 
 import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.HsqlDeque;
-import org.hsqldb.lib.HsqlList;
 import org.hsqldb.lib.Iterator;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.StopWatch;
 
 import junit.framework.TestCase;
 
 /**
- * Randomly excutes methods on the HsqlList data structures and compares the
+ * Randomly excutes methods on the Hsql List data structures and compares the
  * results with equivalent calls on the java vector class.
  *
  * @author dnordahl@users
@@ -365,7 +365,7 @@ public class TestDataStructures extends TestCase {
     }
 
     /** Tells whether the given list contains the same data as the vector */
-    private boolean equalsVector(HsqlList list, Vector vector) {
+    private boolean equalsVector(List list, Vector vector) {
 
         if (list.size() != vector.size()) {
             return false;
@@ -429,7 +429,7 @@ public class TestDataStructures extends TestCase {
 
         randomGenerator = new Random(System.currentTimeMillis());
 
-        int           TEST_RUNS     = 100000;
+        int           TEST_RUNS     = 1000000;
         int           LOOP_COUNT    = 1000;
         HsqlArrayList arrayList     = new HsqlArrayList(TEST_RUNS);
         ArrayList     utilArrayList = new ArrayList(TEST_RUNS);
@@ -451,7 +451,7 @@ public class TestDataStructures extends TestCase {
         }
 
         System.out.println(
-            sw.currentElapsedTimeToMessage("time HsqlArrayLsit"));
+            sw.currentElapsedTimeToMessage("time HsqlArrayList"));
         sw.zero();
 
         for (int i = 0; i < TEST_RUNS; i++) {
