@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,6 +50,7 @@ import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.LineGroupReader;
 import org.hsqldb.lib.StopWatch;
 import org.hsqldb.lib.StringComparator;
+import org.hsqldb.lib.StringConverter;
 import org.hsqldb.lib.StringUtil;
 
 /**
@@ -143,8 +144,7 @@ public class TestUtil {
 
             filelist = new File(absolute).list();
 
-            ArraySort.sort((Object[]) filelist, filelist.length,
-                           new StringComparator());
+            ArraySort.sort(filelist, filelist.length, new StringComparator());
 
             for (int i = 0; i < filelist.length; i++) {
                 String fname = filelist[i];
@@ -173,7 +173,7 @@ public class TestUtil {
         }
     }
 
-    static void testScript(Connection aConnection, String aPath) {
+    public static void testScript(Connection aConnection, String aPath) {
 
         /*
          * This is a legacy wrapper method which purposefully inherits the sins
@@ -214,7 +214,7 @@ public class TestUtil {
 
         System.out.println("Opened test script file: " + sourceName);
 
-        /**
+        /*
          * we read the lines from the start of one section of the script "/*"
          *  until the start of the next section, collecting the lines in the
          *  list.
@@ -323,12 +323,12 @@ public class TestUtil {
         if (pSection instanceof DisplaySection
                 || pSection instanceof WaitSection
                 || pSection instanceof ProceedSection) {
-            String s = pSection.getResultString();
+            String resultString = pSection.getResultString();
 
-            if (s != null) {
+            if (resultString != null) {
 
                 // May or may not want to report line number for these sections?
-                System.out.println(pSection.getResultString());
+                System.out.println(resultString);
             }
         }
 
@@ -336,7 +336,19 @@ public class TestUtil {
             return;    // Do not run test method for DisplaySections.
         }
 
-        if (!pSection.test(stat)) {
+        boolean testResult = pSection.test(stat);
+
+        if (pSection instanceof ResultSetOutputParsedSection) {
+            if (!pSection.getActualResultString().isEmpty()) {
+                System.out.println("Section starting at " + scriptName + ':'
+                                   + line + " displayed a result: "
+                                   + pSection.getTestResultString());
+
+                return;
+            }
+        }
+
+        if (!testResult) {
             System.out.println("Section starting at " + scriptName + ':'
                                + line + " returned an unexpected result: "
                                + pSection.getTestResultString());
@@ -516,9 +528,14 @@ abstract class ParsedSection {
             //Otherwise it will be discarded, and the offset (between the array and the vector)
             //set to 1.
             if (s.length() == 3) {
-                lines = (String[]) linesArray.toArray(1, linesArray.size());
+                lines = new String[linesArray.size() - 1];
+
+                linesArray.toArraySlice(lines, 1, linesArray.size());
             } else {
-                lines    = (String[]) linesArray.toArray();
+                lines = new String[linesArray.size()];
+
+                linesArray.toArray(lines);
+
                 lines[0] = lines[0].substring(3);
             }
 
@@ -548,7 +565,9 @@ abstract class ParsedSection {
                 k--;
             } while (k >= 0);
         } else {
-            lines = (String[]) linesArray.toArray();
+            lines = new String[linesArray.size()];
+
+            linesArray.toArray(lines);
 
             for (k = 0; k < lines.length; k++) {
                 sqlBuff.append(lines[k]);
@@ -685,6 +704,32 @@ abstract class ParsedSection {
 
         return false;
     }
+
+    String[] resultSetToArray(ResultSet results) throws SQLException {
+
+        HsqlArrayList list     = new HsqlArrayList();
+        StringBuilder printVal = new StringBuilder();
+
+        while (results.next()) {
+            for (int j = 0; j < results.getMetaData().getColumnCount(); j++) {
+                if (j != 0) {
+                    printVal.append(',');
+                }
+
+                printVal.append(results.getString(j + 1));
+            }
+
+            printVal.append(LS);
+            list.add(printVal.toString());
+            printVal.setLength(0);
+        }
+
+        String[] array = new String[list.size()];
+
+        list.toArray(array);
+
+        return array;
+    }
 }
 
 /** Represents a ParsedSection for a ResultSet test */
@@ -716,8 +761,7 @@ class ResultSetParsedSection extends ParsedSection {
 
     protected String getResultString() {
 
-        StringBuilder printVal     = new StringBuilder();
-        String[]      expectedRows = getExpectedRows();
+        StringBuilder printVal = new StringBuilder();
 
         for (int i = 0; i < expectedRows.length; i++) {
             printVal.append(expectedRows[i]).append(LS);
@@ -728,8 +772,7 @@ class ResultSetParsedSection extends ParsedSection {
 
     protected String getActualResultString() {
 
-        StringBuilder printVal   = new StringBuilder();
-        String[]      actualRows = getActualRows();
+        StringBuilder printVal = new StringBuilder();
 
         if (actualRows == null) {
             return "no result";
@@ -744,6 +787,8 @@ class ResultSetParsedSection extends ParsedSection {
 
     protected boolean test(Statement aStatement) {
 
+        ResultSet     results  = null;
+
         try {
             try {
 
@@ -763,7 +808,7 @@ class ResultSetParsedSection extends ParsedSection {
 
             //iterate over the ResultSet
             HsqlArrayList list     = new HsqlArrayList(new String[1][], 0);
-            ResultSet     results  = aStatement.getResultSet();
+            results  = aStatement.getResultSet();
             int           colCount = results.getMetaData().getColumnCount();
 
             while (results.next()) {
@@ -776,8 +821,6 @@ class ResultSetParsedSection extends ParsedSection {
                 list.add(row);
             }
 
-            results.close();
-
             actualRows = new String[list.size()];
 
             for (int i = 0; i < list.size(); i++) {
@@ -795,8 +838,7 @@ class ResultSetParsedSection extends ParsedSection {
                 actualRows[i] = sb.toString();
             }
 
-            String[] expectedRows = getExpectedRows();
-            int      count        = 0;
+            int count = 0;
 
             for (; count < list.size(); count++) {
                 if (count < expectedRows.length) {
@@ -861,13 +903,22 @@ class ResultSetParsedSection extends ParsedSection {
                                     break;
                                 }
                             } else if (!actual.equals(expectedFields[i])) {
+                                String actualS = actual;
+
+                                if (results.getMetaData().getColumnClassName(
+                                        i).equals("java.lang.String")) {
+                                    actualS =
+                                        StringConverter.toQuotedString(actualS,
+                                                                       '\'',
+                                                                       true);
+                                }
 
                                 //then the results are different
                                 message = "Expected row " + (count + 1)
                                           + " of the ResultSet to contain:"
                                           + LS + expectedRows[count] + LS
                                           + "but field " + j + " contained "
-                                          + actual;
+                                          + actualS;
 
                                 break;
                             }
@@ -901,25 +952,23 @@ class ResultSetParsedSection extends ParsedSection {
             message = x.toString();
 
             return false;
+        } finally {
+            if (results != null) {
+                try {
+                    results.close();
+                } catch (SQLException e) {}
+            }
         }
 
         return message == null;
     }
-
-    private String[] getExpectedRows() {
-        return expectedRows;
-    }
-
-    private String[] getActualRows() {
-        return actualRows;
-    }
 }
 
 /** Represents a ParsedSection for a ResultSet dump */
 class ResultSetOutputParsedSection extends ParsedSection {
 
     private String   delim = System.getProperty("TestUtilFieldDelimiter", ",");
-    private String[] expectedRows = null;
+    private String[] actualRows = new String[]{};
 
     /**
      * constructs a new instance of ResultSetParsedSection, interpreting
@@ -936,6 +985,17 @@ class ResultSetOutputParsedSection extends ParsedSection {
         return "";
     }
 
+    protected String getActualResultString() {
+
+        StringBuilder result = new StringBuilder();
+
+        for (int i = 0; i < actualRows.length; i++) {
+            result.append(actualRows[i]);
+        }
+
+        return result.toString();
+    }
+
     protected boolean test(Statement aStatement) {
 
         try {
@@ -956,23 +1016,11 @@ class ResultSetOutputParsedSection extends ParsedSection {
             }
 
             //iterate over the ResultSet
-            ResultSet     results  = aStatement.getResultSet();
-            StringBuilder printVal = new StringBuilder();
+            ResultSet results = aStatement.getResultSet();
 
-            while (results.next()) {
-                for (int j = 0; j < results.getMetaData().getColumnCount();
-                        j++) {
-                    if (j != 0) {
-                        printVal.append(',');
-                    }
+            actualRows = this.resultSetToArray(results);
 
-                    printVal.append(results.getString(j + 1));
-                }
-
-                printVal.append(LS);
-            }
-
-            throw new Exception(printVal.toString());
+            return true;
         } catch (Exception x) {
             message = x.toString();
 
@@ -980,8 +1028,31 @@ class ResultSetOutputParsedSection extends ParsedSection {
         }
     }
 
-    private String[] getExpectedRows() {
-        return expectedRows;
+    protected String getTestResultString() {
+
+        StringBuilder b = new StringBuilder();
+
+        b.append(LS + "******" + LS);
+        b.append("Type: ");
+        b.append(getType()).append(LS);
+        b.append("SQL: ").append(getSql()).append(LS);
+
+        if (message != null) {
+            b.append("expected results:").append(LS);
+            b.append(getResultString()).append(LS);
+
+            //check to see if the message field has been populated
+            if (getMessage() != null) {
+                b.append(LS + "message:").append(LS);
+                b.append(getMessage()).append(LS);
+            }
+        }
+
+        b.append("actual results:").append(LS);
+        b.append(getActualResultString());
+        b.append(LS + "******" + LS);
+
+        return b.toString();
     }
 }
 
@@ -1059,7 +1130,9 @@ class WaitSection extends ParsedSection {
 
         /* Can't user the super constructor, since it does funny things when
          * constructing the SQL Buffer, which we don't need. */
-        lines = (String[]) linesArray.toArray();
+        lines = new String[linesArray.size()];
+
+        linesArray.toArray(lines);
 
         int    closeCmd = lines[0].indexOf("*/");
         String cmd      = lines[0].substring(0, closeCmd);
@@ -1151,7 +1224,9 @@ class ProceedSection extends ParsedSection {
 
         /* Can't use the super constructor, since it does funny things when
          * constructing the SQL Buffer, which we don't need. */
-        lines = (String[]) linesArray.toArray();
+        lines = new String[linesArray.size()];
+
+        linesArray.toArray(lines);
 
         int    closeCmd = lines[0].indexOf("*/");
         String cmd      = lines[0].substring(0, closeCmd);
@@ -1396,7 +1471,9 @@ class DisplaySection extends ParsedSection {
 
         /* Can't user the super constructor, since it does funny things when
          * constructing the SQL Buffer, which we don't need. */
-        lines = (String[]) sectionLines.toArray();
+        lines = new String[sectionLines.size()];
+
+        sectionLines.toArray(lines);
 
         int firstSlash = lines[0].indexOf('/');
 
