@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,7 @@ import java.math.BigDecimal;
 import java.text.SimpleDateFormat;
 
 //#ifdef JAVA8
+import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
@@ -61,7 +62,7 @@ import org.hsqldb.lib.StringConverter;
  * Type subclass for DATE, TIME and TIMESTAMP.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.9.0
  */
 public final class DateTimeType extends DTIType {
@@ -769,6 +770,10 @@ public final class DateTimeType extends DTIType {
                         return convertToTypeLimits(session, a);
 
                     case Types.SQL_TIMESTAMP : {
+                        if (!(a instanceof TimestampData)) {
+                            throw Error.error(ErrorCode.X_42561);
+                        }
+
                         TimestampData ts = (TimestampData) a;
                         long seconds = ts.getSeconds()
                                        - session.getZoneSeconds();
@@ -778,6 +783,10 @@ public final class DateTimeType extends DTIType {
                                                  session.getZoneSeconds());
                     }
                     case Types.SQL_DATE : {
+                        if (!(a instanceof TimestampData)) {
+                            throw Error.error(ErrorCode.X_42561);
+                        }
+
                         TimestampData ts = (TimestampData) a;
 
                         return new TimestampData(ts.getSeconds(), 0,
@@ -836,7 +845,7 @@ public final class DateTimeType extends DTIType {
         return convertToType(session, a, otherType);
     }
 
-    /** @todo - check the time zone conversion */
+    /* @todo - check the time zone conversion */
     public Object convertJavaToSQL(SessionInterface session, Object a) {
 
         if (a == null) {
@@ -926,16 +935,24 @@ public final class DateTimeType extends DTIType {
                 if (a instanceof java.util.Date) {
                     long millis = ((java.util.Date) a).getTime();
                     long seconds;
-                    int nanos =
-                        DateTimeType.normaliseFraction((int) (millis % 1000)
-                                                       * 1000000, scale);
-                    int zoneSeconds = 0;
+                    int  nanos;
+                    int  zoneSeconds = 0;
 
                     if (typeCode == Types.SQL_TIMESTAMP) {
                         millis = HsqlDateTime.convertMillisFromCalendar(
                             session.getCalendarGMT(), session.getCalendar(),
                             millis);
+
+                        if (a instanceof java.sql.Date) {
+                            millis = HsqlDateTime.getNormalisedDate(
+                                session.getCalendarGMT(), millis);
+                        }
                     } else {
+                        if (a instanceof java.sql.Date) {
+                            millis = HsqlDateTime.getNormalisedDate(
+                                session.getCalendarGMT(), millis);
+                        }
+
                         zoneSeconds =
                             HsqlDateTime.getZoneMillis(
                                 session.getCalendar(), millis) / 1000;
@@ -948,6 +965,14 @@ public final class DateTimeType extends DTIType {
                         throw Error.error(ErrorCode.X_22008);
                     }
 
+                    if (a instanceof java.sql.Timestamp) {
+                        nanos = ((java.sql.Timestamp) a).getNanos();
+                        nanos = DateTimeType.normaliseFraction(nanos, scale);
+                    } else {
+                        nanos = DateTimeType.normaliseFraction(
+                            (int) (millis % 1000) * 1000000, scale);
+                    }
+
                     return new TimestampData(seconds, nanos, zoneSeconds);
                 }
 
@@ -1023,6 +1048,33 @@ public final class DateTimeType extends DTIType {
                         session.getCalendarGMT(), seconds * 1000) / 1000;
             }
 
+            return new TimestampData(seconds, nanos, zoneSeconds);
+        } else if (a instanceof java.time.Instant) {
+            Instant ins = (Instant) a;
+
+            seconds = ins.getEpochSecond();
+
+            if (timestamp) {
+                nanos   = ins.getNano();
+
+                if (nanos < 0) {
+                    nanos += DTIType.limitNanoseconds;
+
+                    seconds--;
+                }
+                nanos       = DateTimeType.normaliseFraction(nanos, scale);
+                zoneSeconds = session.getZoneSeconds();
+
+                if (!withTimeZone) {
+                    seconds += zoneSeconds;
+                }
+            } else {
+                seconds += zoneSeconds;
+                seconds =
+                    HsqlDateTime.getNormalisedDate(
+                        session.getCalendarGMT(), seconds * 1000) / 1000;
+            }
+
             return new TimestampData(seconds, nanos, zoneSeconds);
         }
 
@@ -1032,21 +1084,21 @@ public final class DateTimeType extends DTIType {
     TimeData convertJavaTimeObject(SessionInterface session, Object a) {
 
         int seconds;
-        int nanos       = 0;
+        int nanos;
         int zoneSeconds = 0;
 
         if (a instanceof java.time.OffsetTime) {
             OffsetTime ot     = (OffsetTime) a;
-            int        offset = ot.get(ChronoField.OFFSET_SECONDS);
 
             seconds = ot.toLocalTime().toSecondOfDay();
             nanos   = ot.getNano();
             nanos   = DateTimeType.normaliseFraction(nanos, scale);
 
             if (withTimeZone) {
-                zoneSeconds = offset;
-            } else {
-                seconds += offset;
+                zoneSeconds = ot.get(ChronoField.OFFSET_SECONDS);
+
+                seconds -= zoneSeconds;
+                seconds = DateTimeType.normaliseTime(seconds);
             }
 
             return new TimeData(seconds, nanos, zoneSeconds);
@@ -1059,6 +1111,8 @@ public final class DateTimeType extends DTIType {
 
             if (withTimeZone) {
                 zoneSeconds = session.getZoneSeconds();
+                seconds -= zoneSeconds;
+                seconds = DateTimeType.normaliseTime(seconds);
             }
 
             return new TimeData(seconds, nanos, zoneSeconds);
@@ -1139,8 +1193,8 @@ public final class DateTimeType extends DTIType {
                 ZoneOffset zone = ZoneOffset.ofTotalSeconds(ts.zone);
                 long millis =
                     HsqlDateTime.getNormalisedTime((ts.seconds + ts.zone)
-                                                   * 1000);
-                long      nanos = millis * 1000000L;
+                                                   * 1_000L);
+                long      nanos = millis * 1_000_000L;
                 LocalTime ldt   = LocalTime.ofNanoOfDay(nanos + ts.nanos);
                 Object    value = OffsetTime.of(ldt, zone);
 
@@ -1253,24 +1307,17 @@ public final class DateTimeType extends DTIType {
             case Types.SQL_TIMESTAMP_WITH_TIME_ZONE :
             case Types.SQL_TIMESTAMP : {
                 TimestampData ts = (TimestampData) a;
+                String tss = HsqlDateTime.getTimestampString(ts.getSeconds()
+                    + ts.getZone(), ts.getNanos(), scale);
 
-                sb = new StringBuilder();
-
-                HsqlDateTime.getTimestampString(sb,
-                                                ts.getSeconds()
-                                                + ts.getZone(), ts.getNanos(),
-                                                    scale);
-
-                if (!withTimeZone) {
-                    return sb.toString();
+                if (withTimeZone) {
+                    s = Type.SQL_INTERVAL_HOUR_TO_MINUTE
+                        .intervalSecondToString(((TimestampData) a).getZone(),
+                                                0, true);
+                    tss += s;
                 }
 
-                s = Type.SQL_INTERVAL_HOUR_TO_MINUTE.intervalSecondToString(
-                    ((TimestampData) a).getZone(), 0, true);
-
-                sb.append(s);
-
-                return sb.toString();
+                return tss;
             }
             default :
                 throw Error.runtimeError(ErrorCode.U_S0500, "DateTimeType");
@@ -1362,7 +1409,6 @@ public final class DateTimeType extends DTIType {
 
         switch (typeCode) {
 
-            /** @todo -  range checks for units added */
             case Types.SQL_TIME_WITH_TIME_ZONE :
             case Types.SQL_TIME :
                 if (b instanceof IntervalMonthData) {
@@ -1587,6 +1633,7 @@ public final class DateTimeType extends DTIType {
                 break;
 
             case Types.DTI_WEEK_OF_YEAR :
+            case Types.DTI_ISO_WEEK_OF_YEAR :
                 calendarPart = Calendar.WEEK_OF_YEAR;
                 break;
 
@@ -1998,7 +2045,7 @@ public final class DateTimeType extends DTIType {
      * compare data of the same types.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2081,7 +2128,7 @@ public final class DateTimeType extends DTIType {
      * Important: when this method returns, the boundaries of the periods may
      * have been changed.
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2155,7 +2202,7 @@ public final class DateTimeType extends DTIType {
      * the same result of "b OVERLAPS a"
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2197,7 +2244,7 @@ public final class DateTimeType extends DTIType {
      * Important: when this method returns, the boundaries of the periods may
      * have been changed.
      *
-     * @param session
+     * @param session  The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2236,7 +2283,7 @@ public final class DateTimeType extends DTIType {
      * than or equal to the start value of b, i.e., if ae <= as.
      * <p>
      *
-     * @param session
+     * @param session  The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2267,7 +2314,7 @@ public final class DateTimeType extends DTIType {
      * of y, i.e., if xe = ys.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2298,7 +2345,7 @@ public final class DateTimeType extends DTIType {
      * of y, i.e., if xs = ye.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2329,7 +2376,7 @@ public final class DateTimeType extends DTIType {
      * i.e., if xs >= ye.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2359,7 +2406,7 @@ public final class DateTimeType extends DTIType {
      * This predicate returns True if the two periods have every time point in common, i.e., if xs = ys and xe = ye.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2396,7 +2443,7 @@ public final class DateTimeType extends DTIType {
      * a period with the same date time value for the period start and end.
      * <p>
      *
-     * @param session
+     * @param session The session
      * @param a First period to compare
      * @param ta Types of the first period
      * @param b Second period to compare
@@ -2592,7 +2639,7 @@ public final class DateTimeType extends DTIType {
         return ti;
     }
 
-    /** @todo - overflow */
+    /* @todo - overflow */
     public static TimestampData addMonths(Session session,
                                           TimestampData source, int months) {
 
