@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ import org.hsqldb.rights.Grantee;
  * Base class for type objects.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.6.0
  * @since 1.9.0
  */
 public abstract class Type implements SchemaObject, Cloneable {
@@ -93,15 +93,6 @@ public abstract class Type implements SchemaObject, Cloneable {
         return userTypeModifier.getName();
     }
 
-    public final HsqlName getCatalogName() {
-
-        if (userTypeModifier == null) {
-            throw Error.runtimeError(ErrorCode.U_S0500, "Type");
-        }
-
-        return userTypeModifier.getSchemaName().schema;
-    }
-
     public final HsqlName getSchemaName() {
 
         if (userTypeModifier == null) {
@@ -111,6 +102,15 @@ public abstract class Type implements SchemaObject, Cloneable {
         return userTypeModifier.getSchemaName();
     }
 
+    public final HsqlName getCatalogName() {
+
+        if (userTypeModifier == null) {
+            throw Error.runtimeError(ErrorCode.U_S0500, "Type");
+        }
+
+        return userTypeModifier.getSchemaName().schema;
+    }
+
     public final Grantee getOwner() {
 
         if (userTypeModifier == null) {
@@ -337,8 +337,8 @@ public abstract class Type implements SchemaObject, Cloneable {
     public abstract boolean canConvertFrom(Type otherType);
 
     /**
-     * Can convert without changing the object
-     * @return 0 always, 1 range check required, -1 never
+     * When canConvertFrom() is true, can convert without changing the object
+     * @return 0 always, 1 only value range check required, -1 value conversion required
      */
     public int canMoveFrom(Type otherType) {
 
@@ -614,7 +614,7 @@ public abstract class Type implements SchemaObject, Cloneable {
         return typeCode + ((int) precision << 8) + (scale << 16);
     }
 
-    /** @todo 1.9.0 - review all - need max implementation defined lengths, used for parameters */
+    /* @todo 1.9.0 - review all - need max implementation defined lengths, used for parameters */
 
     // null type
     public static final Type SQL_ALL_TYPES = NullType.getNullType();
@@ -799,7 +799,7 @@ public abstract class Type implements SchemaObject, Cloneable {
 
     //
     public static final ArrayType SQL_ARRAY_ALL_TYPES =
-        new ArrayType(SQL_ALL_TYPES, 0);
+        new ArrayType(SQL_ALL_TYPES, ArrayType.defaultArrayCardinality);
 
     public static ArrayType getDefaultArrayType(int type) {
         return new ArrayType(getDefaultType(type),
@@ -1060,7 +1060,8 @@ public abstract class Type implements SchemaObject, Cloneable {
                     throw Error.error(ErrorCode.X_42592, "" + precision);
                 }
 
-            // fall through
+                return SQL_DOUBLE;
+
             case Types.SQL_REAL :
             case Types.SQL_DOUBLE :
                 return SQL_DOUBLE;
