@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2019, The HSQL Development Group
+ * Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -90,7 +90,7 @@ import java.util.ArrayList;
 // fredt@users 20190515 - enhancements
 
 /**
- * Modifies the source code to support different JDK or profile settings. <p>
+ * Modifies the source code to support different JDK or profile settings.
  * <pre>
  * Usage: java CodeSwitcher paths|{--pathlist=listfile} [{+|-}label...] [+][-]
  * If no labels are specified then all used
@@ -124,12 +124,6 @@ public class CodeSwitcher {
     private ArrayList<String> vSwitches;
     private static final int  MAX_LINELENGTH = 82;
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param a
-     */
     public static void main(String[] a) {
 
         CodeSwitcher s = new CodeSwitcher();
@@ -276,7 +270,7 @@ public class CodeSwitcher {
             }
         }
 
-        System.out.println("");
+        System.out.println();
     }
 
     /**
@@ -292,11 +286,6 @@ public class CodeSwitcher {
         }
     }
 
-    /**
-     * Wrapper
-     *
-     * @param path
-     */
     void addDir(String path) {
         addDir(new File(path));
     }
@@ -318,12 +307,6 @@ public class CodeSwitcher {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param name
-     */
     boolean processFile(String name) {
 
         File    f         = new File(name);
@@ -529,14 +512,8 @@ public class CodeSwitcher {
         write.close();
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param error
-     */
     static void printError(String error) {
-        System.out.println("");
+        System.out.println();
         System.out.println("ERROR: " + error);
     }
 }
