@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,14 +54,15 @@ import javax.swing.UIManager;
  * @version 1.7.2
  * @since 1.7.0
  */
-class CommonSwing {
+final class CommonSwing {
 
-    protected static String messagerHeader = "Database Manager Swing Error";
-    protected static String Native         = "Native";
-    protected static String Java           = "Java";
-    protected static String Motif          = "Motif";
-    protected static String plaf           = "plaf";
-    protected static String GTK            = "GTK";
+    protected static final String messagerHeader =
+        "Database Manager Swing Error";
+    protected static final String Native = "Native";
+    protected static final String Java   = "Java";
+    protected static final String Motif  = "Motif";
+    protected static String       plaf   = "plaf";
+    protected static String       GTK    = "GTK";
 
     // (ulrivo): An actual Image.
     static Image getIcon(String target) {
@@ -71,7 +72,7 @@ class CommonSwing {
                 CommonSwing.class.getResource("Hourglass.gif")).getImage());
         } else if (target.equalsIgnoreCase("Frame")) {
             return (new ImageIcon(
-                CommonSwing.class.getResource("hsqldb.gif")).getImage());
+                CommonSwing.class.getResource("hsqldb.png")).getImage());
         } else if (target.equalsIgnoreCase("Execute")) {
             return (new ImageIcon(
                 CommonSwing.class.getResource("run_exc.gif")).getImage());
@@ -107,7 +108,7 @@ class CommonSwing {
     // (weconsultants@users: Callable errorMessage method
     protected static void errorMessage(String errorMessage) {
 
-        /**
+        /*
          * Display Jpanel Error messages any text Errors. Overloads
          * errorMessage(Exception exceptionMsg)
          */
@@ -128,7 +129,7 @@ class CommonSwing {
     // (weconsultants@users: Callable errorMessage method
     public static void errorMessage(Exception exceptionMsg, boolean quiet) {
 
-        /**
+        /*
          * Display Jpanel Error messages any SQL Errors. Overloads
          * errorMessage(String e)
          */
@@ -136,8 +137,8 @@ class CommonSwing {
 
         JOptionPane.showOptionDialog(null, exceptionMsg, messagerHeader,
                                      JOptionPane.DEFAULT_OPTION,
-                                     JOptionPane.ERROR_MESSAGE, null,
-                                     options, options[0]);
+                                     JOptionPane.ERROR_MESSAGE, null, options,
+                                     options[0]);
 
         if (!quiet) {
             exceptionMsg.printStackTrace();
