@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -109,7 +109,7 @@ class DataAccessPoint implements Serializable {
         throw new DataAccessPointException("Nothing to Parse");
     }
 
-    void close() throws DataAccessPointException {}
+    void close() {}
 
     void beginDataTransfer() throws DataAccessPointException {
 
