@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -67,11 +67,11 @@ class HsqldbTransferHelper extends TransferHelper {
 
     String fixupColumnDefRead(TransferTable t, ResultSetMetaData meta,
                               String columnType, ResultSet columnDesc,
-                              int columnIndex) throws SQLException {
+                              int columnIndex) {
 
         String CompareString = "INTEGER IDENTITY";
 
-        if (columnType.indexOf(CompareString) >= 0) {
+        if (columnType.contains(CompareString)) {
 
             // We just found a increment
             columnType = "SERIAL";
@@ -82,9 +82,9 @@ class HsqldbTransferHelper extends TransferHelper {
 
     String fixupColumnDefWrite(TransferTable t, ResultSetMetaData meta,
                                String columnType, ResultSet columnDesc,
-                               int columnIndex) throws SQLException {
+                               int columnIndex) {
 
-        if (columnType.indexOf("SERIAL") >= 0) {
+        if (columnType.contains("SERIAL")) {
             columnType = "INTEGER GENERATED BY DEFAULT AS IDENTITY";
         }
 
