@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -78,7 +78,7 @@ class PostgresTransferHelper extends TransferHelper {
                               String columnType, ResultSet columnDesc,
                               int columnIndex) throws SQLException {
 
-        String SeqName   = new String("_" + columnDesc.getString(4) + "_seq");
+        String SeqName   = "_" + columnDesc.getString(4) + "_seq";
         int    spaceleft = 31 - SeqName.length();
 
         if (t.Stmts.sDestTable.length() > spaceleft) {
@@ -89,7 +89,7 @@ class PostgresTransferHelper extends TransferHelper {
 
         String CompareString = "nextval(\'\"" + SeqName + "\"\'";
 
-        if (columnType.indexOf(CompareString) >= 0) {
+        if (columnType.contains(CompareString)) {
 
             // We just found a increment
             columnType = "SERIAL";
@@ -118,9 +118,8 @@ class PostgresTransferHelper extends TransferHelper {
                                int columnIndex) throws SQLException {
 
         if (columnType.equals("SERIAL")) {
-            String SeqName = new String("_" + columnDesc.getString(4)
-                                        + "_seq");
-            int spaceleft = 31 - SeqName.length();
+            String SeqName = "_" + columnDesc.getString(4) + "_seq";
+            int spaceleft  = 31 - SeqName.length();
 
             if (t.Stmts.sDestTable.length() > spaceleft) {
                 SeqName = t.Stmts.sDestTable.substring(0, spaceleft)
