@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2020, The HSQL Development Group
+ * Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -120,7 +120,7 @@ import java.awt.image.MemoryImageSource;
   * @version 2.5.0
   * @since Hypersonic SQL
  */
-public class Transfer extends Applet
+public class Transfer extends Panel
 implements WindowListener, ActionListener, ItemListener, Traceable {
 
     Frame            fMain;
@@ -154,12 +154,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
     static final int TRFM_DUMP             = 2;
     static final int TRFM_RESTORE          = 3;
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param s
-     */
     public void trace(String s) {
 
         if ((s != null) &&!s.equals("")) {
@@ -178,9 +172,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         m._main(null);
     }
 
-    /**
-     * @throws IllegalArgumentException for the obvious reason
-     */
     public static void work(String[] arg) {
 
         Transfer m = new Transfer();
@@ -188,11 +179,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         m._main(arg);
     }
 
-    /**
-     * Run with --help arg for syntax help.
-     *
-     * @throws IllegalArgumentException for the obvious reason
-     */
     public static void main(String[] arg) {
 
         System.getProperties().put("sun.java2d.noddraw", "true");
@@ -500,8 +486,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
 
         ProcessNextStep();
         fMain.setVisible(true);
-
-        return;
     }
 
     private void RefreshMainDisplay() {
@@ -537,13 +521,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         fMain.setVisible(true);
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param f
-     * @param m
-     */
     private void addMenuItems(Menu f, String[] m) {
 
         for (int i = 0; i < m.length; i++) {
@@ -558,12 +535,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void itemStateChanged(ItemEvent e) {
 
         ItemSelectable item = e.getItemSelectable();
@@ -651,12 +622,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param t
-     */
     private void displayTable(TransferTable t) {
 
         tCurrent = t;
@@ -687,12 +652,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         cIdxForced.setState(t.Stmts.bIdxForced);
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param and
-     */
     private void updateEnabled(boolean and) {
 
         boolean b = cTransfer.getState();
@@ -722,9 +681,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method ProcessNextStep
-     */
     private void ProcessNextStep() {
 
         switch (iSelectionStep) {
@@ -767,12 +723,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param ev
-     */
     public void actionPerformed(ActionEvent ev) {
 
         if (ev.getSource() instanceof TextField) {
@@ -809,7 +759,7 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
             transfer();
         } else if (s.equals("Quit")) {
             exit();
-        } else if (s.indexOf("Select Schema") >= 0) {
+        } else if (s.contains("Select Schema")) {
             String[] selection = lTable.getSelectedItems();
 
             if ((selection == null) || (selection.length == 0)) {
@@ -829,7 +779,7 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
             }
 
             ProcessNextStep();
-        } else if (s.indexOf("Select Catalog") >= 0) {
+        } else if (s.contains("Select Catalog")) {
             String selection = lTable.getSelectedItem();
 
             if ((selection == null) || (selection.equals(""))) {
@@ -890,28 +840,10 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowActivated(WindowEvent e) {}
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowDeactivated(WindowEvent e) {}
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowClosed(WindowEvent e) {}
 
     private void cleanup() {
@@ -927,12 +859,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         } catch (Exception e) {}
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param ev
-     */
     public void windowClosing(WindowEvent ev) {
 
         fMain.dispose();
@@ -942,34 +868,12 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowDeiconified(WindowEvent e) {}
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowIconified(WindowEvent e) {}
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param e
-     */
     public void windowOpened(WindowEvent e) {}
 
-    /**
-     * Method declaration
-     *
-     */
     private void initGUI() {
 
         Font fFont = new Font("Dialog", Font.PLAIN, 12);
@@ -1124,12 +1028,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         fMain.add("South", pMessage);
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param center
-     */
     private Panel createBorderPanel(Component center) {
 
         Panel p = new Panel();
@@ -1145,12 +1043,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         return p;
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param s
-     */
     private Label createLabel(String s) {
 
         Label l = new Label(s);
@@ -1212,10 +1104,6 @@ implements WindowListener, ActionListener, ItemListener, Traceable {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     */
     private void transfer() {
 
         saveTable();
