@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -435,12 +435,12 @@ class TransferDb extends DataAccessPoint {
         String    insert         = "";
         ResultSet ImportedKeys   = null;
         boolean   importedkeys   = false;
-        String    alterCreate    = new String("");
-        String    alterDrop      = new String("");
-        String    ConstraintName = new String("");
-        String    RefTableName   = new String("");
-        String    foreignKeyName = new String("");
-        String    columnName     = new String("");
+        String    alterCreate    = "";
+        String    alterDrop      = "";
+        String    ConstraintName = "";
+        String    RefTableName   = "";
+        String    foreignKeyName = "";
+        String    columnName     = "";
 
         Dest.helper.setSchema(TTable.Stmts.sSchema);
 
@@ -638,9 +638,9 @@ class TransferDb extends DataAccessPoint {
 
         boolean   indices     = false;
         ResultSet Indices     = null;
-        String    IndiceName  = new String("");
-        String    CreateIndex = new String("");
-        String    DropIndex   = new String("");
+        String    IndiceName  = "";
+        String    CreateIndex = "";
+        String    DropIndex   = "";
 
         try {
             Indices = meta.getIndexInfo(TTable.Stmts.sDatabaseToConvert,
@@ -881,7 +881,7 @@ class TransferDb extends DataAccessPoint {
         //}
     }
 
-    void close() throws DataAccessPointException {
+    void close() {
 
         if (srcStatement != null) {
             try {
@@ -900,20 +900,8 @@ class TransferDb extends DataAccessPoint {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param type
-     * @param r
-     * @param p
-     *
-     * @throws SQLException
-     */
     private void transferRow(TransferResultSet r, PreparedStatement p,
-                             int len,
-                             int[] types)
-                             throws DataAccessPointException, SQLException {
+                             int len, int[] types) throws SQLException {
 
         for (int i = 1; i <= len; i++) {
             int    t = types[i];
