@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -139,7 +139,7 @@ class TransferSQLText extends DataAccessPoint {
         }
     }
 
-    void close() throws DataAccessPointException {
+    void close() {
 
         if (WTextWrite != null) {
             try {
@@ -149,16 +149,6 @@ class TransferSQLText extends DataAccessPoint {
         }
     }
 
-    /**
-     * Method declaration
-     *
-     *
-     * @param type
-     * @param r
-     * @param p
-     *
-     * @throws SQLException
-     */
     private void transferRow(TransferResultSet r) throws Exception {
 
         String sLast = "";
@@ -197,7 +187,7 @@ class TransferSQLText extends DataAccessPoint {
         sLast = "";
     }
 
-    class ColumnDef {
+    static class ColumnDef {
 
         String columnName;
         String columnType;
@@ -304,8 +294,7 @@ class TransferSQLText extends DataAccessPoint {
     }
 
     String translateTypes(String CreateLine, TransferTable TTable,
-                          DataAccessPoint Dest)
-                          throws DataAccessPointException {
+                          DataAccessPoint Dest) {
 
         String    translatedLine = "";
         JDBCTypes JDBCT          = new JDBCTypes();
@@ -328,7 +317,7 @@ class TransferSQLText extends DataAccessPoint {
             columnName = cDef.columnName;
             columnType = cDef.columnType;
 
-            if (columnName.toUpperCase().indexOf("CONSTRAINT") >= 0) {
+            if (columnName.toUpperCase().contains("CONSTRAINT")) {
                 translatedLine +=
                     CreateLine.substring(currentPos, currentPos + cDef.len)
                     + ",";
@@ -838,7 +827,7 @@ class TransferSQLText extends DataAccessPoint {
                             String sValue =
                                 currentLine.substring(iStart).trim();
 
-                            if (sValue.indexOf("<null>") >= 0) {
+                            if (sValue.contains("<null>")) {
                                 vColumnValues.addElement(null);
                             } else {
                                 int    i       = sValue.indexOf('\'') + 1;
